import _extends from '@babel/runtime/helpers/esm/extends';
import _objectWithoutPropertiesLoose from '@babel/runtime/helpers/esm/objectWithoutPropertiesLoose';
import React, { forwardRef, Fragment, useMemo, useState, useEffect, PureComponent, cloneElement, useRef, useCallback, useLayoutEffect } from 'react';
import styled, { css, keyframes, createGlobalStyle } from '@xstyled/styled-components';
import * as S from '@xstyled/system';
import { compose, createSystemComponent, backgrounds, basics, borders, color, display, flexboxes, grids, height, maxHeight, maxWidth, minHeight, minWidth, positioning, space, typography, verticalAlign, width, margin, marginBottom, marginLeft, marginRight, marginTop, mx, my, th, getFont as getFont$1, getColor, rpxTransformers } from '@xstyled/system';
import difference from 'lodash.difference';
import { oneOfType, func, object, string, oneOf, bool, node, number } from 'prop-types';
import { Button as Button$2 } from 'reakit/Button';
import { Field as Field$2 } from 'react-final-form';
import Downshift from 'downshift';
import matchSorter from 'match-sorter';
import kebabCase from 'lodash.kebabcase';
import isEqual from 'lodash.isequal';
import uniqBy from 'lodash.uniqby';
import differenceBy from 'lodash.differenceby';
import ReactDatePicker from 'react-datepicker';
import range from 'lodash.range';
import _inheritsLoose from '@babel/runtime/helpers/esm/inheritsLoose';
import { createPortal } from 'react-dom';
import { useDropzone } from 'react-dropzone';
import mime from 'mime/lite';
import { Checkbox } from 'reakit/Checkbox';
import { Radio, useRadioState, RadioGroup as RadioGroup$1 } from 'reakit/Radio';
import SimpleMDE from 'react-simplemde-editor';
import { NimblePicker } from 'emoji-mart';
import data from 'emoji-mart/data/apple.json';
import { useRoverState, Rover } from 'reakit/Rover';
import { TabList as TabList$2, Tab as Tab$2, TabPanel as TabPanel$2 } from 'reakit/Tab';
export { useTabState } from 'reakit/Tab';
import flattenChildren from 'react-flatten-children';
import Popper$1 from 'popper.js';
import { Tooltip as Tooltip$2, TooltipReference, useTooltipState, useDialogState } from 'reakit';
import { normalize } from 'polished';
import merge from 'lodash.merge';
import _get from 'lodash.get';

var FINAL_FORM_META_TYPES =
/*#__PURE__*/
Object.freeze({
  active: bool,
  data: object,
  dirty: bool,
  dirtySinceLastSubmit: bool,
  error: object,
  initial: string,
  invalid: bool,
  modified: bool,
  pristine: bool,
  submitError: object,
  submitFailed: bool,
  submitSucceeded: bool,
  submitting: bool,
  touched: bool,
  valid: bool,
  validating: bool,
  visited: bool
});
var COMPONENT_TYPE =
/*#__PURE__*/
oneOfType([func, object, string]);
var SHAPES_TYPE =
/*#__PURE__*/
oneOf(['square', 'circle']);
var SIZES_TYPE =
/*#__PURE__*/
oneOf(['sm', 'md', 'lg']);
var VARIANTS_TYPE =
/*#__PURE__*/
oneOf(['error', 'info', 'valid', 'warning']);

var datePickerProps = ['adjustDateOnChange', 'allowSameDay', 'calendarClassName', 'calendarContainer', 'customInput', 'customInputRef', 'dateFormat', 'dateFormatCalendar', 'dayClassName', 'disabledKeyboardNavigation', 'dropdownMode', 'endDate', 'excludeDates', 'filterDate', 'fixedHeight', 'formatWeekNumber', 'highlightDates', 'includeDates', 'includeTimes', 'injectTimes', 'inline', 'isClearable', 'locale', 'maxDate', 'minDate', 'monthsShown', 'onWeekSelect', 'onClickOutside', 'onChangeRaw', 'onInputClick', 'onMonthChange', 'onYearChange', 'onInputError', 'openToDate', 'peekNextMonth', 'placeholderText', 'popperContainer', 'popperClassName', 'popperModifiers', 'popperPlacement', 'popperProps', 'preventOpenOnFocus', 'scrollableYearDropdown', 'scrollableMonthYearDropdown', 'selectsEnd', 'selectsStart', 'showMonthDropdown', 'showMonthYearDropdown', 'showWeekNumbers', 'showYearDropdown', 'strictParsing', 'forceShowMonthNavigation', 'showDisabledMonthNavigation', 'startDate', 'startOpen', 'timeCaption', 'todayButton', 'useWeekdaysShort', 'formatWeekDay', 'weekLabel', 'withPortal', 'yearDropdownItemNumber', 'shouldCloseOnSelect', 'showTimeInput', 'showMonthYearPicker', 'showQuarterYearPicker', 'showTimeSelect', 'showTimeSelectOnly', 'timeFormat', 'timeIntervals', 'minTime', 'maxTime', 'excludeTimes', 'useShortMonthInDropdown', 'clearButtonTitle', 'previousMonthButtonLabel', 'nextMonthButtonLabel', 'previousYearButtonLabel', 'nextYearButtonLabel', 'timeInputLabel', 'renderCustomHeader', 'renderDayContents', 'wrapperClassName', 'inlineFocusSelectedMonth', 'onDayMouseEnter', 'onMonthMouseLeave'];
var fileDropProps = ['onAddFile', 'onRemoveFile'];
var customProps = ['checkableField', 'focused', 'handleRemoveFile', 'icon', 'iconPlacement', 'isClearable', 'isCreatable', 'isDragAccept', 'isDragActive', 'isDragReject', 'isEditable', 'isMultiple', 'isSearchable', 'maxSize', 'minRows', 'popperZIndex', 'renderItem'];
var finalFormFieldProps = ['afterSubmit', 'allowNull', 'beforeSubmit', 'component', 'format', 'formatOnBlur', 'initialValue', 'isEqual', 'onCreate', 'parse', 'validate', 'validateFields'];
var reservedProps =
/*#__PURE__*/
[].concat(customProps, datePickerProps, fileDropProps, finalFormFieldProps,
/*#__PURE__*/
Object.keys(FINAL_FORM_META_TYPES));

var systemProps = [backgrounds, basics, borders, color, display, flexboxes, grids, height, maxHeight, maxWidth, minHeight, minWidth, positioning, space, typography, verticalAlign, width];
var wrapperProps = [margin, marginBottom, marginLeft, marginRight, marginTop, mx, my, positioning, width];
var system =
/*#__PURE__*/
compose.apply(void 0, systemProps);
var wrapperSystem =
/*#__PURE__*/
compose.apply(void 0, wrapperProps);
var componentProps =
/*#__PURE__*/
difference(system.meta.props, wrapperSystem.meta.props).map(function (prop) {
  return S[prop];
}).filter(function (prop) {
  return prop;
});
var componentSystem =
/*#__PURE__*/
compose.apply(void 0, componentProps);
var filterComponent = function filterComponent(Component, omitProps) {
  if (omitProps === void 0) {
    omitProps = [];
  }

  var unallowedProps = {
    meta: {
      props: ['connected'].concat(omitProps, reservedProps, system.meta.props)
    }
  };
  return createSystemComponent(React, Component, unallowedProps);
};

var Box =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "Box",
  componentId: "sc-16om3c-0"
})(function () {
  return css(["", ";"], system);
});

var getBlockHeight = function getBlockHeight(props) {
  return "\n  calc(" + th.fontSize(props.variant) + " * " + th.lineHeight(props.variant) + " * " + props.lines + ")";
};

var Text =
/*#__PURE__*/
styled.p.withConfig({
  displayName: "styles__Text",
  componentId: "sc-1tgsskr-0"
})(function (props) {
  var lines = props.lines,
      underline = props.underline,
      variant = props.variant;
  var blockHeight = lines ? getBlockHeight(props) : null;
  return css(["", ";", ";display:block;height:", ";display:-webkit-box;-webkit-box-orient:vertical;-webkit-line-clamp:", ";overflow:hidden;", ";"], th("texts." + variant), underline && th('underline'), blockHeight, lines || 'none', system);
});

var TAG_NAMES = {
  h1: 'h1',
  h2: 'h2',
  h3: 'h3',
  h4: 'h4',
  body1: 'p',
  body2: 'p',
  body3: 'p',
  body4: 'p',
  subtitle1: 'p',
  subtitle2: 'p',
  meta1: 'p',
  meta2: 'p'
};
var Text$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var as = _ref.as,
      children = _ref.children,
      dataTestId = _ref.dataTestId,
      lines = _ref.lines,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'body1' : _ref$variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["as", "children", "dataTestId", "lines", "variant"]);

  var tagName = as || TAG_NAMES[variant];
  return React.createElement(Text, _extends({
    as: tagName,
    "data-testid": dataTestId,
    lines: lines,
    ref: ref,
    variant: variant
  }, rest), children);
});
Text$1.displayName = 'Text';

var Alert =
/*#__PURE__*/
styled(Box)(function (_ref) {
  var variant = _ref.variant;
  return css(["", ";", ";", ""], th('alerts.default'), th("alerts." + variant), system);
});
var Title =
/*#__PURE__*/
styled(Text$1).withConfig({
  displayName: "styles__Title",
  componentId: "rcpwqw-0"
})(["margin:0;margin-bottom:sm;font-size:inherit;font-weight:medium;", " &:only-child{margin-bottom:0;}"], system);

var Alert$1 = function Alert$1(_ref) {
  var children = _ref.children,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'error' : _ref$variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "variant"]);

  return React.createElement(Alert, _extends({
    variant: variant
  }, rest), children);
};

var AlertTitle = function AlertTitle(_ref2) {
  var children = _ref2.children,
      dataTestId = _ref2.dataTestId;
  return React.createElement(Title, {
    "data-testid": dataTestId
  }, children);
};

var iconSvgStrokedStyles =
/*#__PURE__*/
css(["g,path{stroke:inherit;fill:none;}"]);
var iconSvgFilledStyles =
/*#__PURE__*/
css(["g,path{fill:currentColor;stroke:none;}"]);
var Icon =
/*#__PURE__*/
styled.svg.withConfig({
  displayName: "styles__Icon",
  componentId: "sc-16ndowf-0"
})(function (_ref) {
  var _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      stroked = _ref.stroked;
  return css(["", ";width:", ";height:", ";", ";"], stroked ? iconSvgStrokedStyles : iconSvgFilledStyles, th("icons." + size), th("icons." + size), system);
});

var icons = {
  actions: {
    width: 15,
    height: 15,
    block: '<path d="M31.54 68.45c7.56.73 34.88 2.18 49.91-12.85C96.51 40.54 95.04 13.23 94.3 5.68c-7.56-.73-34.88-2.19-49.91 12.84C29.33 33.58 30.8 60.9 31.54 68.45zM99.25 2.93c.22 1.5 5.25 37.03-14.1 56.38a44.74 44.74 0 0 1-14.6 9.49l-5.41 21.32a2.62 2.62 0 0 1-4.39 1.2L43.5 74.09c-1 .03-1.98.05-2.9.05-6.85 0-11.54-.69-11.8-.72a2.62 2.62 0 0 1-2.21-2.21c-.1-.6-.93-6.57-.7-14.75L8.66 39.23a2.62 2.62 0 0 1-.68-2.54 2.62 2.62 0 0 1 1.88-1.85l21.26-5.4a44.84 44.84 0 0 1 9.55-14.62C48.74 6.76 61.08 1.77 76.35.4c11.38-1.02 20.32.28 20.7.33a2.62 2.62 0 0 1 2.2 2.2zM72.27 40.08a8.69 8.69 0 0 0 2.56-6.18 8.69 8.69 0 0 0-2.56-6.18 8.69 8.69 0 0 0-6.19-2.57c-2.33 0-4.53.91-6.18 2.57a8.7 8.7 0 0 0-2.56 6.18 8.7 8.7 0 0 0 2.56 6.18 8.68 8.68 0 0 0 6.18 2.56c2.34 0 4.53-.9 6.19-2.56zM56.2 24.01a14 14 0 0 1 19.77 0 14 14 0 0 1 0 19.78 13.94 13.94 0 0 1-9.89 4.09A14 14 0 0 1 56.2 24zm-23.8 55.7a2.62 2.62 0 0 1 1.7 3.3 23.5 23.5 0 0 1-5.6 9.6C22.14 98.99 12.38 100 6.8 100c-2.45 0-4.1-.2-4.3-.22A2.62 2.62 0 0 1 .21 97.5c-.08-.69-2-16.87 7.16-26.02a23.46 23.46 0 0 1 9.6-5.6 2.62 2.62 0 0 1 3.3 1.7 2.62 2.62 0 0 1-1.7 3.28c-3.1 1-5.62 2.45-7.5 4.32-5.64 5.64-5.97 15.28-5.81 19.53 4.26.16 13.91-.19 19.53-5.8a18.34 18.34 0 0 0 4.32-7.5 2.62 2.62 0 0 1 3.29-1.7z" fill="currentColor"/>'
  },
  activity: {
    width: 15,
    height: 15,
    block: '<path d="M99.796 48.633a10.29 10.29 0 0 0-.576-1.89 10.005 10.005 0 0 0-.926-1.728 10.945 10.945 0 0 0-1.255-1.543 10.19 10.19 0 0 0-1.546-1.254 9.555 9.555 0 0 0-1.735-.923c-.62-.26-1.257-.447-1.89-.576-3.296-.663-6.79.418-9.132 2.753-.462.476-.896.98-1.257 1.543a9.99 9.99 0 0 0-.923 1.728c-.261.621-.45 1.256-.58 1.89-.057.294-.097.588-.132.88l-7.29 1.212-6.936-42.607a2.526 2.526 0 0 0-2.405-2.116c-1.137-.05-2.271.767-2.551 1.938L43.117 81.702l-13.533-45.45c-.326-1.092-1.29-1.822-2.486-1.804a2.527 2.527 0 0 0-2.393 1.924l-5.682 23.239-16.908 2.807a2.525 2.525 0 0 0-2.08 2.901 2.531 2.531 0 0 0 2.909 2.076l18.555-3.08a2.526 2.526 0 0 0 2.041-1.892l3.86-15.79 13.566 45.562A2.531 2.531 0 0 0 43.39 94l.071-.001a2.527 2.527 0 0 0 2.39-1.94L62.657 21.4l5.313 32.634a2.524 2.524 0 0 0 2.91 2.083l9.687-1.607a10.123 10.123 0 0 0 2.168 3.235c1.878 1.888 4.494 2.955 7.152 2.955.65 0 1.329-.057 1.98-.187a11.46 11.46 0 0 0 1.89-.577c.607-.26 1.199-.578 1.735-.938a9.374 9.374 0 0 0 1.546-1.253A10.143 10.143 0 0 0 100 50.608c0-.649-.072-1.312-.204-1.975" fill="currentColor" fill-rule="evenodd"/>'
  },
  add: {
    width: 15,
    height: 15,
    block: '<path d="M57.361 41.514V9.362C57.361 4.192 55.681 0 50 0s-7.362 4.191-7.362 9.362v34.284L8.302 47.328C3.17 47.915-.523 50.552.061 55.69c.543 4.778 4.593 6.304 9.29 6.304l33.287-3.501v32.146c0 5.17 2.19 9.362 7.362 9.362 5.174 0 7.361-4.191 7.361-9.362v-34.28l34.34-3.686c5.136-.587 8.824-3.224 8.238-8.361-.584-5.137-5.218-6.844-10.36-6.242" fill="currentColor" fill-rule="evenodd"/>'
  },
  address: {
    width: 15,
    height: 15,
    block: '<path d="M70.957 50.134L8.483 57.233V23.709l62.941-7.151L90.12 30.989 70.957 50.134zm24.98-21.572L73.9 11.553a2.734 2.734 0 0 0-1.99-.555l-21.988 2.499V2.736c0-.78-.334-1.522-.917-2.04a2.733 2.733 0 0 0-2.135-.68L35.988 1.255a2.738 2.738 0 0 0-2.432 2.717v11.386L5.431 18.553A2.738 2.738 0 0 0 3 21.27v39.027a2.734 2.734 0 0 0 2.742 2.734c.101 0 .206-.006.31-.017l27.504-3.125v36.508a2.734 2.734 0 0 0 2.742 2.734c.102 0 .207-.006.31-.017l10.882-1.237a2.736 2.736 0 0 0 2.432-2.718V58.03l22.61-2.57a2.746 2.746 0 0 0 1.63-.784l22.036-22.019a2.727 2.727 0 0 0-.262-4.093z" fill="currentColor" fill-rule="evenodd"/>'
  },
  anniversary: {
    width: 15,
    height: 15,
    block: '<path d="M68.108 59.605c15.12-1.717 27.42-15.747 27.42-31.274 0-7.56-2.888-14.293-8.132-18.958-4.343-3.862-9.89-5.912-15.863-5.912-1 0-2.011.058-3.032.173-15.119 1.718-27.42 15.747-27.42 31.274 0 7.56 2.889 14.292 8.132 18.958 5.068 4.508 11.778 6.546 18.895 5.739zm-3.83 9.457l8.263-.938-3.226-4.74c-.149-.22-.375-.33-.675-.33l-.04.001c-.385.013-.915.226-1.246.79l-3.076 5.217zM29.224 29.564a3.605 3.605 0 0 0 3.612-3.599 3.605 3.605 0 0 0-3.612-3.597c-10.726 0-19.453 8.903-19.453 19.848a3.604 3.604 0 0 0 3.61 3.597 3.604 3.604 0 0 0 3.612-3.597c0-6.977 5.488-12.652 12.231-12.652zM99 28.331c0 15.755-11.442 30.118-26.26 33.923l4.285 6.293a1.732 1.732 0 0 1-1.24 2.691l-6.403.728-2.021 3.563c-.994 1.754-1.27 3.691-.772 5.452.415 1.474 1.362 2.685 2.668 3.41 4.514 2.513 6.002 8.35 3.385 13.296a1.739 1.739 0 0 1-2.345.723 1.724 1.724 0 0 1-.725-2.337c1.758-3.323.894-7.045-2.008-8.659-2.118-1.179-3.651-3.13-4.318-5.496-.748-2.655-.36-5.528 1.093-8.092l.78-1.377-3.902.445a1.74 1.74 0 0 1-1.653-.776 1.724 1.724 0 0 1-.04-1.82l4.194-7.117c-5.471-.252-10.598-2.01-14.9-5.179-4.033 4.72-9.371 8.288-15.368 9.894l3.623 5.321c.34.502.395 1.144.14 1.695a1.74 1.74 0 0 1-1.38.996l-5.532.629-1.724 3.043c-.848 1.498-1.083 3.145-.662 4.641.351 1.244 1.15 2.266 2.25 2.876 4.074 2.268 5.42 7.529 3.062 11.981a1.74 1.74 0 0 1-2.346.721 1.728 1.728 0 0 1-.725-2.337c1.494-2.823.77-5.978-1.684-7.342a8.167 8.167 0 0 1-3.9-4.963c-.672-2.39-.323-4.975.982-7.28l.486-.857-3.029.344a1.74 1.74 0 0 1-1.653-.775 1.724 1.724 0 0 1-.04-1.82l3.517-5.965c-5.47-.327-10.537-2.363-14.586-5.965C4.93 58.107 2 51.321 2 43.726 2 28.46 14.125 14.661 29.028 12.97c5.225-.593 10.231.375 14.565 2.696C49.153 7.344 58.071 1.335 68.108.196c8.11-.92 15.783 1.421 21.599 6.595C95.7 12.121 99 19.773 99 28.331zM69.693 10.943a3.605 3.605 0 0 1 3.611 3.599 3.604 3.604 0 0 1-3.61 3.597c-7.934 0-14.39 6.669-14.39 14.864a3.605 3.605 0 0 1-3.611 3.599 3.605 3.605 0 0 1-3.61-3.599c0-12.165 9.694-22.06 21.61-22.06z" fill="currentColor" fill-rule="evenodd"/>'
  },
  archive: {
    width: 15,
    height: 15,
    block: '<path d="M94.82 81.43V37l-7.68 1-24.88 3.24-21.6 2.8v44.45l54.16-7.05zM59.34 11.52L9.4 18.02l29.34 21.06 6.45-.84 14.14-1.84V11.52zm5.18 2.1v22.1l26.07-3.38-26.07-18.72zM100 33.97l.01.08V83.7a2.58 2.58 0 0 1-2.26 2.56l-59.33 7.72a2.56 2.56 0 0 1-.34.02c-.25 0-.49-.05-.72-.11l-.1-.03a2.59 2.59 0 0 1-.64-.32l-.06-.03L1.07 67.88A2.58 2.58 0 0 1 0 65.8V16.3c0-.14.04-.28.06-.41.01-.07 0-.15.02-.22l.01-.03c.07-.24.16-.47.3-.68v-.02c.13-.2.28-.38.46-.54l.23-.16c.11-.08.2-.17.33-.23l.05-.02.29-.1c.14-.05.28-.1.43-.12l.08-.02 59.33-7.72c.17-.02.34-.02.51-.01l.1.01a2.63 2.63 0 0 1 .69.17c.2.08.38.17.55.3l35.48 25.47.07.06.13.1c.12.1.23.22.33.35l.03.04c.14.18.24.38.33.6.02.05.04.1.05.17.06.17.1.34.11.52l.02.16zM75.9 55.5v-.91c0-.43-.14-.78-.4-1.02a1.24 1.24 0 0 0-.84-.29c-.07 0-.15 0-.23.02l-12.69 1.65a2.64 2.64 0 0 0-2.15 2.43v.92c0 .43.15.78.42 1.01.27.24.63.34 1.06.28l12.69-1.65a2.64 2.64 0 0 0 2.15-2.44zm-2.14-7.32c1.9-.25 3.77.3 5.15 1.51 1.39 1.21 2.18 3 2.18 4.9v.91a7.75 7.75 0 0 1-6.66 7.56l-12.69 1.65a6.9 6.9 0 0 1-.88.06c-1.59 0-3.1-.56-4.28-1.58a6.49 6.49 0 0 1-2.17-4.9v-.9a7.75 7.75 0 0 1 6.66-7.56l12.69-1.65z" fill="currentColor"/>'
  },
  ats: {
    width: 15,
    height: 15,
    block: '<path d="M60.41 50.28c6.86-.72 12.58 3.45 14.03 9.73a2.9 2.9 0 0 1-2.53 3.5L49.5 66.07a2.92 2.92 0 0 1-3.13-3.69c1.73-6.22 7.25-11.27 13.8-12.07a9.82 9.82 0 0 1-11.09-9.97c0-6.21 5.03-11.82 11.22-12.53 6.2-.7 11.22 3.76 11.22 9.96 0 6.17-4.96 11.75-11.1 12.51zm28.8 21.65V13.98l-57.85 6.6v57.96l57.86-6.6zm-78.43-30.6l15.8-1.8V18.45a2.4 2.4 0 0 1 2.12-2.38l14.58-1.67V5.08l-32.5 3.71v32.54zM93.2 9.51c.5.45.8 1.1.8 1.79v62.77a2.4 2.4 0 0 1-2.12 2.38l-43.82 5v11.9a2.4 2.4 0 0 1-2.12 2.38L8.66 99.98A2.39 2.39 0 0 1 6 97.6V60.24c0-1.22.91-2.25 2.12-2.38l18.46-2.11v-11.4L8.66 46.4a2.4 2.4 0 0 1-1.86-.6 2.4 2.4 0 0 1-.8-1.78V6.65c0-1.22.91-2.24 2.12-2.38L45.4.01a2.4 2.4 0 0 1 2.66 2.39v11.46L91.34 8.9a2.39 2.39 0 0 1 1.86.6z" fill="currentColor"/>'
  },
  attachment: {
    width: 15,
    height: 15,
    block: '<path d="M18 68.071V23.06C18 10.377 28.4 0 41.11 0c12.712 0 23.112 10.377 23.112 23.06v45.01c0 7.77-6.435 14.19-14.222 14.19s-14.222-6.42-14.222-14.19V26.386a5.32 5.32 0 0 1 2.644-4.672 5.344 5.344 0 0 1 5.378 0 5.32 5.32 0 0 1 2.644 4.672V68.07c0 2.057 1.494 3.548 3.556 3.548 2.062 0 3.555-1.49 3.555-3.548V23.06c0-6.971-5.458-12.417-12.444-12.417-6.987 0-12.444 5.446-12.444 12.417v45.01c0 11.884 9.422 21.286 21.333 21.286 11.91 0 21.333-9.402 21.333-21.286V31.929a5.32 5.32 0 0 1 2.645-4.672 5.344 5.344 0 0 1 5.377 0 5.32 5.32 0 0 1 2.644 4.672v36.142C82 85.668 67.635 100 50 100c-17.635 0-32-14.332-32-31.929z" fill="currentColor"/>'
  },
  avatar: {
    width: 15,
    height: 15,
    block: '<path d="M49.967 94.572a41.588 41.588 0 0 1-27.89-10.68C23.47 72.89 31.42 63.695 42.214 60.785a2.723 2.723 0 0 0 2.01-2.518 2.724 2.724 0 0 0-1.801-2.671c-8.202-2.944-13.713-10.765-13.713-19.46a20.56 20.56 0 0 1 6.063-14.633 20.559 20.559 0 0 1 14.633-6.06c11.411 0 20.694 9.284 20.694 20.693 0 8.7-5.515 16.52-13.722 19.463a2.722 2.722 0 0 0 .211 5.189A27.412 27.412 0 0 1 76.815 84.8a41.718 41.718 0 0 1-26.848 9.77M49.999 0C22.43 0 0 22.43 0 50s22.43 50 50 50 50-22.43 50-50S77.57 0 50 0" fill="currentColor" fill-rule="evenodd"/>'
  },
  basketball: {
    width: 15,
    height: 15,
    block: '<path d="M39.6 78.64a2.44 2.44 0 0 1 0 3.45L22.4 99.3a2.43 2.43 0 0 1-1.73.71 2.43 2.43 0 0 1-1.73-.71 2.43 2.43 0 0 1 0-3.45l17.21-17.2a2.44 2.44 0 0 1 3.45 0zm-21.1 7.79a2.44 2.44 0 0 1-1.73-4.16l9.54-9.53a2.44 2.44 0 1 1 3.45 3.45l-9.54 9.53c-.47.47-1.1.7-1.72.7zm-1.34-13.2c-.47.48-1.1.71-1.72.71a2.44 2.44 0 0 1-1.72-4.16l3.83-3.83a2.44 2.44 0 0 1 3.45 0 2.44 2.44 0 0 1 0 3.45l-3.84 3.83zm47.06-26.97a31.09 31.09 0 0 1 17.76-7.41 31.19 31.19 0 0 1-7.41 17.75L64.22 46.26zm-3.45 3.45l10.35 10.34a31.23 31.23 0 0 1-17.77 7.41 31.05 31.05 0 0 1 7.42-17.75zM50.73 39.68l6.57 6.56a35.9 35.9 0 0 0-8.86 21.23 31.22 31.22 0 0 1-18.09-7.42l20.39-20.37zM40.7 22.77L30.35 12.42a31.25 31.25 0 0 1 17.77-7.4 31.03 31.03 0 0 1-7.42 17.75zm10.03 10.02l-6.56-6.56A35.92 35.92 0 0 0 53.03 5a31.24 31.24 0 0 1 18.09 7.42L50.73 32.8zM82 33.94a35.95 35.95 0 0 0-21.25 8.86l-6.57-6.56 20.39-20.37A31.18 31.18 0 0 1 82 33.94zM26.9 15.87l10.35 10.34a31.1 31.1 0 0 1-17.76 7.42 31.2 31.2 0 0 1 7.41-17.76zm-7.43 22.66a35.96 35.96 0 0 0 21.25-8.85l6.56 6.56L26.9 56.6a31.18 31.18 0 0 1-7.43-18.07zm67.5-2.03l.03-.22-.02-.2A36.16 36.16 0 0 0 50.89.02l-.2-.02-.22.02A36.15 36.15 0 0 0 14.5 35.98l-.02.22.02.19a36.17 36.17 0 0 0 36.1 36.06l.19.02.21-.02A36.16 36.16 0 0 0 86.98 36.5z" fill="currentColor"/>'
  },
  behance: {
    width: 15,
    height: 15,
    block: '<path d="M90.3 29.2H65.26v-5.8h25.06v5.8zM48.58 53C50.2 55.33 51 58.17 51 61.5c0 3.43-.9 6.52-2.76 9.25a16.5 16.5 0 0 1-4.4 4.55 17.61 17.61 0 0 1-7.02 2.92c-2.7.52-5.64.78-8.79.78H0V21h30.05c7.57.12 12.94 2.16 16.11 6.18a14.07 14.07 0 0 1 2.85 8.86c0 3.54-.95 6.38-2.88 8.53a14.62 14.62 0 0 1-4.73 3.3c3.16 1.08 5.56 2.78 7.17 5.13zm-34.22-9.13h13.17c2.7 0 4.89-.48 6.57-1.44 1.69-.96 2.53-2.66 2.53-5.1 0-2.7-1.11-4.49-3.34-5.35-1.92-.6-4.37-.9-7.35-.9H14.35v12.79zm23.54 16.8c0-3.02-1.32-5.1-3.96-6.22-1.48-.63-3.56-.96-6.22-.98H14.35v15.46H27.5c2.7 0 4.8-.33 6.3-1.02 2.72-1.27 4.09-3.67 4.09-7.24zm61.71-9.44c.3 1.9.44 4.65.39 8.25H67.54c.18 4.17 1.72 7.1 4.66 8.77a12.4 12.4 0 0 0 6.42 1.56c2.65 0 4.8-.63 6.47-1.91a9.2 9.2 0 0 0 2.39-2.85h11.9c-.32 2.46-1.75 4.97-4.32 7.5-4 4.05-9.58 6.07-16.77 6.07-5.93 0-11.16-1.7-15.7-5.11-4.52-3.42-6.8-8.96-6.8-16.64 0-7.21 2.05-12.73 6.14-16.57 4.1-3.84 9.41-5.76 15.95-5.76 3.87 0 7.36.65 10.48 1.94 3.1 1.3 5.67 3.35 7.69 6.16a19.7 19.7 0 0 1 3.55 8.59zm-11.7 1.08c-.22-2.89-1.26-5.07-3.12-6.56a10.62 10.62 0 0 0-6.9-2.25c-3 0-5.31.8-6.96 2.38-1.65 1.58-2.68 3.72-3.1 6.43H87.9z" fill="currentColor"/>'
  },
  birthday: {
    width: 15,
    height: 15,
    block: '<path d="M85.38 54.627c.552-2.842-1.998-5.285-4.234-6.833-5.017-3.472-13.095-5.84-22.052-6.862.011 12.293-.042 12.624-.06 12.752-.156.976-.969 2.735-4.682 3.546a16.731 16.731 0 0 1-3.515.357c-2.809 0-5.6-.632-7.209-1.744-1.264-.878-1.607-1.865-1.672-2.54-.053-.539-.057-6.446-.046-12.628-3.307.265-6.56.705-9.643 1.378-11.304 2.464-15.984 6.697-16.594 9.836-.554 2.844 1.997 4.9 4.234 6.448 9.934 6.872 31.86 9.447 48.88 5.74 11.302-2.463 15.982-6.31 16.592-9.45zm-.019 7.737c.028-.4.04-.556.044-1.322-3.548 2.607-8.452 4.713-14.425 6.17-19.157 4.677-44.002 1.31-55.443-7.502-.002 1.257.01 1.978.056 2.654.742 11.178 3.622 13.772 4.825 14.37 1.6.795 2.095.328 3.294-.796 1.12-1.05 2.815-2.644 5.56-1.834 1.755.514 3.24 2.248 4.96 4.254 1.698 1.984 3.623 4.233 5.302 4.458 1.44.194 2.9-1.194 4.446-2.657 1.784-1.688 3.805-3.6 6.475-3.6 2.717 0 4.75 1.916 6.545 3.61 1.548 1.46 3.01 2.84 4.419 2.647 1.677-.226 3.603-2.474 5.301-4.458 1.72-2.006 3.207-3.74 4.961-4.254 2.748-.806 4.526.789 5.704 1.845 1.34 1.204 1.785 1.519 3.1.81 2.806-1.509 4.471-8.317 4.876-14.395zM45.345 28.078c-.035 9.297-.065 22.928-.01 24.756.038.042.106.102.215.176 1.362.943 5.019 1.528 8.085.862 1.26-.275 1.861-.657 2.045-.834.035-1.547.016-15.645-.01-25.224a1.484 1.484 0 0 1-.015-.076 1.218 1.218 0 0 0-.193-.16c-1.366-.944-5.021-1.53-8.086-.862-1.16.252-1.758.595-1.988.785a1.7 1.7 0 0 1-.043.577zm43.51 25.159c.038 2.995.357 29.351-.094 32.214-.89 5.665-7.911 10.331-19.259 12.804C64.071 99.44 58.144 100 52.232 100c-13.472 0-26.88-2.913-34.244-8.01-3.53-2.441-5.466-5.177-5.754-8.132-.27-2.752-.263-10.44-.193-17.286.064-6.224.141-14.539.299-15.346 1.075-5.537 8.077-10.104 19.21-12.53 3.308-.722 6.807-1.185 10.367-1.454.01-3.919.023-7.561.031-9.586 0-.052.003-.105.008-.155a2.948 2.948 0 0 1 .412-1.657c.684-1.164 2.168-2.024 4.291-2.486 3.718-.81 8.43-.202 10.723 1.387.977.675 1.393 1.442 1.556 2.073.083.196.13.41.13.628.01 3.922.017 7.251.022 10.084 9.69 1.076 18.503 3.644 23.976 7.43 4.159 2.88 5.533 5.772 5.756 8.129.006.052.033.096.033.148zM50.503 5.269c-1.65 3.191-3.09 6.32-3.16 7.133.002 1.745 1.417 3.187 3.158 3.187 1.734 0 3.146-1.434 3.154-3.2-.072-.834-1.506-3.948-3.152-7.12zM50.501 19C46.915 19 44 16.027 44 12.372c0-2.038 3.159-8.081 5.042-11.503A1.666 1.666 0 0 1 50.498 0h.003a1.67 1.67 0 0 1 1.455.866C53.473 3.605 57 10.21 57 12.372 57 16.027 54.083 19 50.5 19z" fill="currentColor" fill-rule="evenodd"/>'
  },
  bold: {
    width: 15,
    height: 15,
    block: '<path d="M9.5 100V0h43.435c14.909 0 25.803 9.14 25.803 21.722 0 6.093-1.863 11.126-7.597 15.761C83.469 41.722 92.5 51.391 92.5 66.623 92.5 86.093 76.301 100 53.365 100H9.5zm20.642-56.954C37.167 40 44.334 36.821 51.215 32.98c4.874-2.781 6.738-5.298 6.738-8.477 0-3.84-2.868-6.755-7.741-6.755h-18.78c-.716 0-1.29.53-1.29 1.192v24.106zM31.72 81.59h21.503C64.547 81.59 72 75.1 72 66.093c0-8.477-6.45-15.63-17.346-15.63-5.59 0-13.761 3.842-24.513 9.537v20.265c0 .795.574 1.324 1.577 1.324z" fill="currentColor"/>'
  },
  book: {
    width: 15,
    height: 15,
    block: '<path d="M85.98 81.78L78.1 23.7a2.5 2.5 0 0 0-2.75-2.13L23.7 27.61c-1.1-.06-3.18-2.18-4.62-4.3v-.02L55.55 6.16l1.14 8.4a2.48 2.48 0 0 0 2.8 2.13 2.48 2.48 0 0 0 2.13-2.79l-1.6-11.75A2.48 2.48 0 0 0 58.74.3 2.5 2.5 0 0 0 56.5.24L16.76 18.9A3.93 3.93 0 0 0 14.1 22a5 5 0 0 0-.03 1.31 2.39 2.39 0 0 0-.05.89l7.72 56.88a9.55 9.55 0 0 0 3.8 6.62c1.42 1.05 3.71 2.12 7.16 2.12a19 19 0 0 0 2.52-.2c.35-.02.7-.06 1.05-.14l3.7-.39 1.19 8.75a2.49 2.49 0 0 0 2.8 2.13 2.48 2.48 0 0 0 2.13-2.79l-1.17-8.6 38.85-4.02a2.5 2.5 0 0 0 1.7-.93c.41-.53.6-1.2.5-1.87" fill="currentColor"/>'
  },
  bulb: {
    width: 15,
    height: 15,
    block: '<path d="M24.96 74.49a2.87 2.87 0 0 1 .22 4.05l-4.36 4.87a2.85 2.85 0 0 1-4.03.22 2.87 2.87 0 0 1-.22-4.04l4.36-4.88a2.85 2.85 0 0 1 4.03-.22zm57.61-64.42a2.87 2.87 0 0 1 .22 4.05L78.43 19a2.84 2.84 0 0 1-2.13.95c-.68 0-1.36-.24-1.9-.73a2.87 2.87 0 0 1-.22-4.05l4.36-4.88a2.85 2.85 0 0 1 4.03-.22zM16.8 21.44a2.88 2.88 0 0 1-.25-4.05 2.85 2.85 0 0 1 4.04-.24l4.36 3.88a2.87 2.87 0 0 1 .24 4.05 2.84 2.84 0 0 1-2.14.96 2.84 2.84 0 0 1-1.89-.72l-4.36-3.88zm65.52 51.1a2.51 2.51 0 0 1 .22 3.54 2.49 2.49 0 0 1-3.53.21l-4.36-3.88a2.51 2.51 0 0 1-.22-3.54 2.5 2.5 0 0 1 3.53-.22l4.36 3.89zM46.82 9.06v-6.2A2.86 2.86 0 0 1 49.68 0a2.86 2.86 0 0 1 2.85 2.87v6.2a2.86 2.86 0 0 1-2.85 2.86 2.86 2.86 0 0 1-2.86-2.87zM14.87 50.83a2.86 2.86 0 0 1-2.52 3.18l-6.17.7a2.86 2.86 0 0 1-3.16-2.52 2.86 2.86 0 0 1 2.51-3.17l6.18-.7a2.86 2.86 0 0 1 3.16 2.51zm78.92-6.5l-6.18.7a2.5 2.5 0 0 1-2.76-2.2 2.5 2.5 0 0 1 2.2-2.77l6.17-.7a2.5 2.5 0 0 1 2.76 2.2 2.5 2.5 0 0 1-2.2 2.77zm-26.63 4.54a2.5 2.5 0 0 1-2.5 2.5 2.5 2.5 0 0 1-2.5-2.5c0-3.58-1.52-7-4.18-9.4a12.47 12.47 0 0 0-9.82-3.13 2.48 2.48 0 0 1-2.76-2.22 2.5 2.5 0 0 1 2.2-2.77c5-.55 10 1.05 13.7 4.39a17.69 17.69 0 0 1 5.86 13.13zM61.28 67.4a7.07 7.07 0 0 0-3.5 6.08v2.13l-.13.17-.05.05a3.14 3.14 0 0 1-.22.22l-.17.15-.1.08-.23.19a1.73 1.73 0 0 1-.08.06l-.38.24-.12.07-.33.18a9.48 9.48 0 0 1-1.18.49 5.3 5.3 0 0 1-.9.26l-.14.03-.66.14-.3.05a13.66 13.66 0 0 1-.95.13l-.7.06-.33.02a21.67 21.67 0 0 1-2.25 0l-.34-.02a18.62 18.62 0 0 1-.69-.06l-.35-.04a15.82 15.82 0 0 1-1.47-.25l-.23-.06c-.26-.06-.5-.12-.72-.2a8.59 8.59 0 0 1-.8-.29 9.46 9.46 0 0 1-.37-.16 19.9 19.9 0 0 1-.18-.09 6.31 6.31 0 0 1-.45-.24 6.42 6.42 0 0 1-.3-.19 5.31 5.31 0 0 1-.67-.52l-.05-.05a4.1 4.1 0 0 1-.16-.15l-.04-.05a3.96 3.96 0 0 1-.12-.14l-.02-.02a.84.84 0 0 0-.03-.04v-2.15c0-2.5-1.3-4.77-3.5-6.08a22.8 22.8 0 0 1-10.72-23.27 22.27 22.27 0 0 1 19.74-18.8 22.4 22.4 0 0 1 17.68 5.64A22.8 22.8 0 0 1 72.3 47.9c0 8.06-4.13 15.35-11.03 19.5zm-19.1 14.58c.33.13.67.26 1.04.38l.2.05c.33.1.66.2 1.02.27l.32.08c.42.09.87.17 1.34.24l.15.02c.43.06.88.1 1.35.14l.41.03a29.37 29.37 0 0 0 3.34 0l.41-.03c.47-.04.92-.08 1.34-.14l.16-.02c.47-.07.92-.15 1.34-.24l.32-.08 1.01-.26.2-.06a13.88 13.88 0 0 0 1.3-.48l.36-.15v4.17c-.56.73-2.55 2.62-8.11 2.62-5.57 0-7.55-1.9-8.1-2.62v-4.17l.36.15.24.1zM68.1 27.23a27.7 27.7 0 0 0-21.56-6.89 27.22 27.22 0 0 0-24.12 23 27.8 27.8 0 0 0 13.1 28.36 2.1 2.1 0 0 1 1.06 1.78v13.08c0 .29.05.58.14.85.14.4 1.09 2.7 4.35 4.36.23 4.58 4 8.23 8.6 8.23a8.65 8.65 0 0 0 8.62-8.23c3.26-1.66 4.2-3.97 4.35-4.36.1-.27.14-.56.14-.85V73.48c0-.71.4-1.38 1.06-1.78A27.9 27.9 0 0 0 77.3 47.9a27.82 27.82 0 0 0-9.2-20.66z" fill="currentColor"/>'
  },
  bulk: {
    width: 15,
    height: 15,
    block: '<path d="M32.284 94.139V60.928l25.038-2.878-5.183 5.825a4.767 4.767 0 0 0 .357 6.692 4.672 4.672 0 0 0 6.635-.362l13.448-15.11c.031-.036.053-.078.083-.114.103-.121.19-.253.28-.385.085-.123.17-.243.24-.373.076-.137.134-.281.197-.425.058-.137.12-.273.168-.415.045-.149.075-.303.11-.457.029-.15.067-.298.084-.451.015-.15.014-.302.017-.455.003-.122.023-.239.016-.36-.003-.048-.018-.092-.022-.136-.003-.044.003-.087-.002-.131-.01-.108-.048-.207-.067-.311-.03-.165-.058-.329-.105-.487-.042-.148-.099-.286-.155-.426-.061-.15-.12-.296-.193-.438a4.138 4.138 0 0 0-.222-.366 4.643 4.643 0 0 0-.288-.414c-.08-.1-.17-.188-.259-.281-.089-.095-.164-.2-.263-.288l-13.45-12.019a4.67 4.67 0 0 0-6.63.405 4.767 4.767 0 0 0 .401 6.688l5.56 4.97-25.795 2.964V10.652l41.717-4.795v17.6c0 .786.333 1.536.916 2.06a2.722 2.722 0 0 0 2.134.685l17.468-2.006v62.791L32.284 94.14zm58.557-75.086L79.48 20.36V8.902l11.36 10.151zm9.068 1.371c-.015-.061-.039-.118-.06-.178a2.794 2.794 0 0 0-.21-.493c-.035-.059-.065-.117-.103-.174a2.691 2.691 0 0 0-.46-.55L78.56.693a2.703 2.703 0 0 0-.601-.397 2.484 2.484 0 0 0-.165-.072 2.73 2.73 0 0 0-.543-.165c-.049-.009-.097-.023-.147-.03a2.68 2.68 0 0 0-.672-.014L29.234 5.44a2.755 2.755 0 0 0-2.43 2.746V52.02l-22.639 2.6C1.59 54.918-.262 57.265.03 59.865c.273 2.418 2.306 4.202 4.662 4.202.177 0 .357-.01.539-.031l21.572-2.478v35.678c0 .787.334 1.538.916 2.063a2.729 2.729 0 0 0 2.135.684L97.57 92.2a2.756 2.756 0 0 0 2.43-2.747V21.097c0-.23-.036-.453-.09-.673z" fill="currentColor" fill-rule="evenodd"/>'
  },
  calcul: {
    width: 15,
    height: 15,
    block: '<path d="M89.36 6l-36.54 4.18v36.65l36.54-4.18V6zM83.3 61.86a2.82 2.82 0 0 0-3.12-2.49l-18.82 2.15a2.83 2.83 0 0 0-2.48 3.13 2.82 2.82 0 0 0 3.12 2.5l18.82-2.16a2.82 2.82 0 0 0 2.48-3.13zm0 10.98a2.82 2.82 0 0 0-3.12-2.5L61.36 72.5a2.83 2.83 0 0 0-2.48 3.13 2.82 2.82 0 0 0 3.12 2.5l18.82-2.16a2.82 2.82 0 0 0 2.48-3.13zM47.18 10.82L10.63 15v36.65l36.55-4.18V10.82zm0 42.35l-36.55 4.18V94l36.55-4.18V53.17zM95 2.83v84.69a2.82 2.82 0 0 1-2.5 2.81l-42.18 4.83-42.18 4.82a2.8 2.8 0 0 1-2.2-.7A2.83 2.83 0 0 1 5 97.17v-84.7a2.83 2.83 0 0 1 2.5-2.8L91.86.02A2.82 2.82 0 0 1 95 2.82zm-74.63 80.3a2.8 2.8 0 0 0 3.98-.22l4.79-5.34 4.55 4.05a2.81 2.81 0 0 0 3.98-.24 2.84 2.84 0 0 0-.24-4l-4.53-4.02 4.76-5.32a2.83 2.83 0 0 0-.22-4 2.81 2.81 0 0 0-3.98.22l-4.78 5.34-4.55-4.05a2.81 2.81 0 0 0-3.98.24 2.83 2.83 0 0 0 .24 4l4.53 4.02-4.76 5.32a2.84 2.84 0 0 0 .21 4zm42.26-52.92c.1 0 .21 0 .32-.02l5.32-.6v5.32a2.82 2.82 0 0 0 2.82 2.82 2.82 2.82 0 0 0 2.82-2.82v-5.97l5.96-.68a2.82 2.82 0 0 0 2.48-3.13 2.82 2.82 0 0 0-3.12-2.5l-5.32.61v-5.32a2.82 2.82 0 0 0-2.82-2.83 2.82 2.82 0 0 0-2.82 2.83v5.97l-5.96.68a2.83 2.83 0 0 0-2.48 3.13 2.82 2.82 0 0 0 2.8 2.51zm-44.5 2.26a2.83 2.83 0 0 1 2.48-3.13l15.96-1.82A2.82 2.82 0 0 1 39.69 30a2.83 2.83 0 0 1-2.48 3.13l-15.96 1.82a2.82 2.82 0 0 1-3.12-2.49z" fill="currentColor"/>'
  },
  camera: {
    width: 15,
    height: 15,
    block: '<path d="M94.42 36.8v-9.73l-15.76 2.05v9.74l15.77-2.05zM58.46 75.84c10.27-1.17 18.6-10.42 18.6-20.65 0-10.24-8.33-17.6-18.6-16.43-10.27 1.17-18.6 10.41-18.6 20.65 0 10.24 8.33 17.6 18.6 16.43zM27.44 30.62l8.29-1.08-11.11-7.76-15.15 1.97 11.11 7.76 6.86-.9zM17.35 84.16V35.52l-12.2-8.53v48.5l12.2 8.67zM78.99 14.7l-46.81 6.1 11.1 7.76 46.82-6.1-11.11-7.76zm20.57 9.35l.01.1V79.1a2.57 2.57 0 0 1-2.24 2.54L20.26 91.69l-.33.02c-.24 0-.48-.04-.7-.1l-.12-.04a2.64 2.64 0 0 1-.62-.3l-.06-.03L1.08 78.9A2.56 2.56 0 0 1 0 76.8V22.07c0-.13.03-.26.06-.4 0-.07 0-.14.02-.2l.01-.04c.06-.24.15-.46.28-.66v-.02c.13-.21.29-.4.47-.56.06-.06.14-.1.2-.15.12-.08.22-.17.34-.24l.07-.02.26-.1c.15-.05.3-.1.45-.12l.08-.03L79.32 9.5a2.58 2.58 0 0 1 1.8.44l17.36 12.12.07.07.15.1.28.3.07.08c.14.18.24.38.33.59l.05.17c.05.17.1.34.11.51l.02.18zm-41.1 19.66C66 42.85 72.1 48.24 72.1 55.74S66 70.02 58.46 70.87c-7.53.86-13.63-4.53-13.63-12.03 0-7.5 6.1-14.28 13.63-15.13zm3.65 14.2a5.19 5.19 0 0 0 4.52-5.02 3.95 3.95 0 0 0-4.52-3.99c-2.5.29-4.51 2.53-4.51 5.02s2.02 4.27 4.51 3.99z" fill="currentColor"/>'
  },
  candidate_status: {
    width: 15,
    height: 15,
    block: '<path d="M54 73.56c-1.15-5-5.04-8.54-10.16-9.24a2.41 2.41 0 0 1-.65-4.6c4.42-1.97 7.39-6.4 7.39-11.01a9.01 9.01 0 0 0-2.94-6.85 9 9 0 0 0-6.06-2.24c-.4 0-.8.03-1.21.07-5.93.68-10.75 6.04-10.75 11.95 0 4.39 2.78 7.95 6.91 8.86a2.41 2.41 0 0 1 .31 4.62c-5 1.83-9 6.15-10.44 11.26a.9.9 0 0 0 .2.85.9.9 0 0 0 .8.32l25.79-2.93a.96.96 0 0 0 .68-.4.8.8 0 0 0 .14-.66zm-4.26-12.43c4.48 2.2 7.8 6.28 8.98 11.34a5.65 5.65 0 0 1-.9 4.53 5.82 5.82 0 0 1-4.08 2.42l-25.78 2.93a5.76 5.76 0 0 1-5.05-1.99 5.74 5.74 0 0 1-1.16-5.28 22 22 0 0 1 8.73-12.06 13.7 13.7 0 0 1-5.7-11.38c0-8.29 6.75-15.8 15.04-16.75 4.16-.47 8.07.72 11.03 3.36a13.78 13.78 0 0 1 4.56 10.46c0 4.69-2.15 9.23-5.67 12.42zm37.63-43.41a2.42 2.42 0 0 0-3.6-3.23l-10.3 11.49-5.23-4.63a2.42 2.42 0 0 0-3.41.2 2.41 2.41 0 0 0 .2 3.41l7.03 6.22a2.41 2.41 0 0 0 3.4-.19l11.92-13.27zm-14.51 69.7V42.96a19.01 19.01 0 0 1-11.83-4.76 19.1 19.1 0 0 1-6.3-14.15l-47.4 5.4v65.43l65.53-7.46zM91.18 4.8a19.16 19.16 0 0 1 6.32 14.54c0 11.2-8.78 21.37-19.8 23.3v46.94c0 1.22-.93 2.26-2.15 2.4l-70.36 8a2.42 2.42 0 0 1-1.88-.6 2.42 2.42 0 0 1-.81-1.8V27.3c0-1.23.92-2.26 2.14-2.4l50.55-5.75C57.25 9.4 65.72 1.29 75.83.14c5.79-.65 11.23 1 15.35 4.66z" fill="currentColor"/>'
  },
  celebrate: {
    width: 15,
    height: 15,
    block: '<path d="M74.886 60.726a3.944 3.944 0 0 1-.808.712l-.1.064c-2.368 1.537-7.523 2.117-16.014-.312-2.909-.832-5.887-1.953-8.832-3.27 1.792-.452 3.336-1.36 4.324-3.136 2.198-3.953-.743-7.837-3.337-11.265-2.514-3.322-4.086-5.638-3.065-7.474.62-1.116 1.927-1.537 3.799-1.646 5.3 2.692 10.333 5.968 14.48 9.411l-4.456 4.358a1.74 1.74 0 0 0 .003 2.503 1.83 1.83 0 0 0 1.28.517c.465 0 .929-.173 1.283-.52l4.578-4.478c2.822 2.66 5.06 5.351 6.386 7.882 1.067 2.034 2.017 4.841.479 6.654zM56.194 72.664a46.084 46.084 0 0 1-5.547-1.383C39.49 67.791 27.32 60.289 20.782 53.258l.042-11.987c4.223 5.8 11.731 11.854 20.233 16.582.108.072.212.137.334.187 5.019 2.761 10.357 5.06 15.554 6.546 3.458.99 6.608 1.537 9.41 1.7l-10.161 6.378zm-18.149 11.39c-6.094-2.42-12.212-5.822-17.337-9.518l.035-10.11c6.833 5.666 16.461 11.07 25.433 13.875.242.077.469.136.706.207l-8.837 5.546zm-17.41 10.928l.038-10.46a84.376 84.376 0 0 0 8.939 4.827l-8.977 5.633zm.968-65.067c1.018-1.199 3.255-2.109 6.88-2.109.637 0 1.319.031 2.042.09v10.338c0 .978.81 1.769 1.813 1.769 1 0 1.812-.791 1.812-1.77v-9.811c1.356.256 2.789.576 4.374 1.029 2.454.702 4.958 1.618 7.45 2.675a6.037 6.037 0 0 0-2.106 2.23c-2.199 3.954.74 7.838 3.336 11.266 2.515 3.322 4.087 5.638 3.064 7.472-.974 1.757-3.63 1.809-7.556 1.587-9.352-5.227-17.49-12.12-20.632-18.11-1.066-2.036-2.014-4.841-.477-6.656zM70.58 43.687L83.47 31.08a1.74 1.74 0 0 0-.003-2.503 1.845 1.845 0 0 0-2.564.003L67.905 41.295c-2.793-2.347-5.96-4.604-9.345-6.678 3.298-.006 6.446-.597 8.079-3.533 2.2-3.954-.741-7.838-3.334-11.267-2.516-3.324-4.088-5.64-3.066-7.477.862-1.546 3.1-1.615 6.674-1.574.507.008 1.018.015 1.528.015 1.002 0 1.813-.792 1.813-1.769 0-.978-.81-1.77-1.813-1.77-.493 0-.986-.006-1.473-.013-3.727-.061-7.945-.116-9.914 3.422-2.199 3.955.74 7.84 3.335 11.268 2.514 3.324 4.086 5.638 3.064 7.475-1.02 1.837-3.866 1.81-8.09 1.56-1.2-.07-2.44-.142-3.659-.127-3.995-1.97-8.122-3.615-12.16-4.77a51.111 51.111 0 0 0-5.394-1.249V1.77c0-.979-.812-1.77-1.812-1.77-1.002 0-1.813.791-1.813 1.77v22.597c-5.43-.388-9.534.719-11.715 3.292-1.005 1.186-1.877 3.008-1.584 5.622L17 98.225c0 .052.025.098.029.147.009.12.035.23.07.346.036.117.075.226.134.334.024.044.027.093.054.136.055.082.125.148.192.22.026.03.046.061.075.09.148.14.318.247.499.33.04.018.084.03.127.047.198.073.402.12.614.122.004 0 .007.003.011.003h.009c.21 0 .42-.05.622-.123.061-.02.115-.048.173-.077.06-.028.124-.043.184-.08l56.093-35.208c.054-.034.106-.065.157-.1l.091-.057c.023-.014.035-.038.058-.054a7.643 7.643 0 0 0 1.486-1.319c1.543-1.819 2.789-5.12-.043-10.522-1.495-2.85-3.962-5.843-7.055-8.773z" fill="currentColor" fill-rule="evenodd"/>'
  },
  check: {
    width: 15,
    height: 15,
    block: '<path d="M98.139 9.433a5.606 5.606 0 0 0-7.915.428L28.537 78.516 9.322 61.508a5.609 5.609 0 0 0-7.913.476 5.599 5.599 0 0 0 .479 7.906l23.383 20.7A5.589 5.589 0 0 0 28.985 92c1.538 0 3.068-.63 4.174-1.861L98.567 17.34a5.597 5.597 0 0 0-.428-7.908" fill="currentColor" fill-rule="evenodd"/>'
  },
  chevron: {
    width: 15,
    height: 15,
    block: '<path d="M42.73 76.06l10.62-34.94a2.88 2.88 0 0 1 3.62-1.95 2.98 2.98 0 0 1 1.9 3.7L48.24 77.84a2.9 2.9 0 0 1-3.61 1.94 2.98 2.98 0 0 1-1.9-3.7zm20.48-8.69l9.35-10.68-9.12-8.28a3.01 3.01 0 0 1-.24-4.18 2.84 2.84 0 0 1 4.07-.25l11.3 10.26c.57.52.92 1.26.96 2.04a3.01 3.01 0 0 1-.73 2.15l-11.3 12.9a2.84 2.84 0 0 1-4.07.22 3 3 0 0 1-.22-4.18zm-40.48-2.63a2.99 2.99 0 0 1-.97-2.05 3 3 0 0 1 .73-2.14l11.3-12.9a2.84 2.84 0 0 1 4.07-.22 3.01 3.01 0 0 1 .22 4.18l-9.35 10.68 9.11 8.28a3.01 3.01 0 0 1 .25 4.18 2.85 2.85 0 0 1-4.07.25l-11.3-10.26zm71.5 18.77L6.77 93.73V35.5l87.46-10.2v58.2zm-81.9-64.56a3.03 3.03 0 0 1 .5-.42c.18-.12.38-.24.57-.32.2-.09.4-.14.61-.2a3.28 3.28 0 0 1 1.29 0c.21.06.43.11.63.2a3.81 3.81 0 0 1 1.48 1.25 3.7 3.7 0 0 1 .55 1.87 3 3 0 0 1-.07.66 3.5 3.5 0 0 1-.48 1.22 4.3 4.3 0 0 1-.41.5c-.17.18-.33.31-.51.43a2.74 2.74 0 0 1-1.2.5 2.79 2.79 0 0 1-1.28 0 2.58 2.58 0 0 1-.6-.18 2.82 2.82 0 0 1-.58-.32 2.38 2.38 0 0 1-.5-.42 3.44 3.44 0 0 1-.97-2.39c0-.88.36-1.75.97-2.38zm14.23-1.7c.15-.16.32-.3.5-.43a3.8 3.8 0 0 1 1.19-.5 2.75 2.75 0 0 1 1.28 0 3.73 3.73 0 0 1 1.7.91 3.49 3.49 0 0 1 0 4.8 3.3 3.3 0 0 1-2.34 1 3.3 3.3 0 0 1-2.33-1 3.4 3.4 0 0 1-.97-2.39c0-.9.35-1.76.97-2.4zM96.02 3.1a11.92 11.92 0 0 0-9.6-3.01l-72.5 8.47C6.8 9.39 1 16.02 1 23.33v73.71a3 3 0 0 0 .96 2.2 2.84 2.84 0 0 0 2.25.74L97.44 89.1a2.94 2.94 0 0 0 2.56-2.94v-73.7c0-3.69-1.41-7-3.98-9.35z" fill="currentColor"/>'
  },
  code: {
    width: 15,
    height: 15,
    block: '<path d="M29.028 61.293l.21.181a5.806 5.806 0 0 1 0 8.499c-2.404 2.274-6.254 2.274-8.447.181L1.819 55.249C.543 54.039-.083 52.387.01 51.007c-.092-1.693.534-3.346 2.022-4.738l18.55-14.541c2.403-2.274 6.253-2.274 8.657 0 2.466 2.333 2.466 6.165-.21 8.68L15.724 50.85l13.304 10.443zM75.61 16.314L36.39 89.677c-1.64 2.705-4.405 3.352-7.705 2.425-3.703-1.042-4.751-5.399-2.988-8.299l39.22-73.362c1.706-2.815 5.43-3.767 8.346-2.164 2.976 1.63 4.01 5.305 2.347 8.037zm-4.848 23.91a5.806 5.806 0 0 1 0-8.5c2.403-2.273 6.253-2.273 8.447-.18L97.966 46.27l.211.182c1.275 1.209 1.906 2.862 1.814 4.238.092 1.693-.534 3.346-2.022 4.739L79.419 69.97c-2.403 2.274-6.253 2.274-8.656 0-2.467-2.334-2.467-6.165.21-8.68l13.305-10.444-13.515-10.622z" fill="currentColor"/>'
  },
  coffee: {
    width: 15,
    height: 15,
    block: '<path d="M52.29 16.16a2.55 2.55 0 0 1 .73-3.53 2.53 2.53 0 0 1 3.51.73l.7 1.06a11.46 11.46 0 0 1 1.08 10.43l-1.22 3.11a2.54 2.54 0 0 1-3.29 1.44 2.55 2.55 0 0 1-1.43-3.3l1.21-3.1a6.35 6.35 0 0 0-.6-5.78l-.7-1.06zm-27.57 0a2.55 2.55 0 0 1 .73-3.53 2.53 2.53 0 0 1 3.52.73l.7 1.06a11.47 11.47 0 0 1 1.08 10.43l-1.22 3.11a2.54 2.54 0 0 1-3.29 1.44 2.55 2.55 0 0 1-1.44-3.3l1.22-3.1a6.35 6.35 0 0 0-.6-5.78l-.7-1.06zm14.05-1.28a11.45 11.45 0 0 1-1-10.62l1.1-2.68A2.54 2.54 0 0 1 42.18.19a2.55 2.55 0 0 1 1.38 3.33l-1.1 2.69a6.34 6.34 0 0 0 .56 5.87l.7 1.06a11.47 11.47 0 0 1 1.07 10.44l-1.2 3.1a2.54 2.54 0 0 1-3.3 1.45 2.55 2.55 0 0 1-1.44-3.3l1.22-3.11a6.35 6.35 0 0 0-.6-5.78l-.7-1.06zm36.26 62.09a35.74 35.74 0 0 0 2.37-12.8V53.11a12.07 12.07 0 0 1-2.37 23.85zM41.7 94.9a30.71 30.71 0 0 1-30.62-30.74v-7.29a24.24 24.24 0 0 0 3.02 1.84l.31.16a37.02 37.02 0 0 0 1.7.8h.03c5.75 2.52 13.49 4.1 21.97 4.45l.65.02c.33.01.66.03 1 .03.64.02 1.3.03 1.94.03a86.8 86.8 0 0 0 1.95-.03l.99-.03.64-.02c8.5-.35 16.23-1.93 21.98-4.44l.03-.02a33.89 33.89 0 0 0 1.7-.8l.3-.15a24.31 24.31 0 0 0 3.03-1.84v7.3A30.71 30.71 0 0 1 41.7 94.9zm0-56.95c18.97 0 30.62 6.16 30.62 10.57 0 1.1-.72 2.29-2.07 3.47-6.59-3.78-17.05-6.02-28.55-6.02S19.74 48.21 13.15 52c-1.35-1.18-2.07-2.38-2.07-3.47 0-4.41 11.65-10.57 30.62-10.57zm35.66 10c-.67-9.81-18.68-15.1-35.66-15.1-17.3 0-35.7 5.5-35.7 15.68v15.64A35.8 35.8 0 0 0 41.7 100a35.69 35.69 0 0 0 30.9-17.93h2.3a17.15 17.15 0 0 0 2.46-34.12z" fill="currentColor"/>'
  },
  collapse: {
    width: 15,
    height: 15,
    block: '<path d="M93.873 81.467a3.364 3.364 0 0 1 .758 6.684l-50.98 5.826a3.355 3.355 0 0 1-3.71-2.96 3.357 3.357 0 0 1 2.952-3.723l50.98-5.827zm0-29.226a3.36 3.36 0 0 1 3.71 2.962 3.362 3.362 0 0 1-2.952 3.723l-50.98 5.826a3.355 3.355 0 0 1-3.71-2.96 3.357 3.357 0 0 1 2.952-3.723l50.98-5.828zm6.09-28.874c.358 3.164-1.907 6.022-5.06 6.383l-75.697 8.651 10.365 9.214a5.78 5.78 0 0 1 .49 8.14 5.721 5.721 0 0 1-4.302 1.943 5.723 5.723 0 0 1-3.811-1.451L1.931 38.455a5.61 5.61 0 0 1-.745-.807c-.064-.083-.11-.177-.17-.262a5.401 5.401 0 0 1-.403-.663c-.062-.121-.104-.25-.157-.375a6.107 6.107 0 0 1-.234-.638c-.044-.157-.07-.319-.1-.48-.028-.148-.074-.289-.092-.44-.005-.052.002-.104-.002-.158-.005-.056-.023-.11-.026-.165-.008-.148.015-.292.019-.439.004-.186.002-.372.023-.555.02-.186.063-.365.103-.548.04-.188.075-.375.136-.555.056-.175.13-.339.201-.506.075-.175.148-.351.242-.519.086-.157.191-.301.291-.451.111-.162.22-.321.347-.471.036-.044.06-.094.1-.137L21.481 7.914a5.733 5.733 0 0 1 8.116-.438 5.777 5.777 0 0 1 .439 8.141L20.13 26.688l73.472-8.397c3.146-.371 6.002 1.912 6.36 5.076z" fill="currentColor" fill-rule="evenodd"/>'
  },
  comment: {
    width: 15,
    height: 15,
    block: '<path d="M77.174 32.866l-53.426 6.07a4.048 4.048 0 0 1-4.487-3.558 4.043 4.043 0 0 1 3.57-4.472l53.425-6.07a4.047 4.047 0 0 1 4.487 3.559 4.043 4.043 0 0 1-3.57 4.47m0 21.77l-53.425 6.069a4.05 4.05 0 0 1-4.487-3.556 4.044 4.044 0 0 1 3.57-4.473l53.425-6.068a4.046 4.046 0 0 1 4.487 3.558 4.041 4.041 0 0 1-3.57 4.47M96.315.897a3.53 3.53 0 0 0-2.762-.875L5.645 10.008A3.54 3.54 0 0 0 2.5 13.522v69.704a3.53 3.53 0 0 0 1.186 2.637 3.53 3.53 0 0 0 2.764.877l26.519-3.013L47.43 98.9a3.556 3.556 0 0 0 2.572 1.1c.057 0 .114-.002.172-.004a3.556 3.556 0 0 0 2.623-1.356L67.56 79.797l26.797-3.043A3.541 3.541 0 0 0 97.5 73.24V3.535A3.531 3.531 0 0 0 96.314.898" fill="currentColor" fill-rule="evenodd"/>'
  },
  comment_outline: {
    width: 15,
    height: 15,
    block: '<path d="M90.407 70.085V7.497l-80.814 9.18v62.587l24.327-2.762a3.55 3.55 0 0 1 2.973 1.077l12.845 13.476 13.146-16.78a3.544 3.544 0 0 1 2.393-1.335l25.13-2.855zM96.314.898A3.531 3.531 0 0 1 97.5 3.535V73.24a3.54 3.54 0 0 1-3.145 3.513l-26.796 3.043L52.794 98.64a3.553 3.553 0 0 1-2.623 1.356 3.556 3.556 0 0 1-2.742-1.097L32.968 83.727 6.448 86.74a3.529 3.529 0 0 1-2.762-.875A3.532 3.532 0 0 1 2.5 83.226V13.522a3.54 3.54 0 0 1 3.145-3.514L93.552.023a3.537 3.537 0 0 1 2.762.875zM23.282 39.44a3.54 3.54 0 0 1-3.518-3.136 3.537 3.537 0 0 1 3.121-3.914l53.427-6.07c1.945-.211 3.702 1.173 3.925 3.114a3.54 3.54 0 0 1-3.123 3.914l-53.426 6.07a3.923 3.923 0 0 1-.406.022zm0 20.786a3.54 3.54 0 0 1-3.518-3.136 3.537 3.537 0 0 1 3.121-3.913l53.427-6.07c1.945-.214 3.702 1.172 3.925 3.114a3.54 3.54 0 0 1-3.123 3.914l-53.426 6.069a3.923 3.923 0 0 1-.406.022z" fill="currentColor" fill-rule="evenodd"/>'
  },
  compass: {
    width: 15,
    height: 15,
    block: '<path d="M74.05 83.92l-4.97-5.2-14.1-34.75a18.63 18.63 0 0 0 4.75-3.67L74.1 75.73l-.05 8.2zM48.57 35.9a5.36 5.36 0 0 1-6.12-5.44c0-3.4 2.74-6.46 6.12-6.85a5.36 5.36 0 0 1 6.12 5.45c0 3.39-2.74 6.45-6.12 6.84zm-20.1 43.29a6.3 6.3 0 0 1-1.82-2.33 7.89 7.89 0 0 1 .05-6.29l11.46-27.44a14.19 14.19 0 0 0 4.43 2.24L28.47 79.18zm50.52-4a2.37 2.37 0 0 0-.04-.38l-.09-.33-.04-.13v-.02L63.03 35.44a17.06 17.06 0 0 0 1.66-7.26c0-4.36-1.7-8.28-4.79-11.05a14.24 14.24 0 0 0-6.39-3.27l2.26-10.9a2.46 2.46 0 0 0-.6-2.16A2.44 2.44 0 0 0 53.1.01l-9.62 1.1a2.44 2.44 0 0 0-1.7 1 2.46 2.46 0 0 0-.42 1.92l2.14 10.84c-6.4 2.78-11.07 9.34-11.07 16.44 0 2.85.74 5.5 2.1 7.78L22.19 68.67a12.82 12.82 0 0 0 .02 10.22 11.1 11.1 0 0 0 4.34 4.9l-5.35 12.8a2.46 2.46 0 0 0 2.26 3.41c.96 0 1.86-.57 2.26-1.5l6.25-14.97 15.68-37.55c.4-.02.8-.02 1.2-.07a16.31 16.31 0 0 0 1.54-.25L64.72 81c0 .02.02.03.03.05.08.18.18.35.3.5l.1.14.07.08 9.47 9.91a2.45 2.45 0 0 0 2.68.58A2.46 2.46 0 0 0 78.91 90L79 75.3v-.03l-.01-.1z" fill="currentColor"/>'
  },
  computer: {
    width: 15,
    height: 15,
    block: '<path d="M91.5 65.42L9.5 76.2V16.7l82-10.77v59.5zM96.06.7A2.73 2.73 0 0 0 93.9.02L6.4 11.52A2.76 2.76 0 0 0 4 14.24v65.09c0 .8.34 1.55.94 2.08a2.74 2.74 0 0 0 2.17.66l29.95-3.93v14.4L22.32 94.5a2.76 2.76 0 0 0-2.37 3.1 2.76 2.76 0 0 0 3.09 2.39l55.64-7.3a2.76 2.76 0 0 0 2.37-3.1 2.76 2.76 0 0 0-3.09-2.4l-15.53 2.05V74.82l32.18-4.23A2.76 2.76 0 0 0 97 67.85V2.77a2.77 2.77 0 0 0-.94-2.08z" fill="currentColor"/>'
  },
  cover_letter: {
    width: 15,
    height: 15,
    block: '<path d="M15.99 93.63l68.02-7.77V28.04l-21.04 2.4a2.98 2.98 0 0 1-2.33-.74 3.01 3.01 0 0 1-1-2.25V6.37l-43.65 4.99v82.27zm64-71.19L65.63 9.68v14.4l14.36-1.63zm9.91 1.5a3 3 0 0 1 .1.73v63.86a3 3 0 0 1-2.66 2.99l-74 8.46a2.99 2.99 0 0 1-2.34-.74c-.64-.57-1-1.39-1-2.25V8.68a3 3 0 0 1 2.66-2.99L62.29.02c.25-.03.5-.02.74.01.05 0 .1.03.16.04.2.03.4.1.59.17l.19.08c.23.12.45.26.65.43l24.37 21.67a3.08 3.08 0 0 1 .85 1.32l.06.2zM28.29 34.25a3 3 0 0 1-2.97-2.66 3 3 0 0 1 2.63-3.33l18.09-2.06a3 3 0 0 1 3.31 2.64 3 3 0 0 1-2.63 3.32l-18.09 2.07-.34.02zm43.55 8.97a2.99 2.99 0 0 1 3.32 2.64 3 3 0 0 1-2.64 3.33l-44.01 5.03a3 3 0 0 1-3.32-2.64 3 3 0 0 1 2.64-3.33l44.01-5.03zm0 19.02a2.99 2.99 0 0 1 3.32 2.64 3 3 0 0 1-2.64 3.33l-44.01 5.03a3 3 0 0 1-3.32-2.65 3 3 0 0 1 2.64-3.32l44.01-5.03z" fill="currentColor"/>'
  },
  create: {
    width: 15,
    height: 15,
    block: '<path d="M82.55 23.87l-8.43.96v8.44a2.52 2.52 0 0 1-2.52 2.53 2.52 2.52 0 0 1-2.51-2.53v-7.86l-7.86.9a2.52 2.52 0 0 1-2.8-2.23 2.52 2.52 0 0 1 2.22-2.79l8.44-.96v-8.44a2.52 2.52 0 0 1 2.51-2.52 2.52 2.52 0 0 1 2.52 2.52v7.86l7.86-.9a2.52 2.52 0 0 1 2.8 2.23 2.52 2.52 0 0 1-2.23 2.8zm-32.92 41.7c-.28.42-.42.9-.42 1.4v19.66l-8.33 5.95v-24.9a2.54 2.54 0 0 0-.52-1.54L13.23 30.78l36.07-4.12c.42 5.3 2.7 10.03 6.53 13.46a19.57 19.57 0 0 0 7.82 4.27L49.63 65.57zM87.38 5.04C83.08 1.2 77.37-.54 71.32.14 60.24 1.42 51.06 10.7 49.48 21.57l-41.25 4.7A2.52 2.52 0 0 0 6.2 27.8a2.53 2.53 0 0 0 .32 2.52l29.32 38.23v28.94c0 .94.53 1.8 1.37 2.24a2.51 2.51 0 0 0 2.61-.19L53.2 90a2.53 2.53 0 0 0 1.06-2.05V67.73L69.2 45.16h.12c.85 0 1.71-.05 2.58-.15C84.1 43.62 94 32.54 94 20.31c0-6.03-2.35-11.45-6.62-15.27z" fill="currentColor"/>'
  },
  cross: {
    width: 15,
    height: 15,
    block: '<path d="M49.42 39.78L82.87 2.42a7.22 7.22 0 0 1 10.22-.56 7.28 7.28 0 0 1 .56 10.26l-33.39 37.3 32.8 29.14c3 2.66 3.27 7.25.62 10.25a7.23 7.23 0 0 1-10.23.62l-32.87-29.2-33.45 37.36a7.22 7.22 0 0 1-5.39 2.41 7.18 7.18 0 0 1-4.83-1.86 7.28 7.28 0 0 1-.56-10.26l33.39-37.3-32.8-29.13a7.29 7.29 0 0 1-.62-10.26 7.23 7.23 0 0 1 10.23-.61l32.87 29.2z" fill="currentColor"/>'
  },
  cross_target: {
    width: 15,
    height: 15,
    block: '<path d="M61.543 41.984c0 6.217-5.058 11.83-11.298 12.537-6.24.71-11.298-3.756-11.298-9.973 0-6.216 5.058-11.83 11.298-12.538 6.24-.708 11.298 3.758 11.298 9.974zM50.245 54.522c6.96-.79 12.784 3.398 14.252 9.726.388 1.672-.829 3.305-2.542 3.498l-22.586 2.565c-2.065.234-3.72-1.694-3.16-3.688 1.759-6.269 7.377-11.345 14.036-12.101zm1.698 33.868c19.745-3.207 35.635-20.832 36.61-40.607l-9.914 1.126a1.718 1.718 0 0 1-1.903-1.508 1.715 1.715 0 0 1 1.512-1.896l10.316-1.17c-.378-9.469-4.272-17.944-11.073-23.992-6.193-5.505-14.13-8.427-22.697-8.427-.942 0-1.895.048-2.85.12v10.26c0 .946-.77 1.713-1.72 1.713a1.716 1.716 0 0 1-1.718-1.713v-9.865C28.76 15.638 12.87 33.262 11.896 53.038l9.914-1.126c.946-.095 1.796.568 1.903 1.508a1.713 1.713 0 0 1-1.512 1.894l-10.316 1.173c.379 9.468 4.273 17.944 11.075 23.992 6.873 6.112 15.895 9.026 25.546 8.31V78.525c0-.947.77-1.712 1.719-1.712.948 0 1.718.765 1.718 1.712v9.866zm45.593-45.073c.957-.09 1.794.568 1.903 1.507a1.715 1.715 0 0 1-1.514 1.896L92 47.392c-.792 21.747-18.322 41.202-40.057 44.454v5.892c0 .946-.77 1.712-1.718 1.712a1.715 1.715 0 0 1-1.72-1.712V92.22c-.96.066-1.917.11-2.865.11-9.407 0-18.137-3.224-24.97-9.298-7.448-6.62-11.74-15.852-12.212-26.157l-5.544.63a1.718 1.718 0 0 1-1.903-1.507 1.715 1.715 0 0 1 1.513-1.896l5.925-.673c.792-21.748 18.322-41.204 40.057-44.456v-5.89c0-.947.77-1.713 1.719-1.713.948 0 1.718.766 1.718 1.713v5.51c10.492-.717 20.316 2.509 27.837 9.195 7.447 6.622 11.739 15.854 12.212 26.158l5.544-.629z" fill="currentColor" fill-rule="evenodd"/>'
  },
  crown: {
    width: 15,
    height: 15,
    block: '<path d="M38.58 51.5a11.43 11.43 0 0 1 22.84 0 11.43 11.43 0 0 1-22.84 0zM50 85.26c-23.13 0-40.35-6.28-44.25-12.53v-7.28C13.98 72.17 30.32 76.58 50 76.58s36.02-4.4 44.25-11.14v7.28C90.35 78.97 73.13 85.25 50 85.25zM5.75 30.32l17.7 15.3a2.88 2.88 0 0 0 4.15-.4l22.38-28.66L72.14 45.3a2.88 2.88 0 0 0 4.15.43L94.25 30.3v24.83c0 7.43-18.18 15.7-44.25 15.7-26.08 0-44.25-8.27-44.25-15.7v-24.8zM100 24.03a2.87 2.87 0 0 0-1.68-2.6 2.87 2.87 0 0 0-3.07.43l-7.67 6.59-9.46-14.7a2.88 2.88 0 0 0-4.3-.63l-11.55 9.95-9.99-12.95A2.88 2.88 0 0 0 50.01 9H50c-.89 0-1.72.4-2.27 1.1l-9.85 12.62-10.68-9.56a2.88 2.88 0 0 0-4.29.51l-10.3 14.99-7.85-6.8A2.88 2.88 0 1 0 0 24.04v49.42c0 .45.1.9.3 1.29C5.1 84.32 25.52 91 50 91c24.48 0 44.91-6.68 49.7-16.25.2-.4.3-.84.3-1.28V24.03z" fill="currentColor"/>'
  },
  date: {
    width: 15,
    height: 15,
    block: '<path d="M47.084 49.904v5.792l5.833-.665v-5.79l-5.833.663zM44.62 60.91a2.462 2.462 0 0 1-2.464-2.46V47.71c0-1.251.94-2.302 2.185-2.444l10.76-1.223a2.46 2.46 0 0 1 2.744 2.443v10.741a2.46 2.46 0 0 1-2.185 2.444l-10.762 1.224c-.092.01-.185.016-.278.016zm2.464 11.02v5.79l5.833-.663v-5.79l-5.833.663zM44.62 82.936a2.458 2.458 0 0 1-2.464-2.46V69.735c0-1.251.94-2.302 2.185-2.444l10.76-1.224a2.458 2.458 0 0 1 2.744 2.444v10.741c0 1.251-.94 2.302-2.185 2.444L44.898 82.92c-.092.01-.185.016-.278.016zM24.363 52.488v5.79l5.833-.663v-5.79l-5.833.663zM21.9 63.494a2.461 2.461 0 0 1-2.464-2.46v-10.74c0-1.25.94-2.302 2.185-2.444l10.762-1.224a2.478 2.478 0 0 1 1.919.608c.524.467.823 1.135.823 1.836v10.74a2.46 2.46 0 0 1-2.185 2.444l-10.761 1.223a2.319 2.319 0 0 1-.279.017zm0 22.026a2.458 2.458 0 0 1-2.464-2.46V72.32c0-1.251.94-2.302 2.185-2.444l10.762-1.223a2.461 2.461 0 0 1 2.743 2.443v10.741a2.462 2.462 0 0 1-2.186 2.444l-10.761 1.224a2.61 2.61 0 0 1-.279.016zm45.44-27.194a2.458 2.458 0 0 1-2.464-2.46v-10.74c0-1.25.94-2.302 2.185-2.444l10.762-1.223a2.461 2.461 0 0 1 2.743 2.443v10.741a2.461 2.461 0 0 1-2.186 2.444l-10.761 1.225c-.093.01-.186.015-.279.015zm2.464 11.02v5.792l5.834-.665v-5.79l-5.834.663zM67.34 80.352a2.462 2.462 0 0 1-2.464-2.46V67.151a2.46 2.46 0 0 1 2.185-2.444l10.762-1.223a2.461 2.461 0 0 1 2.743 2.443v10.741a2.46 2.46 0 0 1-2.186 2.444l-10.761 1.224a2.61 2.61 0 0 1-.279.016zm20.733 5.772V30.898l-76.144 8.66v55.226l76.144-8.66zM29.745 9.823v11.195l5.551-.63V9.191l-5.551.63zm34.959-3.976v11.195l5.551-.63V5.215l-5.551.63zm27.474-.287c.522.467.822 1.134.822 1.835V88.32c0 1.25-.94 2.302-2.185 2.444l-81.072 9.22a2.468 2.468 0 0 1-1.92-.609A2.461 2.461 0 0 1 7 97.54V16.615c0-1.25.94-2.302 2.185-2.443l15.632-1.777V7.627c0-1.25.94-2.302 2.183-2.442l10.48-1.192a2.465 2.465 0 0 1 2.744 2.443v4.206l19.552-2.225V3.651a2.46 2.46 0 0 1 2.185-2.442L72.44.016a2.465 2.465 0 0 1 2.742 2.444v4.206l15.074-1.715a2.488 2.488 0 0 1 1.92.609z" fill="currentColor" fill-rule="evenodd"/>'
  },
  "delete": {
    width: 15,
    height: 15,
    block: '<path d="M87.69 19.84c.53-2.7-2.08-5.12-4.36-6.68-7.35-5.02-21.31-7.91-35.27-7.91a87 87 0 0 0-18.04 1.78C17.9 9.63 12.9 14.1 12.31 17.15c-.54 2.7 2.07 5.12 4.35 6.67 10.62 7.26 35.04 10.07 53.31 6.14C82.1 27.35 87.1 22.88 87.7 19.84zm-2.2 15.4c.36-2.07.67-4.15.95-6.08-3.73 2.5-8.93 4.53-15.36 5.91a92.3 92.3 0 0 1-19.16 1.91c-15.02 0-29.99-3.21-38.22-8.84l-.14-.1c.28 1.91.6 3.96.94 6a15.97 15.97 0 0 0 2.16 1.75c10.62 7.25 35.04 10.06 53.31 6.13 7.08-1.52 12.55-3.88 15.53-6.69zm.8-26.4c6.84 4.67 7.03 9.53 6.55 12l-.06.23c-.11.99-1 8.73-2.26 15.87a2.61 2.61 0 0 1-.66 1.33 21.24 21.24 0 0 1-4.77 3.7c-3.3 18.88-8.13 46.26-8.5 47.58-1.2 4.32-6.1 7.6-13.79 9.26-3.75.8-7.8 1.19-11.82 1.19-9.13 0-18.14-1.98-23.27-5.5-2.5-1.7-3.94-3.7-4.4-6.13-.44-2.25-5.22-29.38-8.41-47.5-.41-.25-.82-.5-1.2-.77a20.42 20.42 0 0 1-3.58-3.07 2.63 2.63 0 0 1-.65-1.3A306.96 306.96 0 0 1 7.15 19.5v-.06a8.95 8.95 0 0 1 0-3.31C8.4 9.8 16.35 4.62 28.93 1.9 48.72-2.35 74.47.76 86.3 8.84zm-31.02 1.9a8.9 8.9 0 0 1 8.9 8.88 2.62 2.62 0 0 1-2.62 2.62 2.62 2.62 0 0 1-2.62-2.61 3.65 3.65 0 0 0-3.66-3.65H44.72a3.65 3.65 0 0 0-3.65 3.64 2.62 2.62 0 0 1-2.62 2.62 2.62 2.62 0 0 1-2.62-2.61c0-4.9 3.99-8.88 8.9-8.88h10.54z" fill="currentColor"/>'
  },
  department: {
    width: 15,
    height: 15,
    block: '<path d="M11.3 37.2a10.67 10.67 0 0 1-3.5-8.08c0-6.32 5.1-12.05 11.39-12.77 3.18-.36 6.19.56 8.46 2.6 2.26 2.03 3.5 4.9 3.5 8.07 0 6.33-5.1 12.06-11.4 12.78-.45.05-.9.07-1.34.07-2.68 0-5.17-.92-7.12-2.67zm61.05-6.15a10.67 10.67 0 0 1-3.5-8.07c0-6.32 5.1-12.05 11.4-12.77 3.17-.36 6.18.56 8.46 2.6 2.25 2.02 3.5 4.89 3.5 8.07 0 6.32-5.11 12.05-11.4 12.77a10.52 10.52 0 0 1-8.46-2.6zM59.67 65.51l4.88-2.1V51.03c0-3.83-1.46-7.25-4.12-9.64a12.76 12.76 0 0 0-10.15-3.05c-8.18.94-14.84 8.38-14.84 16.6V66.9l4.4.88a2.5 2.5 0 0 1 1.97 2.06l3.95 24.12c.12.69.67 1.08 1.41 1l5.1-.59c.94-.1 1.8-.96 1.96-1.93l3.95-25.02a2.5 2.5 0 0 1 1.49-1.92zM91.75 40.3a14.5 14.5 0 0 1 4.75 10.97v11.09a2.51 2.51 0 0 1-1.52 2.31L91.2 66.3l-2.9 18.4a6.38 6.38 0 0 1-5.47 5.28l-4.02.46a5.86 5.86 0 0 1-.67.04 5.37 5.37 0 0 1-5.36-4.56l-2.84-17.34-3.2-.64-3.83 1.64-3.73 23.66a7.4 7.4 0 0 1-6.34 6.13l-5.1.59a6.88 6.88 0 0 1-.76.04 6.15 6.15 0 0 1-6.14-5.21l-3.67-22.4-4.7-.95-2.32 1-2.9 18.4a6.38 6.38 0 0 1-5.48 5.29l-4.02.46a5.83 5.83 0 0 1-.67.04 5.37 5.37 0 0 1-5.36-4.56L8.87 74.73l-3.36-.68A2.5 2.5 0 0 1 3.5 71.6V60.5c0-8.7 7.04-16.58 15.69-17.57a14.5 14.5 0 0 1 12.64 4.67c2.85-7.46 9.78-13.31 17.89-14.24 5.3-.6 10.28.92 14.04 4.3a17.12 17.12 0 0 1 4.4 6.24 17.87 17.87 0 0 1 12.08-7.11c4.34-.5 8.42.75 11.5 3.52zM50.28 5.09c-5.18.6-9.4 5.3-9.4 10.51 0 2.38.9 4.5 2.54 5.97a7.92 7.92 0 0 0 6.3 1.89c5.18-.6 9.4-5.31 9.4-10.52 0-2.38-.9-4.5-2.54-5.97a7.75 7.75 0 0 0-5.25-1.94c-.34 0-.7.02-1.05.06zM40.1 25.32a12.84 12.84 0 0 1-4.21-9.72c0-7.68 6.2-14.63 13.84-15.5 3.84-.45 7.45.67 10.19 3.12a12.84 12.84 0 0 1 4.21 9.72c0 7.68-6.2 14.63-13.84 15.5a12.66 12.66 0 0 1-10.2-3.12z" fill="currentColor"/>'
  },
  details: {
    width: 15,
    height: 15,
    block: '<path d="M30.08 59.7c7.13-.78 13.1 3.52 14.6 10.01a3 3 0 0 1-2.62 3.6l-23.22 2.64a3.01 3.01 0 0 1-3.25-3.8c1.8-6.42 7.55-11.64 14.37-12.44-6.39.7-11.56-3.9-11.56-10.27 0-6.4 5.2-12.17 11.62-12.9 6.42-.73 11.62 3.87 11.62 10.26 0 6.38-5.17 12.14-11.56 12.9zm64.54 19.98v-63.2l-32.6 3.7v6.38a2.68 2.68 0 0 1-2.39 2.66l-18.65 2.12a2.7 2.7 0 0 1-2.1-.66 2.68 2.68 0 0 1-.9-2v-5.76l-32.6 3.7v63.2l89.24-10.14zM43.36 11.7v13.99l13.28-1.5v-14L43.36 11.7zm55.74-.2a2.68 2.68 0 0 1 .9 2v68.59a2.68 2.68 0 0 1-2.38 2.66L2.99 95.48a2.7 2.7 0 0 1-2.1-.66 2.68 2.68 0 0 1-.89-2V24.23a2.68 2.68 0 0 1 2.38-2.66l35.6-4.05V9.3a2.68 2.68 0 0 1 2.39-2.66l18.65-2.12a2.67 2.67 0 0 1 2.1.66c.57.51.9 1.24.9 2v7.61L97 10.82a2.69 2.69 0 0 1 2.1.66zM55.38 44.11l28.64-3.1c1.48-.2 2.8.9 2.96 2.37a2.68 2.68 0 0 1-2.38 2.95l-28.64 3.1A2.68 2.68 0 0 1 53 47.09a2.68 2.68 0 0 1 2.38-2.96zm28.64 10.8c1.48-.2 2.8.9 2.96 2.37a2.68 2.68 0 0 1-2.38 2.95l-28.64 3.11A2.69 2.69 0 0 1 53 60.98a2.68 2.68 0 0 1 2.38-2.96l28.64-3.1z" fill="currentColor"/>'
  },
  dish: {
    width: 15,
    height: 15,
    block: '<path d="M99.08 2.75a2.58 2.58 0 0 1 .36 3.58L60.73 55.27l21.16 18.85c4 3.57 4.25 10.26.57 14.91a10 10 0 0 1-7.74 3.98 8.32 8.32 0 0 1-6.32-2.87L49.8 69.08 27.49 97.3a6.88 6.88 0 0 1-4.95 2.69A5.86 5.86 0 0 1 18 98.25c-2.48-2.5-2.57-6.8-.2-9.78L41.01 59.1l-8.42-9.54A13.5 13.5 0 0 1 19.73 46a2.96 2.96 0 0 1-.16-.17L.6 22.92a2.58 2.58 0 0 1 .35-3.64 2.6 2.6 0 0 1 3.66.34l18.9 22.82a8.36 8.36 0 0 0 9.02 1.75 2.61 2.61 0 0 1 2.87.71l36.9 41.83c.84.95 1.8 1.13 2.5 1.11a4.86 4.86 0 0 0 3.57-2c1.95-2.47 1.97-6.15.04-7.87L37.36 41.38a2.58 2.58 0 0 1-.81-2.44c.75-4.07-.28-8.12-2.7-10.63L11.6 9.76a2.58 2.58 0 0 1-.32-3.64 2.6 2.6 0 0 1 3.66-.32l22.34 18.63c.06.06.12.1.17.17 3.42 3.43 5.02 8.53 4.42 13.86l9.08 8.09 1.8-2.27a35.15 35.15 0 0 1 7.29-17.96l10.6-13.4C74.95 7.47 82.64.82 90.1.07c3.42-.34 6.44.56 8.97 2.68zM26.7 37.08L6.1 16.34a2.58 2.58 0 0 1 .02-3.65 2.6 2.6 0 0 1 3.67.01L30.4 33.45a2.58 2.58 0 0 1-.02 3.66 2.6 2.6 0 0 1-3.67-.02z" fill="currentColor"/>'
  },
  down: {
    width: 15,
    height: 15,
    block: '<path d="M50 80.5a6.52 6.52 0 0 1-4.32-1.63L2.2 40.63a6.43 6.43 0 0 1-.55-9.12 6.55 6.55 0 0 1 9.2-.55l38.64 33.98 39.16-43.3a6.55 6.55 0 0 1 9.2-.49 6.43 6.43 0 0 1 .5 9.13l-43.5 48.07A6.53 6.53 0 0 1 50 80.5" fill="currentColor"/>'
  },
  dribbble: {
    width: 15,
    height: 15,
    block: '<path d="M50 0a50 50 0 1 0 0 100A50 50 0 0 0 50 0zm32.8 24.2a41.56 41.56 0 0 1 8.93 24.63c-11.22-1.97-20.89-2.03-29.25-.7a177.56 177.56 0 0 0-3.27-7.08c8.97-3.7 17.01-9.07 23.6-16.85zm-5.74-5.97c-5.9 7.14-13.28 12.06-21.64 15.4a214.17 214.17 0 0 0-15.26-24.2A41.38 41.38 0 0 1 50 8.24a41.54 41.54 0 0 1 27.06 9.99zM32.05 12.3a204.86 204.86 0 0 1 15.44 23.98c-11.73 3.23-24.85 4.1-38.13 4.13A41.92 41.92 0 0 1 32.05 12.3zM8.24 50l.03-1.35h.23c14.88 0 29.65-.98 42.9-4.88.99 2 1.96 4.07 2.9 6.2-17.42 5.1-28.29 16.57-35.73 27.48A41.56 41.56 0 0 1 8.24 50zm16.42 33.16c7.05-10.62 16.87-21.13 32.86-25.54a142.71 142.71 0 0 1 8.4 30.98A41.38 41.38 0 0 1 50 91.76a41.49 41.49 0 0 1-25.34-8.6zm48.93 1.28A152.24 152.24 0 0 0 65.71 56c7.3-.93 15.7-.7 25.45 1.08a41.85 41.85 0 0 1-17.57 27.36z" fill="currentColor"/>'
  },
  email: {
    width: 15,
    height: 15,
    block: '<path d="M60.871 45.865L49.677 57.947 5.253 20.063 94.103 10 60.89 45.846l-.014.013-.006.006zM0 25.97l30.414 25.937L0 84.73V25.97zm69.588 22.123L100 15.27v58.76L69.588 48.093zm-5.377 5.803l30.535 26.04L5.898 90l30.537-32.958 10.982 9.367c.748.637 1.668.95 2.582.95 1.073 0 2.14-.43 2.919-1.271L64.21 53.896z" fill="currentColor" fill-rule="evenodd"/>'
  },
  email_outline: {
    width: 15,
    height: 15,
    block: '<path d="M31.12 51.87L6.94 78.14V31.12l24.18 20.75zm61.94-30.01v47.02L68.88 48.11l24.18-26.26zM47.74 66.13a3.46 3.46 0 0 0 2.26.84c.94 0 1.87-.38 2.55-1.12l11.62-12.62 24.06 20.65-75.9 8.65L36.4 56.4l11.35 9.73zm39.93-48.66L49.72 58.68 11.77 26.12l75.9-8.65zm12.33-4.5c0-.14-.03-.28-.04-.41l-.02-.22a3.51 3.51 0 0 0-.3-.88l-.01-.07-.09-.11a3.47 3.47 0 0 0-.45-.63l-.15-.17-.1-.1a3.47 3.47 0 0 0-.65-.46l-.09-.03a3.36 3.36 0 0 0-.8-.29 3.5 3.5 0 0 0-1.16-.08L3.08 20.12c-.31.04-.6.13-.88.24a3.42 3.42 0 0 0-.91.52l-.1.09c-.2.17-.38.37-.53.59l-.1.12a3.46 3.46 0 0 0-.37.8l-.04.07-.01.1c-.08.29-.13.58-.14.88v63.5c0 .14.03.27.04.4l.03.23c.05.3.15.6.28.88l.03.06c.02.05.07.1.1.14a3.43 3.43 0 0 0 .55.74l.13.14c.15.13.31.25.48.35l.03.02c.24.15.5.25.76.34l.2.05c.27.07.55.12.83.12h.01c.13 0 .26 0 .4-.02l93.06-10.6c.3-.04.6-.13.87-.24l.18-.07c.26-.13.51-.27.73-.46l.1-.08c.2-.18.38-.38.53-.6l.1-.12c.15-.24.28-.51.37-.8l.04-.07.01-.1c.08-.28.13-.57.14-.87v-63.5z" fill="currentColor"/>'
  },
  employer_branding: {
    width: 15,
    height: 15,
    block: '<path d="M50.47 20.38c-12.37 1.4-22.42 12.55-22.42 24.86v33.58a4.1 4.1 0 0 1-4.11 4.1 4.1 4.1 0 0 1-4.1-4.1V45.24c0-16.33 13.32-31.13 29.7-32.99a4.1 4.1 0 0 1 4.54 3.6 4.1 4.1 0 0 1-3.61 4.53zm15.35-3.33c7.91 4.47 12.64 12.8 12.64 22.27v33.59a2.4 2.4 0 0 1-2.4 2.38 2.4 2.4 0 0 1-2.4-2.38V39.32c0-7.74-3.81-14.5-10.2-18.11a2.38 2.38 0 0 1-.9-3.25 2.4 2.4 0 0 1 3.26-.9zM35.75 55.6a2.4 2.4 0 0 1 2.4 2.39v30.96a2.4 2.4 0 0 1-2.4 2.4 2.4 2.4 0 0 1-2.4-2.4V57.98a2.4 2.4 0 0 1 2.4-2.39zM61.7 31.61a14.89 14.89 0 0 1 4.94 11.32V85.7a2.39 2.39 0 0 1-2.39 2.39 2.4 2.4 0 0 1-2.4-2.39V42.93c0-3.1-1.18-5.85-3.34-7.76a10.43 10.43 0 0 0-8.24-2.45c-6.68.76-12.12 6.79-12.12 13.44a2.4 2.4 0 0 1-2.4 2.39 2.4 2.4 0 0 1-2.4-2.39c0-9 7.35-17.16 16.38-18.19 4.51-.5 8.76.78 11.97 3.64zM78.28 8.88C85.83 15.61 90 25.18 90 35.83v8.36a2.39 2.39 0 0 1-2.4 2.39 2.4 2.4 0 0 1-2.4-2.39v-8.36c0-9.27-3.59-17.58-10.12-23.38-6.6-5.87-15.4-8.51-24.8-7.44-11.18 1.26-21.84 7.83-28.52 17.57a2.4 2.4 0 0 1-3.33.62 2.38 2.38 0 0 1-.63-3.32C25.37 8.86 37.01 1.71 49.73.26 60.51-.96 70.64 2.1 78.27 8.9zM14.34 32.02a2.39 2.39 0 0 1 1.7 2.92 36.77 36.77 0 0 0-1.25 9.43v10.88a2.4 2.4 0 0 1-2.4 2.4 2.4 2.4 0 0 1-2.39-2.4V44.37c0-3.56.47-7.15 1.4-10.65a2.4 2.4 0 0 1 2.93-1.7zM50 41.45a4.1 4.1 0 0 1 4.1 4.1V95.9A4.1 4.1 0 0 1 50 100a4.1 4.1 0 0 1-4.1-4.1V45.55a4.1 4.1 0 0 1 4.1-4.1z" fill="currentColor"/>'
  },
  expand: {
    width: 15,
    height: 15,
    block: '<path d="M56.349 86.445a3.354 3.354 0 0 1 3.71 2.967 3.367 3.367 0 0 1-2.952 3.73l-50.98 5.835a3.357 3.357 0 0 1-3.71-2.965 3.362 3.362 0 0 1 2.951-3.73l50.98-5.837zm0-29.276c1.87-.22 3.5 1.118 3.71 2.967a3.367 3.367 0 0 1-2.952 3.729l-50.98 5.836a3.357 3.357 0 0 1-3.71-2.965 3.362 3.362 0 0 1 2.951-3.73l50.98-5.837zm42.925-29.772c-.087.158-.192.304-.292.454-.113.16-.22.322-.344.47-.039.045-.064.095-.102.139L78.517 50.869a5.72 5.72 0 0 1-4.278 1.918 5.704 5.704 0 0 1-3.837-1.479c-2.364-2.13-2.558-5.782-.439-8.156l9.907-11.09-73.472 8.412c-.22.025-.44.039-.657.039-2.884 0-5.37-2.176-5.704-5.124-.358-3.169 1.907-6.03 5.06-6.392l75.698-8.668L70.43 11.1a5.798 5.798 0 0 1-.49-8.154 5.73 5.73 0 0 1 8.113-.493L98.07 20.277c.096.085.167.187.257.277.14.145.278.285.404.441.11.139.204.285.301.432.111.165.219.33.31.51.085.161.15.327.217.495.073.18.148.356.201.546.056.191.09.387.127.584.023.13.067.252.082.385.006.054-.004.104.002.158.006.056.023.11.027.165.01.149-.016.293-.02.441-.001.187-.001.372-.022.555-.02.186-.065.367-.102.55-.042.187-.078.376-.136.557-.055.173-.132.337-.203.504-.077.177-.147.353-.241.52z" fill="currentColor" fill-rule="evenodd"/>'
  },
  external_link: {
    width: 15,
    height: 15,
    block: '<path d="M80.65 42.47a2.77 2.77 0 0 1 2.77 2.77v43.69a2.77 2.77 0 0 1-2.45 2.75l-72.89 8.3a2.77 2.77 0 0 1-2.15-.69A2.77 2.77 0 0 1 5 97.23V24.4a2.77 2.77 0 0 1 2.46-2.75l38.32-4.37a2.77 2.77 0 0 1 3.06 2.44 2.77 2.77 0 0 1-2.44 3.06l-35.86 4.09v67.27l67.34-7.67V45.24a2.77 2.77 0 0 1 2.77-2.77zM95 4.61l.01.12V28.7a4.75 4.75 0 0 1-4.75 4.75 4.75 4.75 0 0 1-4.75-4.75V17.12L36.83 71.31a4.74 4.74 0 0 1-3.54 1.58c-1.13 0-2.26-.4-3.17-1.22a4.74 4.74 0 0 1-.36-6.7l48.6-54.1-13.14 1.49a4.75 4.75 0 1 1-1.07-9.43L89.7 0h.13c.2-.02.4 0 .59 0l.38.01c.2.03.38.07.58.12.12.03.24.05.35.09.2.06.4.16.6.26l.28.13c.2.11.4.27.58.41.07.06.15.1.21.16h.01c.25.23.47.47.66.73l.1.16c.14.22.28.44.39.68l.1.28c.08.2.15.4.2.62.03.12.03.24.05.36.03.2.06.4.07.59z" fill="currentColor"/>'
  },
  facebook: {
    width: 15,
    height: 15,
    block: '<path d="M74.97.02L62 0C47.46 0 38.06 9.66 38.06 24.61v11.35H25.04A2.04 2.04 0 0 0 23 38v16.44c0 1.12.91 2.04 2.04 2.04h13.02v41.48c0 1.13.91 2.04 2.04 2.04h16.99a2.04 2.04 0 0 0 2.03-2.04V56.48h15.23a2.04 2.04 0 0 0 2.04-2.04V38a2.04 2.04 0 0 0-2.03-2.04H59.12v-9.62c0-4.62 1.1-6.97 7.12-6.97h8.72A2.04 2.04 0 0 0 77 17.32V2.06C77 .93 76.09.02 74.97.02z" fill="currentColor"/>'
  },
  female: {
    width: 15,
    height: 15,
    block: '<path d="M49.63 55.47c-6.52.74-12.62-1.08-17.18-5.13-4.5-4-6.99-9.74-6.99-16.16 0-13.66 11.17-26.03 24.9-27.59a24.96 24.96 0 0 1 2.83-.16c5.45 0 10.47 1.83 14.36 5.29 4.5 4 6.99 9.74 6.99 16.16 0 13.66-11.17 26.03-24.9 27.59zM69.25 4.89C63.68 1.05 56.84-.6 49.64.2 32.73 2.12 19 17.36 19 34.18c0 8.28 3.25 15.72 9.15 20.96a27.73 27.73 0 0 0 18.62 6.92v15.5L34.14 79a3.22 3.22 0 0 0-2.85 3.55 3.23 3.23 0 0 0 3.58 2.83l11.9-1.35V96.8A3.22 3.22 0 0 0 50 100a3.22 3.22 0 0 0 3.23-3.21V83.3l12.64-1.43a3.22 3.22 0 0 0 2.84-3.56 3.22 3.22 0 0 0-3.58-2.83l-11.9 1.35V61.4C68.78 58.18 81 43.74 81 27.88c0-7.17-2.44-13.7-6.93-18.73a37.08 37.08 0 0 0-4.83-4.26z" fill="currentColor"/>'
  },
  filters: {
    width: 15,
    height: 15,
    block: '<path d="M70.32 17.1a6.82 6.82 0 0 0-5.82 6.51c0 1.4.52 2.64 1.46 3.48a4.62 4.62 0 0 0 3.68 1.09 6.82 6.82 0 0 0 5.83-6.52c0-1.4-.52-2.63-1.47-3.48a4.5 4.5 0 0 0-3.68-1.08zM3.01 33.35a3.02 3.02 0 0 1-2.99-2.69 3.03 3.03 0 0 1 2.65-3.35l56.13-6.44a12.78 12.78 0 0 1 10.84-9.8c3.15-.35 6.12.57 8.37 2.59A10.34 10.34 0 0 1 81 18.33l15.65-1.8a3 3 0 0 1 3.34 2.67 3.02 3.02 0 0 1-2.65 3.35l-16.17 1.86A12.78 12.78 0 0 1 69 34.28c-2.65 0-5.1-.93-7.04-2.66a10.33 10.33 0 0 1-2.98-4.67L3.35 33.33l-.34.02zm93.64 9.61a3 3 0 0 1 3.33 2.67A3.03 3.03 0 0 1 97.33 49l-61.09 7a12.78 12.78 0 0 1-10.84 9.8 11.53 11.53 0 0 1-1.33.07c-2.65 0-5.11-.92-7.05-2.66a10.34 10.34 0 0 1-2.97-4.67l-10.7 1.23A3.02 3.02 0 0 1 .02 57.1a3.02 3.02 0 0 1 2.65-3.35l11.2-1.29a12.79 12.79 0 0 1 10.84-9.79c3.14-.36 6.12.56 8.38 2.58a10.36 10.36 0 0 1 2.98 4.67l60.57-6.95zM53.44 82.9a6.82 6.82 0 0 0 5.82-6.51 4.6 4.6 0 0 0-1.46-3.48 4.5 4.5 0 0 0-3.68-1.09 6.82 6.82 0 0 0-5.83 6.52c0 1.4.52 2.63 1.47 3.48a4.63 4.63 0 0 0 3.68 1.08zm43.2-13.5a3.03 3.03 0 1 1 .68 6.02l-32.36 3.71A12.79 12.79 0 0 1 52.8 89c-2.65 0-5.11-.92-7.04-2.66a10.34 10.34 0 0 1-2.98-4.67L3.35 86.2a3.02 3.02 0 0 1-3.33-2.66 3.03 3.03 0 0 1 2.65-3.36L42.6 75.6a12.78 12.78 0 0 1 10.84-9.79c3.14-.36 6.12.56 8.37 2.58a10.33 10.33 0 0 1 2.98 4.67l31.86-3.65z" fill="currentColor"/>'
  },
  flag: {
    width: 15,
    height: 15,
    block: '<path d="M62.47 55.94c-9.08-.8-19.15-1.7-26.3 6.39L23.86 24.55c5.5-8.82 14-8.08 23.71-7.22 9.67.86 20.47 1.82 27.66-8.07 1.66 5.04 3.5 10.6 5.32 16.17 2.44 7.4 4.88 14.8 6.9 21-5.4 11.23-14.5 10.43-24.98 9.5m30.4-10.17l-7.23-22-7.2-21.92A2.67 2.67 0 0 0 76.03 0a2.7 2.7 0 0 0-2.59 1.6c-5.34 12.19-14.63 11.37-25.4 10.41-9.12-.8-19.23-1.7-26.4 6.5a4.56 4.56 0 0 0-2.09-1.64l.2-.16a5.65 5.65 0 0 0 .86-1.04 6.92 6.92 0 0 0 1.02-2.47 6.7 6.7 0 0 0 0-2.7 6.62 6.62 0 0 0-.38-1.28 7.62 7.62 0 0 0-.64-1.2A7.03 7.03 0 0 0 19.75 7a6.89 6.89 0 0 0-4.86-2.02c-1.81 0-3.58.74-4.87 2.02a8.02 8.02 0 0 0-.86 1.04 7.42 7.42 0 0 0-.63 1.2 6.67 6.67 0 0 0-.4 1.27 6.7 6.7 0 0 0 0 2.7 6.76 6.76 0 0 0 5.95 5.45 4.55 4.55 0 0 0-.53 3.9l24.21 74.28a4.6 4.6 0 0 0 5.79 2.94A4.58 4.58 0 0 0 46.49 94l-8.27-25.38c5.5-8.93 14.03-8.2 23.78-7.35 11.2 1 23.88 2.12 30.78-13.59.26-.6.3-1.28.09-1.9" fill="currentColor"/>'
  },
  gear: {
    width: 15,
    height: 15,
    block: '<path d="M62.58 61.1c-7.07 7.85-18.47 9.25-25.4 3.12a15.44 15.44 0 0 1-5.1-10.82c-.3-5.11 1.65-10.4 5.34-14.5 4.1-4.55 9.67-6.94 14.97-6.94 3.83 0 7.53 1.25 10.44 3.82a15.44 15.44 0 0 1 5.1 10.82c.29 5.11-1.66 10.4-5.35 14.5zm34.2-24.18l-7.64.87c-1-4.93-2.99-9.59-5.96-13.68l5.4-6c3.04-3.37-7.97-13.1-11-9.72l-5.4 6a35.74 35.74 0 0 0-14.4-4.31V2.46c0-4.28-15.56-2.51-15.56 1.77v7.62a45.24 45.24 0 0 0-14.4 7.58l-5.4-4.77c-3.03-2.69-14.04 9.54-11 12.22l5.4 4.77a44.38 44.38 0 0 0-5.96 15.04l-7.64.87c-4.3.48-4.3 16 0 15.52l7.64-.87c1 4.93 2.99 9.59 5.96 13.68l-5.4 6c-3.04 3.37 7.97 13.1 11 9.72l5.4-6a35.76 35.76 0 0 0 14.4 4.31v7.62c0 4.28 15.56 2.51 15.56-1.77v-7.62a45.23 45.23 0 0 0 14.4-7.58l5.4 4.77c3.03 2.69 14.04-9.54 11-12.22l-5.4-4.77a44.46 44.46 0 0 0 5.96-15.04l7.64-.87c4.3-.48 4.3-16 0-15.52z" fill="currentColor"/>'
  },
  github: {
    width: 15,
    height: 15,
    block: '<path d="M93.3 26.02A49.9 49.9 0 0 0 75.1 7.74 48.75 48.75 0 0 0 50 1a48.75 48.75 0 0 0-25.1 6.74A49.9 49.9 0 0 0 6.7 26.02 49.31 49.31 0 0 0 0 51.22a48.97 48.97 0 0 0 9.54 29.54A49 49 0 0 0 34.18 98.9c1.17.22 2.04.07 2.6-.45.57-.53.85-1.18.85-1.96l-.03-3.54a586.75 586.75 0 0 1-.04-5.82l-1.5.26c-.95.18-2.15.25-3.6.23a27.4 27.4 0 0 1-4.53-.45 10.09 10.09 0 0 1-4.36-1.96 8.3 8.3 0 0 1-2.87-4.03l-.65-1.5c-.43-1-1.12-2.12-2.05-3.34a7.88 7.88 0 0 0-2.83-2.48l-.46-.33a4.79 4.79 0 0 1-.84-.78 3.59 3.59 0 0 1-.59-.92c-.13-.3-.02-.56.33-.75.34-.2.97-.3 1.88-.3l1.3.2c.87.17 1.95.7 3.23 1.57 1.28.87 2.33 2 3.16 3.4 1 1.79 2.2 3.15 3.6 4.09a7.64 7.64 0 0 0 4.27 1.4c1.43 0 2.67-.1 3.71-.32a12.9 12.9 0 0 0 2.93-.99c.4-2.92 1.46-5.16 3.2-6.73-2.48-.26-4.7-.66-6.68-1.18a26.5 26.5 0 0 1-6.12-2.55 17.54 17.54 0 0 1-5.24-4.38 21.1 21.1 0 0 1-3.42-6.87 32.78 32.78 0 0 1-1.33-9.81c0-5.28 1.71-9.77 5.14-13.47-1.6-3.97-1.45-8.42.46-13.34 1.26-.4 3.12-.1 5.6.88 2.47.98 4.28 1.82 5.43 2.52a57.48 57.48 0 0 1 2.77 1.76 46.03 46.03 0 0 1 12.5-1.7c4.3 0 8.46.57 12.5 1.7l2.47-1.57a35 35 0 0 1 6-2.87c2.3-.88 4.05-1.12 5.27-.72 1.95 4.92 2.12 9.37.52 13.34 3.43 3.7 5.14 8.2 5.14 13.47 0 3.7-.45 6.99-1.33 9.84a20.3 20.3 0 0 1-3.45 6.87c-1.41 1.72-3.17 3.17-5.28 4.35s-4.14 2.03-6.12 2.55c-1.97.52-4.2.92-6.67 1.18 2.26 1.96 3.38 5.06 3.38 9.29v13.8c0 .78.28 1.43.82 1.96.54.52 1.4.67 2.57.45a48.98 48.98 0 0 0 24.64-18.15A48.97 48.97 0 0 0 100 51.23c0-9.11-2.24-17.52-6.7-25.21z" fill="currentColor"/>'
  },
  handshake: {
    width: 15,
    height: 15,
    block: '<path d="M91.02 41.63l-7.45 8.25L71.5 39.19a16.26 16.26 0 0 0 9.48-4.89 2.42 2.42 0 0 0-.09-3.44 2.46 2.46 0 0 0-3.46.08c-3.6 3.76-9.08 4.64-12.8 2.09l-3.2-2.75c-.08-.08-.18-.14-.28-.2l-.1-.07a2.4 2.4 0 0 0-.43-.2l-.12-.02a2.35 2.35 0 0 0-.33-.08L60 29.7c-.1 0-.19-.02-.28-.01l-.19.02c-.09.02-.18.02-.27.05l-.18.06c-.09.02-.18.05-.26.09-.06.02-.12.06-.17.1l-.23.13-.17.14-.16.14-7.47 7.64c-2.84 3.05-7.2 3.85-10.16 2.08l16.44-18.5c6.78-7.62 17.8-9.03 24.56-3.14l2.16 1.88c.06.06.1.13.17.18l7.43 6.55a8.78 8.78 0 0 1 2.9 6.15c.17 2.95-.96 6-3.1 8.37m-8.37 18.9c-1.39 1.54-3.55 1.87-4.83.74l-7.78-6.85a2.46 2.46 0 0 0-3.45.2 2.42 2.42 0 0 0 .2 3.44l7.78 6.86c.68.59.86 1.36.89 1.9.05 1-.34 2.05-1.08 2.87-1.4 1.54-3.55 1.87-4.83.74l-7.78-6.85a2.46 2.46 0 0 0-3.45.2 2.42 2.42 0 0 0 .2 3.44l7.78 6.86c.68.6.86 1.36.89 1.9a4 4 0 0 1-1.08 2.88c-1.4 1.53-3.55 1.86-4.83.74l-1.17-1.04v-.58a7.52 7.52 0 0 0-2.53-5.27c-1.6-1.4-3.66-2-5.73-1.84v-.16a7.5 7.5 0 0 0-8.27-7.12v-.17a7.53 7.53 0 0 0-2.52-5.27 7.7 7.7 0 0 0-5.75-1.85v-.17a7.52 7.52 0 0 0-2.52-5.27c-3.29-2.89-8.54-2.38-11.71 1.13l-2.78 3.05L5.94 44.22l19.4-21.56 7.1 4.97c.36.25.76.4 1.19.44 2.48.23 5.13-.22 7.68-.66 1.5-.26 3.02-.52 4.49-.63l-10.67 12c-.87.98-.8 2.47.15 3.37l.96.91a11.66 11.66 0 0 0 7.78 2.85c3.64 0 7.4-1.54 10.15-4.5l5.8-5.93 22.87 20.27c.68.6.86 1.37.89 1.91.05 1-.34 2.05-1.08 2.87M54.12 81.16l-3.27 3.7a6.67 6.67 0 0 1-4.6-4.05l2.6-2.95.67-.75.09-.1c1.39-1.45 3.48-1.75 4.73-.65.67.6.85 1.36.88 1.9.06 1-.34 2.05-1.1 2.9m-17.7-6.03l4.83-5.3c1.4-1.54 3.56-1.87 4.83-.75.67.6.85 1.37.88 1.9.06.97-.32 1.98-1 2.78l-.11.11-.65.73-4.16 4.58a6.68 6.68 0 0 1-4.63-4.05m-8.27-7.28l4.84-5.31c1.4-1.54 3.56-1.87 4.83-.75.67.6.85 1.37.88 1.9a4 4 0 0 1-1.07 2.87l-4.85 5.33a6.68 6.68 0 0 1-4.62-4.04m-8.27-7.3l.45-.49 4.38-4.81c1.39-1.54 3.56-1.87 4.83-.74.67.6.85 1.36.88 1.9a4 4 0 0 1-1.07 2.87L24.5 64.6a6.68 6.68 0 0 1-4.62-4.04M99 32.98a13.6 13.6 0 0 0-4.54-9.52l-3.19-2.8a2.51 2.51 0 0 0-.36-.4l-6.23-5.43c-8.79-7.65-22.9-6.04-31.45 3.59l-3.24 3.64c-3.23-.52-6.54.04-9.52.55-2.08.36-4.09.7-5.77.65l-8.32-5.83a2.46 2.46 0 0 0-3.23.37l-22.5 25a2.43 2.43 0 0 0 .2 3.45l14.2 12.43a2.41 2.41 0 0 0-.28 2.14l.4 1.11a11.63 11.63 0 0 0 8.33 7.43 11.63 11.63 0 0 0 8.27 7.29 11.64 11.64 0 0 0 8.4 7.33l1.17.26a2.5 2.5 0 0 0 1.17-.03 11.66 11.66 0 0 0 7.51 5.47l1.17.26a2.46 2.46 0 0 0 2.39-.77l4.2-4.78c.24-.27.46-.56.67-.85a7.65 7.65 0 0 0 4.67 1.58 8.98 8.98 0 0 0 6.63-3.01 8.9 8.9 0 0 0 2.32-6.2 9.03 9.03 0 0 0 5.95-2.97 8.9 8.9 0 0 0 2.33-6.18 9.01 9.01 0 0 0 5.94-2.98 8.88 8.88 0 0 0 2.32-6.4 7.62 7.62 0 0 0-1.5-4.15l7.55-8.35c3-3.33 4.59-7.67 4.34-11.9" fill="currentColor"/>'
  },
  hard_hat: {
    width: 15,
    height: 15,
    block: '<path d="M95.06 68.47l-43.41 9.68 2.28-19.97a17.17 17.17 0 0 1 14.33-14.95l23.62-3.76a32.77 32.77 0 0 1 3.18 14.08v14.92zM49.02 57.62L46.8 77.16l-10.68-6.62 2.9-18.02c1.95-1.5 3.55-4.12 4.03-8.23.11-1.02.14-2.07.1-3.14a20.2 20.2 0 0 1 12.89-7.87l26.88-4.5c.21-.04.41-.12.6-.2a32.8 32.8 0 0 1 5.72 6.32l-21.76 3.47a22.12 22.12 0 0 0-18.45 19.25zM31.95 80.91a21.6 21.6 0 0 1-14.45-3.35L5.51 69.72a1.24 1.24 0 0 1-.57-1.07c0-.2.07-.72.6-1.05l8.25-5.1 17.89 11.09.3.22.2.1 9.38 5.8-9.6 1.2zM19.82 42.89c.44-2.1 1.12-4.12 2-6.02a24.76 24.76 0 0 0 4.08 12.26l-2.2 13.7-7.14-4.42 3.26-15.52zm7-9.26c.4-3.51 1.97-5.51 3.92-5.51.88 0 1.84.4 2.8 1.26 3.12 2.75 5.18 9.21 4.59 14.35-.4 3.53-1.97 5.54-3.92 5.54-.88 0-1.84-.41-2.81-1.29-3.1-2.8-5.17-9.25-4.58-14.35zm16.55-13.18l5.92-.96a43.58 43.58 0 0 1 22.04 2.13l-21.66 2.17c-.67.07-1.57.17-2.47.36a29.35 29.35 0 0 0-8.72 3.31 13.89 13.89 0 0 0-1.65-1.77 10.28 10.28 0 0 0-2.98-1.87 28.46 28.46 0 0 1 9.52-3.37zm39.68 1.6a48.5 48.5 0 0 0-34.55-7.43l-5.92.96a33.86 33.86 0 0 0-27.6 26.3l-3.4 16.17-8.65 5.36A6.16 6.16 0 0 0 0 68.6a6.16 6.16 0 0 0 2.8 5.26l12 7.83a26.55 26.55 0 0 0 17.76 4.12l16.55-2.05.07-.01.13-.02h.03l48.73-10.86a2.46 2.46 0 0 0 1.93-2.41v-16.9c0-12.7-6.34-24.47-16.95-31.5z" fill="currentColor"/>'
  },
  hashtag: {
    width: 15,
    height: 15,
    block: '<path d="M60.66 38.68V59l-20.32 2.32V41l20.32-2.32zm32.44-3.7a5.6 5.6 0 0 0 4.9-5.5v-5.72a4.51 4.51 0 0 0-1.49-3.36 4.5 4.5 0 0 0-3.5-1.1l-16.73 1.91V4.5c0-1.29-.54-2.51-1.49-3.36a4.48 4.48 0 0 0-3.5-1.1l-5.7.65a5.63 5.63 0 0 0-4.93 5.53V23l-20.32 2.3V8.6a4.5 4.5 0 0 0-1.5-3.36 4.46 4.46 0 0 0-3.5-1.1l-5.73.66a5.6 5.6 0 0 0-4.89 5.49V27.1L7.89 29.02A5.6 5.6 0 0 0 3 34.5v5.72c0 1.29.54 2.52 1.49 3.36a4.48 4.48 0 0 0 3.5 1.1l16.73-1.9V63.1L7.87 65.03A5.56 5.56 0 0 0 3 70.49v5.72a4.53 4.53 0 0 0 1.5 3.37 4.5 4.5 0 0 0 3 1.14 4.3 4.3 0 0 0 .52-.03l16.7-1.9V95.5a4.5 4.5 0 0 0 1.49 3.36 4.47 4.47 0 0 0 3.5 1.1l5.7-.65a5.63 5.63 0 0 0 4.93-5.53V77l20.32-2.32v16.7c0 1.3.55 2.53 1.5 3.38a4.5 4.5 0 0 0 3.52 1.1l5.68-.64a5.62 5.62 0 0 0 4.92-5.53V72.9l16.82-1.92A5.59 5.59 0 0 0 98 65.5v-5.72a4.51 4.51 0 0 0-1.49-3.36 4.5 4.5 0 0 0-3.5-1.1l-16.73 1.9V36.9l16.82-1.92z" fill="currentColor"/>'
  },
  'heading-1': {
    width: 15,
    height: 15,
    block: '<path d="M0 96.5v-93h17.367v38.062h34.497V3.5H69.23v93H51.864V58.56H17.367V96.5H0zm91.421 0V58.851h-6.806V50H100v46.5h-8.579z" fill="currentColor"/>'
  },
  'heading-2': {
    width: 15,
    height: 15,
    block: '<path d="M0 90V10h15.052v32.742h29.896V10H60v80H44.948V57.364H15.052V90H0zm73.561 0v-6.757c5.071-4.757 12.935-12.865 16.126-16.486 1.14-1.46 1.766-3.135 1.766-4.54 0-2.758-1.88-4.812-4.786-4.812-2.792 0-4.844 2.054-4.844 4.811v2.054h-8.49v-1.946c0-6.81 5.87-12.324 13.334-12.324C94.188 50 100 55.19 100 62c0 2.919-.855 5.081-2.393 7.19-1.71 2.432-8.89 9.837-11.909 12.594-.456.432-.285.865.285.865h13.79V90H73.56z" fill="currentColor"/>'
  },
  heart: {
    width: 15,
    height: 15,
    block: '<path d="M92.229 8.932C87.176 4.407 80.474 2.359 73.34 3.176c-10.09 1.154-19.132 8.067-23.452 17.32-4.478-8.264-13.585-13.08-23.749-11.922C11.726 10.222 0 23.337 0 37.813c0 6.079 2.1 11.796 5.917 16.104 4.413 4.981 40.905 41.837 42.455 43.403A2.29 2.29 0 0 0 50 98c.04 0 .077-.002.117-.004a2.293 2.293 0 0 0 1.666-.85c1.55-1.92 38.032-47.105 42.428-53.077C97.944 39.002 100 32.904 100 26.9c0-7.098-2.761-13.479-7.771-17.969" fill="currentColor" fill-rule="evenodd"/>'
  },
  heart_outline: {
    width: 15,
    height: 15,
    block: '<path d="M49.67 16.913C44.358 10.572 36.052 7.25 27.177 8.26 12.145 9.972 0 23.518 0 38.573c0 6.4 2.228 12.447 6.296 17.025 1.797 2.021 8.874 9.283 19.708 20.273l.227.23a8154.588 8154.588 0 0 0 19.514 19.722l.688.693A5.03 5.03 0 0 0 50 98c.09 0 .09 0 .158-.003l.083-.003a5.032 5.032 0 0 0 3.662-1.854l.689-.85a11514.418 11514.418 0 0 0 6.05-7.48c4.61-5.705 9.18-11.368 13.45-16.672l.185-.23c10.836-13.461 17.932-22.36 19.71-24.769C97.862 40.893 100 34.572 100 28.314c0-7.467-2.938-14.24-8.276-19.01-5.385-4.809-12.52-6.979-20.041-6.12-8.834 1.008-16.979 6.23-22.014 13.73zm44.618 11.401c0 5.03-1.74 10.173-4.903 14.454-1.705 2.31-8.827 11.241-19.565 24.58l-.185.231a11346.504 11346.504 0 0 1-19.49 24.14l-.198.244-.139-.14a8726.638 8726.638 0 0 1-19.502-19.709l-.226-.23c-10.7-10.852-17.812-18.15-19.506-20.057-3.129-3.52-4.862-8.223-4.862-13.254 0-12.162 9.966-23.277 22.115-24.662 8.3-.943 15.831 2.882 19.556 9.736 1.117 2.055 4.108 1.966 5.1-.152 3.718-7.941 11.467-13.702 19.85-14.66 5.922-.675 11.428.999 15.576 4.704 4.112 3.674 6.379 8.9 6.379 14.775z" fill="currentColor" fill-rule="evenodd"/>'
  },
  heart_shiny: {
    width: 15,
    height: 15,
    block: '<path d="M83.29 45.46c0-4.8-2.21-9.4-5.77-12.03a11.4 11.4 0 0 0-10.35-1.7 2.64 2.64 0 0 0-1.75 3.3 2.65 2.65 0 0 0 3.31 1.74c2.58-.79 4.5.06 5.65.9 2.2 1.62 3.61 4.68 3.61 7.8 0 2.31-.81 4.69-2.29 6.68a2.63 2.63 0 0 0 .56 3.7 2.65 2.65 0 0 0 3.7-.55 16.67 16.67 0 0 0 3.33-9.84M72.67 60.72a2.65 2.65 0 0 0-3.73.37l-5.4 6.62a2.64 2.64 0 1 0 2.04 4.3c.77 0 1.53-.33 2.05-.97l5.42-6.61a2.64 2.64 0 0 0-.38-3.71m18.47-16.66c0 4.83-1.66 9.73-4.68 13.8-3.44 4.65-31.9 39.67-33.12 41.16a2.64 2.64 0 0 1-2.05.98 2.65 2.65 0 0 1-1.88-.78c-1.2-1.21-29.68-29.79-33.14-33.66a19.52 19.52 0 0 1-4.83-13.05c0-11.63 9.49-22.17 21.14-23.5 7.72-.88 14.7 2.45 18.56 8.33 3.72-6.72 10.61-11.64 18.25-12.51 5.82-.65 11.28 1 15.4 4.67a19.17 19.17 0 0 1 6.35 14.56M13.26 29.33c.73 0 1.46-.3 1.98-.89a2.63 2.63 0 0 0-.22-3.72L6.4 17.1a2.65 2.65 0 0 0-3.73.22 2.63 2.63 0 0 0 .22 3.73l8.62 7.6a2.64 2.64 0 0 0 1.75.67M98.12 6.88a2.65 2.65 0 0 0-3.74.2l-8.61 9.57a2.63 2.63 0 0 0 .2 3.72 2.63 2.63 0 0 0 1.77.68c.72 0 1.44-.3 1.97-.88l8.61-9.57a2.63 2.63 0 0 0-.2-3.72m-49.48 7.9V2.64A2.64 2.64 0 0 1 51.3 0a2.64 2.64 0 0 1 2.64 2.64v12.14a2.64 2.64 0 0 1-2.64 2.64 2.64 2.64 0 0 1-2.65-2.63" fill="currentColor"/>'
  },
  information: {
    width: 15,
    height: 15,
    block: '<path d="M49.66 93.76c24.456-2.769 44.353-24.788 44.353-49.084 0-11.56-4.496-21.915-12.66-29.157-7.049-6.252-16.119-9.567-25.946-9.567-1.67 0-3.36.096-5.07.29-24.453 2.767-44.35 24.786-44.35 49.08 0 11.562 4.496 21.92 12.66 29.16 8.245 7.313 19.266 10.61 31.013 9.277zm35.678-82.68C94.793 19.464 100 31.397 100 44.676c0 27.225-22.28 51.895-49.662 54.996-1.94.22-3.866.328-5.768.328-11.29 0-21.748-3.839-29.91-11.08C5.207 80.535 0 68.604 0 55.323 0 28.1 22.278 3.43 49.66.328 63.14-1.196 75.804 2.622 85.338 11.08zM43.71 31.12a7.784 7.784 0 0 1-.342-1.122 6.458 6.458 0 0 1-.103-1.156c0-.391.034-.782.103-1.156.085-.391.205-.765.342-1.122a5.95 5.95 0 0 1 .564-1.02 5.29 5.29 0 0 1 .736-.901 5.4 5.4 0 0 1 .907-.749 6.079 6.079 0 0 1 1.043-.544c.36-.153.736-.272 1.112-.34a6.04 6.04 0 0 1 4.5.884c.324.221.632.46.906.749.273.272.532.578.752.9.207.324.394.664.548 1.02.137.358.256.732.342 1.123a6.497 6.497 0 0 1 0 2.312 7.784 7.784 0 0 1-.342 1.122c-.154.357-.34.697-.548 1.02a7.52 7.52 0 0 1-.752.918 6.3 6.3 0 0 1-.907.73 4.953 4.953 0 0 1-1.026.545 5.708 5.708 0 0 1-1.13.34 5.517 5.517 0 0 1-1.163.119c-.393 0-.786-.034-1.18-.12a5.239 5.239 0 0 1-1.112-.34 5.079 5.079 0 0 1-1.043-.543 6.3 6.3 0 0 1-.907-.731 6.192 6.192 0 0 1-.736-.918 5.95 5.95 0 0 1-.564-1.02zm13.64 36.81c2.82-.32 5.36 1.692 5.68 4.49.321 2.798-1.701 5.325-4.517 5.644a12.99 12.99 0 0 1-10.076-3.18 12.831 12.831 0 0 1-4.32-9.589V52.548l-3.023.343c-2.828.317-5.362-1.691-5.68-4.49-.321-2.8 1.702-5.326 4.516-5.645l8.737-.99a5.155 5.155 0 0 1 4 1.263 5.088 5.088 0 0 1 1.713 3.805v18.461c0 1.034.558 1.683.892 1.979a2.65 2.65 0 0 0 2.078.656z" fill="currentColor" fill-rule="evenodd"/>'
  },
  instagram: {
    width: 15,
    height: 15,
    block: '<path d="M70.21 0A29.82 29.82 0 0 1 100 29.79v40.42A29.82 29.82 0 0 1 70.21 100H29.79A29.82 29.82 0 0 1 0 70.21V29.79A29.82 29.82 0 0 1 29.79 0h40.42zm19.73 70.21V29.79c0-10.9-8.83-19.73-19.73-19.73H29.79a19.73 19.73 0 0 0-19.73 19.73v40.42c0 10.9 8.83 19.73 19.73 19.73h40.42c10.9 0 19.73-8.83 19.73-19.73zM50 24.14A25.9 25.9 0 0 1 75.86 50 25.9 25.9 0 0 1 50 75.86c-14.26 0-25.86-11.6-25.86-25.86S35.74 24.14 50 24.14zm0 41.66a15.8 15.8 0 1 0 0-31.6 15.8 15.8 0 0 0 0 31.6zm25.91-35.27a6.2 6.2 0 1 1 0-12.4 6.2 6.2 0 0 1 0 12.4z" fill="currentColor"/>'
  },
  italic: {
    width: 15,
    height: 15,
    block: '<path d="M50 0h16.5L50 100H33.5z" fill="currentColor"/>'
  },
  language: {
    width: 15,
    height: 15,
    block: '<path d="M84.06 53.08l-9.6 24a.8.8 0 0 1-.74.5h-2.27a.78.78 0 0 1-.78-.77V62.95a5.24 5.24 0 0 0-5.23-5.24h-5.21a1 1 0 0 1-.97-.73l-1.32-4.78c-.23-.85.14-1.75.94-2.22l7.6-4.67a5.25 5.25 0 0 0 2.6-4.52v-9.16a3.9 3.9 0 0 1 1.84-3.32l12.8-7.47A44.55 44.55 0 0 1 94.6 49.8h-5.67a5.21 5.21 0 0 0-4.86 3.29M40.5 68.78l-14.3 17.8a.59.59 0 0 1-.71.2.58.58 0 0 1-.42-.6V61.46a5.2 5.2 0 0 0-1.13-2.98L8.18 38.64a2.92 2.92 0 0 1-.5-2.74 44.74 44.74 0 0 1 11.49-18.1c.52-.5 1.18-.77 1.85-.77h10.43c.92 0 1.77.46 2.26 1.24l6.12 9.5c.42.65.56 1.44.39 2.2a2.87 2.87 0 0 1-1.32 1.83L22.38 41.9a4.76 4.76 0 0 0-2.18 3.03 4.76 4.76 0 0 0 .65 3.68l2.98 4.59a5.22 5.22 0 0 0 4.4 2.38h8.73c.56 0 1.04.38 1.17.92l2.63 11.16c.1.4 0 .8-.25 1.12M50 0C22.42 0 0 22.43 0 50s22.43 50 50 50 50-22.43 50-50S77.57 0 50 0" fill="currentColor"/>'
  },
  left: {
    width: 15,
    height: 15,
    block: '<path d="M71.93 100c-1.55 0-3.1-.54-4.35-1.64L23.7 59.83a6.5 6.5 0 0 1-2.2-4.5 6.48 6.48 0 0 1 1.67-4.73L67.04 2.16a6.6 6.6 0 0 1 9.28-.5 6.47 6.47 0 0 1 .5 9.2L37.37 54.43 76.28 88.6a6.47 6.47 0 0 1 .57 9.2 6.59 6.59 0 0 1-4.92 2.19" fill="currentColor"/>'
  },
  link: {
    width: 15,
    height: 15,
    block: '<path d="M39.897 93.167c-9.111 9.11-23.953 9.11-33.064 0-9.11-9.111-9.11-23.953 0-33.064l18.37-18.369c9.11-9.11 23.952-9.11 33.063 0a3.897 3.897 0 1 1-5.51 5.51c-6.154-6.153-15.89-6.153-22.043 0l-18.37 18.37c-6.153 6.153-6.153 15.889 0 22.042 6.154 6.154 15.89 6.153 22.043 0l17.45-17.45a3.897 3.897 0 1 1 5.511 5.51l-17.45 17.45zm34.9-34.901c-9.11 9.11-23.952 9.11-33.063 0a3.897 3.897 0 1 1 5.51-5.51c6.154 6.153 15.89 6.153 22.043 0l18.37-18.37c6.153-6.153 6.153-15.889 0-22.042-6.154-6.154-15.89-6.154-22.043 0l-17.45 17.45a3.897 3.897 0 1 1-5.511-5.51l17.45-17.45c9.111-9.112 23.953-9.112 33.064 0 9.11 9.11 9.11 23.952 0 33.063l-18.37 18.369z" fill="currentColor"/>'
  },
  linkedin: {
    width: 15,
    height: 15,
    block: '<path d="M100 60.52V96.5H78.57V62.93c0-8.44-3.1-14.2-10.86-14.2-5.92 0-9.45 3.89-11 7.64-.56 1.34-.7 3.2-.7 5.09V96.5H34.55s.29-56.86 0-62.75H56v8.9l-.14.2H56v-.2c2.85-4.28 7.93-10.38 19.32-10.38 14.1 0 24.68 8.97 24.68 28.25zM12.13 3.5C4.8 3.5 0 8.18 0 14.34c0 6.02 4.66 10.85 11.85 10.85h.14c7.48 0 12.13-4.83 12.13-10.85C23.98 8.18 19.47 3.5 12.13 3.5zm-10.86 93h21.44V33.75H1.27V96.5z" fill="currentColor"/>'
  },
  location: {
    width: 15,
    height: 15,
    block: '<path d="M49.83 93.46C56.84 83.62 81.48 48 81.48 32.75c0-8.29-3.21-15.71-9.04-20.9A27.53 27.53 0 0 0 53.9 5c-1.2 0-2.4.07-3.63.2-17.51 2-31.77 17.81-31.77 35.27 0 14.98 24.05 44.43 31.31 53zM75.78 8.12c6.9 6.15 10.71 14.9 10.71 24.63 0 19.3-33.07 64.32-34.48 66.23a2.5 2.5 0 0 1-1.9 1.02H50a2.51 2.51 0 0 1-1.88-.84C46.71 97.56 13.5 59.9 13.5 40.47 13.5 20.56 29.75 2.51 49.72.24c9.83-1.12 19.1 1.68 26.06 7.88zM62.71 21.4a16.18 16.18 0 0 1 5.36 12.29c0 9.79-7.98 18.66-17.8 19.78-.7.08-1.4.12-2.08.12-4.12 0-7.93-1.41-10.92-4.07a16.18 16.18 0 0 1-5.36-12.3c0-9.78 7.98-18.65 17.8-19.77 4.9-.55 9.51.85 13 3.95z" fill="currentColor"/>'
  },
  lock: {
    width: 15,
    height: 15,
    block: '<path d="M76.67 64.41c0-7.04-2.71-13.34-7.64-17.74a23.2 23.2 0 0 0-15.66-5.81 27.2 27.2 0 0 0-3.07.17c-14.87 1.7-26.96 15.19-26.96 30.07 0 7.04 2.7 13.34 7.63 17.74 4.97 4.45 11.62 6.45 18.73 5.64 14.87-1.7 26.97-15.19 26.97-30.07m5.33 0c0 17.51-14.22 33.38-31.7 35.38a32.53 32.53 0 0 1-3.7.21 28.45 28.45 0 0 1-19.19-7.17C21.34 87.4 18 79.69 18 71.1c0-9.4 4.12-18.3 10.62-24.87a2.7 2.7 0 0 1-.2-1.04V25.51c0-12.8 9.55-23.7 22.21-25.35a18.53 18.53 0 0 1 14.64 4.46 18.6 18.6 0 0 1 6.32 13.96V30.3a2.67 2.67 0 0 1-2.67 2.67 2.67 2.67 0 0 1-2.67-2.67V18.58c0-3.81-1.64-7.44-4.5-9.95a13.19 13.19 0 0 0-10.42-3.18 20.27 20.27 0 0 0-17.58 20.06v16.4a34.72 34.72 0 0 1 15.95-6.18c8.63-.99 16.76 1.48 22.89 6.96C78.66 48.1 82 55.83 82 64.4m-21.26-.83a11.9 11.9 0 0 1-6.93 10.66v7.4A3.81 3.81 0 0 1 50 85.46a3.81 3.81 0 0 1-3.81-3.82v-6.78a9.55 9.55 0 0 1-6.94-9.44c0-5.88 4.6-11 10.45-11.67 2.93-.33 5.7.52 7.8 2.4a9.8 9.8 0 0 1 3.24 7.42" fill="currentColor"/>'
  },
  male: {
    width: 15,
    height: 15,
    block: '<path d="M19.04 86.32c-5.2-4.67-8.07-11.37-8.07-18.86 0-15.94 12.9-30.38 28.77-32.2a28.56 28.56 0 0 1 3.27-.19c6.29 0 12.09 2.14 16.59 6.18 5.2 4.67 8.07 11.37 8.07 18.86 0 15.94-12.9 30.38-28.77 32.2-7.54.86-14.6-1.26-19.86-5.99zM92.34.02L64.91 3.18a3.74 3.74 0 0 0-3.28 4.15 3.75 3.75 0 0 0 4.13 3.3l17.86-2.04-22.07 24.7c-6.42-4.48-14.32-6.43-22.65-5.47C19.38 30.04 3.5 47.83 3.5 67.46c0 9.66 3.76 18.34 10.57 24.46A31.85 31.85 0 0 0 35.6 100s3.73 0 7.46-.79c17.96-3.77 32.09-20.6 32.09-39.1 0-8.36-2.83-15.99-8-21.85l21.9-24.52v17.58a3.74 3.74 0 0 0 3.73 3.75 3.74 3.74 0 0 0 3.73-3.75V3.75a3.76 3.76 0 0 0-1.25-2.8 3.71 3.71 0 0 0-2.9-.92z" fill="currentColor"/>'
  },
  map: {
    width: 15,
    height: 15,
    block: '<path d="M80.47 53.2c0-6.57-5.36-11.92-11.93-11.92S56.6 46.63 56.6 53.21c0 6.57 5.35 11.93 11.93 11.93 6.57 0 11.92-5.36 11.92-11.93M94 52.76c0 13.09-20.97 42.81-23.36 46.16a2.58 2.58 0 0 1-4.2 0c-2.4-3.35-23.37-33.07-23.37-46.16a25.5 25.5 0 0 1 25.47-25.47A25.5 25.5 0 0 1 94 52.76m-45.56 31a2.58 2.58 0 0 1-.61 3.6l-11.3 8a2.58 2.58 0 0 1-2.5.28L8.57 84.87A2.58 2.58 0 0 1 7 82.49V10.81a2.58 2.58 0 0 1 3.34-2.47l24.28 7.46L57.58.44A2.57 2.57 0 0 1 60.02.2l25.45 10.7a2.58 2.58 0 0 1 1.58 2.38v9.36a2.58 2.58 0 1 1-5.16 0V15L59.3 5.5 36.48 20.77a2.58 2.58 0 0 1-2.2.32l-22.11-6.8v66.5l22.56 9.54 10.13-7.18a2.58 2.58 0 0 1 3.6.6" fill="currentColor"/>'
  },
  marketplace: {
    width: 15,
    height: 15,
    block: '<path d="M9.76 14.32v15.04l30.73-3.51V10.8L9.76 14.32zm-2.38 20.1c-.58 0-1.15-.2-1.58-.6a2.4 2.4 0 0 1-.8-1.78V12.19c0-1.21.9-2.23 2.11-2.37l35.5-4.06a2.39 2.39 0 0 1 2.65 2.37v19.85a2.39 2.39 0 0 1-2.11 2.37l-35.5 4.06-.27.01zm2.38 13.9v46.62l30.73-3.52v-46.6l-30.73 3.5zM7.38 100A2.38 2.38 0 0 1 5 97.61V46.2c0-1.22.9-2.24 2.11-2.38l35.5-4.06a2.36 2.36 0 0 1 1.85.6c.5.45.8 1.1.8 1.78v51.41a2.39 2.39 0 0 1-2.12 2.38L7.65 99.98l-.27.02zm78.33-27.16a2.04 2.04 0 0 0 1.8-2.26 2.04 2.04 0 0 0-2.26-1.8l-8.34.95v-8.36a2.04 2.04 0 1 0-4.08 0v8.83l-8.8 1a2.05 2.05 0 0 0-1.8 2.27 2.04 2.04 0 0 0 2.26 1.8l8.34-.95v8.35a2.04 2.04 0 1 0 4.08 0v-8.82l8.8-1zm8.5-22.44c.5.45.79 1.1.79 1.78V87.8a2.38 2.38 0 0 1-2.11 2.37l-35.5 4.06a2.37 2.37 0 0 1-1.85-.59 2.39 2.39 0 0 1-.8-1.78V56.24c0-1.22.91-2.24 2.11-2.38l35.5-4.06c.68-.07 1.35.14 1.85.6zM59.5 8.58V39.4l30.73-3.51V5.07L59.51 8.58zm-2.39 35.89c-.57 0-1.14-.22-1.58-.6a2.4 2.4 0 0 1-.8-1.8V6.46c0-1.22.91-2.24 2.12-2.37L92.35.02A2.36 2.36 0 0 1 94.2.6c.51.45.8 1.1.8 1.78v35.63a2.39 2.39 0 0 1-2.11 2.37l-35.5 4.06-.26.02z" fill="currentColor"/>'
  },
  megaphone: {
    width: 15,
    height: 15,
    block: '<path d="M96.37 50.38a2.5 2.5 0 0 1-3.32 1.23 2.51 2.51 0 0 1-1.23-3.32c3.78-8.24 4.2-17.03 1.2-24.74A26 26 0 0 0 76.28 7.9a2.5 2.5 0 0 1-1.64-3.14 2.5 2.5 0 0 1 3.13-1.64 30.93 30.93 0 0 1 19.9 18.6c3.5 9 3.04 19.18-1.3 28.66zm-9.6-23.33c2.41 6.19 2.13 13.2-.78 19.73a2.5 2.5 0 0 1-3.3 1.27 2.51 2.51 0 0 1-1.26-3.31c2.36-5.3 2.6-10.94.69-15.86a16.78 16.78 0 0 0-10.6-10.02 2.5 2.5 0 0 1-1.6-3.16 2.5 2.5 0 0 1 3.16-1.6 21.7 21.7 0 0 1 13.7 12.95zM28.62 64.47l-5.19-13.31-.78-2.02 34.22-32.67 16.4 42.1-44.65 5.9zm-13.6 5.82L9.54 56.24l8.82-4.3 5.47 14.04-8.82 4.3zm45.15-59.12a2.5 2.5 0 0 0-1.78-1.53 2.5 2.5 0 0 0-2.27.63L18.26 46.4 5.28 52.75a2.5 2.5 0 0 0-1.23 3.17l.26.67C.64 59.5-1 64.51.64 68.73a8.88 8.88 0 0 0 5.08 5.1 9.45 9.45 0 0 0 3.45.65c.68 0 1.35-.08 2.03-.22l.15.38a2.5 2.5 0 0 0 2.32 1.6c.38 0 .76-.09 1.1-.26l11.22-5.48L41 96.74a2.5 2.5 0 0 0 3.27 1l14-6.84a2.5 2.5 0 0 0 1.07-3.5L47.68 67l29.39-3.89a2.5 2.5 0 0 0 1.82-1.2c.4-.67.46-1.48.18-2.2L60.16 11.18z" fill="currentColor"/>'
  },
  menu: {
    width: 15,
    height: 15,
    block: '<path d="M4.55 79.9l90.416-9.15A4.574 4.574 0 0 1 100 75.3v.487a5.06 5.06 0 0 1-4.55 5.034L5.033 89.97A4.574 4.574 0 0 1 0 85.42v-.487A5.06 5.06 0 0 1 4.55 79.9zm0-30.36l90.416-9.15A4.574 4.574 0 0 1 100 44.94v.486a5.06 5.06 0 0 1-4.55 5.035L5.033 59.61A4.574 4.574 0 0 1 0 55.06v-.487a5.06 5.06 0 0 1 4.55-5.035zm0-30.36l90.416-9.15A4.574 4.574 0 0 1 100 14.58v.486a5.06 5.06 0 0 1-4.55 5.034L5.033 29.25A4.574 4.574 0 0 1 0 24.7v-.487a5.06 5.06 0 0 1 4.55-5.034z" fill="currentColor" fill-rule="evenodd"/>'
  },
  mic: {
    width: 15,
    height: 15,
    block: '<path d="M50.42 80.6a3.76 3.76 0 0 0 4.72 1.96A3.8 3.8 0 0 0 57.5 78l-4.62-17.45a11.45 11.45 0 0 1-4.6 3.1 11.52 11.52 0 0 1-3.96.7c-.53 0-1.06-.03-1.58-.1l7.68 16.35zM32.83 41.83c-.43 0-.87-.03-1.3-.05l6.4 14.14a7.06 7.06 0 0 0 8.86 3.64 7.12 7.12 0 0 0 4.45-8.52l-4.12-14.95a20.73 20.73 0 0 1-14.29 5.74zm56.04 5.33a2.19 2.19 0 0 1-1.3 2.8 2.17 2.17 0 0 1-2.79-1.3l-1.48-4.1a8.18 8.18 0 1 0-15.37 5.63L79.83 83a12.63 12.63 0 0 1-.43 9.68 12.54 12.54 0 0 1-7.11 6.55 12.57 12.57 0 0 1-9.64-.42 12.56 12.56 0 0 1-6.51-7.14l-1.66-4.56c-.22.02-.44.06-.66.06a8.1 8.1 0 0 1-7.34-4.7L36.5 61.2a11.54 11.54 0 0 1-2.5-3.45l-7.7-17a20.81 20.81 0 0 1-13.03-12.69A20.95 20.95 0 0 1 25.69 1.27a20.6 20.6 0 0 1 15.92.7 20.74 20.74 0 0 1 10.76 11.8 20.85 20.85 0 0 1-.7 15.98c-.35.75-.75 1.47-1.18 2.17l4.95 17.98a11.74 11.74 0 0 1 .29 4.44l5.98 22.55a8.13 8.13 0 0 1-3.14 8.72l1.65 4.56a8.22 8.22 0 0 0 4.27 4.68 8.16 8.16 0 0 0 6.31.27 8.21 8.21 0 0 0 4.66-4.28 8.27 8.27 0 0 0 .28-6.34l-11.9-32.83a12.61 12.61 0 0 1 7.49-16.13c6.5-2.37 13.7 1 16.06 7.52l1.48 4.09zM40.89 49.9l-1.18-3.24a2.19 2.19 0 0 1 1.3-2.8 2.17 2.17 0 0 1 2.8 1.3l1.17 3.24a2.19 2.19 0 0 1-2.04 2.94c-.9 0-1.73-.55-2.05-1.44z" fill="currentColor"/>'
  },
  microship: {
    width: 15,
    height: 15,
    block: '<path d="M70.89 34.21c.55.5.86 1.2.86 1.94V59.6a2.6 2.6 0 0 1-2.3 2.57l-4.65.54v4.64a2.6 2.6 0 0 1-2.3 2.57L39.09 72.6a2.6 2.6 0 0 1-2.02-.65 2.6 2.6 0 0 1-.86-1.93v-4.05l-4.07.46a2.6 2.6 0 0 1-2.02-.64 2.6 2.6 0 0 1-.86-1.94V40.4a2.6 2.6 0 0 1 2.3-2.57l4.65-.53v-4.65a2.6 2.6 0 0 1 2.3-2.57l23.42-2.67a2.59 2.59 0 0 1 2.88 2.57v4.05l4.07-.46a2.58 2.58 0 0 1 2.02.64zm9.22 42.04L20.89 83V23.75l8.47-.96 42.86-4.9 7.89-.9v59.26zm15.6-35.83a2.6 2.6 0 0 0-.6-5.15l-9.82 1.12v-9.2L95.7 26a2.6 2.6 0 0 0 2.28-2.87 2.6 2.6 0 0 0-2.86-2.29l-9.83 1.12V14.1a2.6 2.6 0 0 0-.86-1.94 2.6 2.6 0 0 0-2.02-.64l-7.89.9V2.6A2.6 2.6 0 0 0 71.93 0a2.6 2.6 0 0 0-2.59 2.6V13l-9.22 1.05V4.24a2.6 2.6 0 0 0-2.6-2.6 2.6 2.6 0 0 0-2.59 2.6v10.4l-8.86 1.02V5.84a2.6 2.6 0 0 0-2.6-2.6 2.6 2.6 0 0 0-2.58 2.6v10.41l-2.98.34-6.25.71V7.48a2.6 2.6 0 1 0-5.18 0V17.9l-8.47.97a2.6 2.6 0 0 0-2.3 2.57v8.47L5.3 31.1a2.6 2.6 0 0 0-2.28 2.86 2.6 2.6 0 0 0 2.87 2.29l9.82-1.12v9.2L5.3 45.5a2.6 2.6 0 0 0-2.28 2.87 2.6 2.6 0 0 0 2.87 2.29l9.82-1.12v8.84L5.3 59.58a2.6 2.6 0 0 0-2.28 2.87 2.6 2.6 0 0 0 2.87 2.28l9.82-1.12v9.2L5.3 74.01a2.6 2.6 0 0 0-2.28 2.86 2.6 2.6 0 0 0 2.87 2.28l9.82-1.12v7.88c0 .74.31 1.45.86 1.94a2.6 2.6 0 0 0 2.02.64l7.9-.9v9.82a2.6 2.6 0 1 0 5.17 0V87l9.23-1.05v9.81a2.6 2.6 0 0 0 5.18 0v-10.4l8.86-1.02v9.82a2.6 2.6 0 1 0 5.19 0v-10.4l9.22-1.06v9.82a2.6 2.6 0 0 0 2.6 2.6 2.6 2.6 0 0 0 2.58-2.6V82.1l8.48-.97a2.6 2.6 0 0 0 2.3-2.57V70.1l10.4-1.2a2.6 2.6 0 0 0 2.28-2.86 2.6 2.6 0 0 0-2.86-2.29l-9.83 1.12v-9.2L95.7 54.5a2.6 2.6 0 0 0 2.28-2.87 2.59 2.59 0 0 0-2.86-2.29l-9.83 1.12v-8.84l10.41-1.19z" fill="currentColor"/>'
  },
  money: {
    width: 15,
    height: 15,
    block: '<path d="M54.63 54.18a2.5 2.5 0 0 1 2.77 2.2 2.5 2.5 0 0 1-2.2 2.75l-15.03 1.7a14.91 14.91 0 0 0-.09 5.23l14.56-1.65a2.5 2.5 0 0 1 2.76 2.2 2.49 2.49 0 0 1-2.2 2.75l-13.4 1.52a12.64 12.64 0 0 0 2.43 2.95 13.5 13.5 0 0 0 10.68 3.2c3.2-.37 6.3-1.7 8.94-3.87a2.5 2.5 0 0 1 3.5.35 2.48 2.48 0 0 1-.34 3.5 22.17 22.17 0 0 1-13.88 5.1c-4.6 0-8.88-1.59-12.23-4.56a17.64 17.64 0 0 1-4.41-6.07l-3.96.45a2.5 2.5 0 0 1-2.76-2.19 2.49 2.49 0 0 1 2.2-2.75l3.15-.36a19.98 19.98 0 0 1-.22-2.87c0-.79.06-1.57.15-2.34l-2.52.29a2.49 2.49 0 0 1-2.76-2.2 2.49 2.49 0 0 1 2.2-2.75l4.34-.5c2.94-7.72 10.16-13.8 18.6-14.75 4.24-.48 8.31.35 11.8 2.41a2.49 2.49 0 0 1 .86 3.41 2.5 2.5 0 0 1-3.41.88 13.87 13.87 0 0 0-8.68-1.75c-5.7.65-10.68 4.28-13.4 9.15l12.55-1.42zM68.1 30.44c-5.2-4.47-10.14-8.75-13.63-13.86C62.44 13.62 66.05 3.8 66.22 3.33a2.49 2.49 0 0 0-.8-2.78 2.5 2.5 0 0 0-2.88-.17L50.25 8.07 38.06 3.21a2.5 2.5 0 0 0-2.69.55 2.48 2.48 0 0 0-.55 2.69c.16.4 3.53 8.6 11.4 10.55-3.47 4.85-8.23 9.03-13.24 13.38C23.16 38.94 13 47.78 13 62.6A37.5 37.5 0 0 0 50.5 100 37.5 37.5 0 0 0 88 62.6c0-15.03-10.12-23.74-19.91-32.16z" fill="currentColor"/>'
  },
  more: {
    width: 15,
    height: 15,
    block: '<path d="M10.034 64.5a11.04 11.04 0 0 1-1.95-.171 15.906 15.906 0 0 1-1.891-.57 10.067 10.067 0 0 1-1.72-.942 8.928 8.928 0 0 1-1.52-1.226C1.089 59.737 0 57.14 0 54.517c0-.627.086-1.283.2-1.94.144-.627.316-1.254.574-1.853a11.04 11.04 0 0 1 .918-1.74 10.714 10.714 0 0 1 2.78-2.767 12.356 12.356 0 0 1 1.72-.913 11.953 11.953 0 0 1 1.893-.57 10.113 10.113 0 0 1 3.928 0c.63.142 1.261.314 1.863.57.602.257 1.204.57 1.749.913.545.37 1.06.799 1.52 1.255a8.9 8.9 0 0 1 1.232 1.512c.373.542.688 1.112.946 1.74.23.599.43 1.226.545 1.854.144.656.2 1.312.2 1.94 0 .655-.056 1.311-.2 1.967a10.564 10.564 0 0 1-.545 1.854 10.238 10.238 0 0 1-.946 1.74 8.9 8.9 0 0 1-1.232 1.512 8.928 8.928 0 0 1-1.52 1.226c-.545.371-1.147.685-1.749.941-.602.229-1.233.428-1.863.57-.66.115-1.32.172-1.979.172zM50 59.993c-2.638 0-5.218-1.084-7.082-2.938-.487-.456-.888-.97-1.261-1.511a9.84 9.84 0 0 1-.917-1.712 9.437 9.437 0 0 1-.574-1.882 9.099 9.099 0 0 1-.2-1.94c0-.656.057-1.312.2-1.968a8.662 8.662 0 0 1 .574-1.854c.258-.599.544-1.198.917-1.74s.774-1.055 1.261-1.511c3.727-3.708 10.465-3.708 14.192 0 1.864 1.854 2.924 4.45 2.924 7.073a9.997 9.997 0 0 1-2.924 7.045c-.487.457-.975.885-1.548 1.255-.545.343-1.118.656-1.72.913-.602.257-1.233.428-1.893.57-.63.115-1.29.2-1.95.2zm39.966-4.534a9.29 9.29 0 0 1-1.979-.2 8.773 8.773 0 0 1-1.863-.57 9.926 9.926 0 0 1-1.72-.913c-.574-.371-1.061-.799-1.549-1.255a9.997 9.997 0 0 1-2.924-7.045c0-2.624 1.06-5.191 2.924-7.074a10.79 10.79 0 0 1 1.549-1.226 8.298 8.298 0 0 1 1.72-.913 8.773 8.773 0 0 1 1.863-.57 10.112 10.112 0 0 1 3.928 0 8.5 8.5 0 0 1 1.892.57 8.298 8.298 0 0 1 1.72.913c.545.37 1.061.77 1.52 1.226.459.457.889.97 1.261 1.54.345.542.66 1.113.918 1.712s.43 1.226.573 1.882c.115.628.201 1.284.201 1.94 0 2.624-1.09 5.19-2.953 7.045-.459.456-.975.884-1.52 1.255a9.926 9.926 0 0 1-1.72.913 8.533 8.533 0 0 1-1.892.57c-.63.143-1.29.2-1.95.2z" fill="currentColor" fill-rule="evenodd"/>'
  },
  mountain: {
    width: 15,
    height: 15,
    block: '<path d="M73.5 63.1l-9.69-16.2 5.5-26.73L93.64 60.8 73.5 63.1zM27.89 84.83L41.45 18.9l36.08 60.26-49.65 5.68zm71.78-23.3l-29.4-49.1-.04-.05a2.41 2.41 0 0 0-.42-.5l-.02-.02a2.4 2.4 0 0 0-.53-.35l-.08-.04-.06-.03c-.07-.03-.13-.02-.2-.04a2.26 2.26 0 0 0-.52-.11h-.59l-.18.06a2.61 2.61 0 0 0-.7.32 2.14 2.14 0 0 0-.25.17 2.3 2.3 0 0 0-.35.4c-.04.05-.1.08-.13.13L54.32 31.06 42.4 11.15l-.04-.05a2.37 2.37 0 0 0-.42-.5l-.02-.02a2.4 2.4 0 0 0-.53-.35l-.08-.04-.07-.03c-.06-.03-.13-.02-.2-.04a2.36 2.36 0 0 0-.5-.12h-.32l-.28.01-.18.06a2.42 2.42 0 0 0-.7.32 2.49 2.49 0 0 0-.25.17 2.38 2.38 0 0 0-.35.39c-.04.05-.1.09-.13.14L.38 70.86a2.41 2.41 0 0 0 .66 3.27l22.47 15.45.06.03c.16.1.33.18.51.24a2.38 2.38 0 0 0 .79.15l.27-.01 56.63-6.48a2.4 2.4 0 0 0 1.88-1.33c.36-.73.32-1.6-.1-2.3l-7.33-12.25 21.66-2.48a2.4 2.4 0 0 0 1.87-1.32 2.41 2.41 0 0 0-.1-2.3z" fill="currentColor"/>'
  },
  music: {
    width: 15,
    height: 15,
    block: '<path d="M20.9 65.82c-.5.06-.98.08-1.46.08-2.89 0-5.56-1-7.67-2.88A11.48 11.48 0 0 1 8 54.34c0-6.82 5.52-12.99 12.3-13.77 2.78-.31 5.42.3 7.63 1.7V2.63A2.64 2.64 0 0 1 29.53.2c.98-.41 2.11-.2 2.87.54L47.02 15.1a2.65 2.65 0 0 1 .04 3.74 2.63 2.63 0 0 1-3.72.04L33.19 8.92v43.14c0 6.81-5.51 12.98-12.3 13.76zm59.2 15.24a6.32 6.32 0 0 1-5.02-1.5 6.25 6.25 0 0 1-2.01-4.74 8.8 8.8 0 0 1 7.63-8.51 7.58 7.58 0 0 1 .84-.05c1.59 0 3.05.53 4.18 1.54a6.26 6.26 0 0 1 2.01 4.74 8.8 8.8 0 0 1-7.63 8.52zM53.13 48.92V38.53l34.6-11.8V37.1l-34.6 11.8zm-12.9 45.75c-1.9.22-3.7-.31-5.01-1.5a6.24 6.24 0 0 1-2.02-4.74 8.8 8.8 0 0 1 8.47-8.56c1.6 0 3.06.53 4.18 1.54a6.25 6.25 0 0 1 2.02 4.74 8.8 8.8 0 0 1-7.63 8.52zM93 23.03c0-.13-.03-.26-.05-.39l-.01-.15-.1-.33-.09-.21a2.78 2.78 0 0 0-.48-.73l-.2-.18c-.06-.05-.1-.11-.17-.16-.02 0-.04-.01-.05-.03a2.72 2.72 0 0 0-.47-.25l-.2-.06a2.45 2.45 0 0 0-.36-.1l-.23-.03-.23-.02-.12.01a2.78 2.78 0 0 0-.61.1l-.1.03-39.88 13.61-.05.03c-.23.08-.44.2-.64.34l-.1.08c-.17.14-.32.3-.45.46l-.06.08a2.67 2.67 0 0 0-.32.63l-.05.15a2.6 2.6 0 0 0-.11.73v39.72c-2.21-1.4-4.85-2-7.63-1.69-6.78.77-12.3 6.95-12.3 13.76 0 3.42 1.34 6.5 3.77 8.69a11.36 11.36 0 0 0 9.12 2.8c6.78-.78 12.3-6.95 12.3-13.77V54.5l34.6-11.81v20.06c-2.21-1.4-4.85-2-7.63-1.69-6.78.78-12.3 6.95-12.3 13.76 0 3.42 1.34 6.5 3.78 8.69a11.35 11.35 0 0 0 9.11 2.8c6.79-.78 12.3-6.95 12.3-13.77l.01-49.5z" fill="currentColor"/>'
  },
  negative: {
    width: 15,
    height: 15,
    block: '<path d="M73.2 73.3a4.6 4.6 0 0 1-6.18-1.93c-3.1-5.9-9.4-9.06-16.5-8.25-7.33.83-14.18 5.87-17.45 12.84a4.59 4.59 0 0 1-4.16 2.63c-.65 0-1.3-.14-1.93-.43a4.54 4.54 0 0 1-2.22-6.05c4.66-9.94 14.13-16.85 24.72-18.05 10.78-1.22 20.86 3.92 25.67 13.1a4.54 4.54 0 0 1-1.94 6.14zM32.83 29.95a5.77 5.77 0 0 1 6.57 5.8c0 3.43-2.7 6.43-6.15 6.82a6.7 6.7 0 0 1-.74.04 5.76 5.76 0 0 1-5.84-5.84c0-3.44 2.71-6.43 6.16-6.82zm33.94-3.85a5.78 5.78 0 0 1 6.57 5.8c0 3.44-2.7 6.44-6.16 6.83a6.7 6.7 0 0 1-.73.04 5.77 5.77 0 0 1-5.84-5.84c0-3.44 2.7-6.44 6.16-6.83zm18.56-15C75.8 2.63 63.11-1.2 49.63.33 22.28 3.43 0 28.09 0 55.3c0 13.29 5.21 25.22 14.67 33.6C22.84 96.16 33.3 100 44.59 100c1.9 0 3.83-.11 5.77-.33C77.73 96.57 100 71.91 100 44.7c0-13.28-5.2-25.22-14.67-33.61z" fill="currentColor"/>'
  },
  negative_outline: {
    width: 15,
    height: 15,
    block: '<path d="M49.636 93.332c24.232-2.743 43.945-24.56 43.945-48.63 0-11.444-4.448-21.69-12.525-28.855C74.082 9.662 65.106 6.38 55.38 6.38c-1.654 0-3.329.095-5.018.286C26.132 9.411 6.42 31.227 6.42 55.3c0 11.443 4.446 21.69 12.525 28.854C27.102 91.389 38 94.65 49.636 93.333zM85.33 11.088C94.789 19.478 100 31.417 100 44.7c0 27.212-22.268 51.87-49.638 54.97-1.94.22-3.866.329-5.768.329-11.296 0-21.758-3.842-29.925-11.086C5.209 80.522 0 68.584 0 55.299 0 28.089 22.266 3.429 49.636.329 63.106-1.2 75.788 2.626 85.33 11.089zM32.504 42.613c-1.467 0-2.832-.505-3.907-1.458-1.245-1.105-1.929-2.662-1.929-4.384 0-3.438 2.705-6.434 6.157-6.826 1.744-.192 3.388.306 4.64 1.416 1.244 1.105 1.93 2.661 1.93 4.384 0 3.436-2.704 6.434-6.155 6.826a6.657 6.657 0 0 1-.736.042zM66.44 38.77c-1.467 0-2.834-.505-3.907-1.458-1.245-1.103-1.929-2.66-1.929-4.384 0-3.436 2.705-6.435 6.157-6.825 1.755-.19 3.388.307 4.64 1.417 1.246 1.102 1.932 2.66 1.932 4.382 0 3.437-2.706 6.436-6.157 6.826a6.683 6.683 0 0 1-.736.042zM49.48 54.06c10.78-1.221 20.855 3.917 25.672 13.091a4.54 4.54 0 0 1-1.944 6.147c-2.243 1.164-5.015.3-6.189-1.932-3.09-5.892-9.414-9.05-16.5-8.25-7.33.83-14.177 5.87-17.449 12.843a4.59 4.59 0 0 1-4.16 2.632 4.581 4.581 0 0 1-1.934-.428 4.544 4.544 0 0 1-2.218-6.056c4.66-9.932 14.134-16.847 24.722-18.047z" fill="currentColor"/>'
  },
  negative_straigth: {
    width: 15,
    height: 15,
    block: '<path d="M73.112 75.893a4.584 4.584 0 0 1-6.139-2.087C63.758 67.28 57.256 63.226 50 63.226c-7.254 0-13.757 4.054-16.969 10.58a4.586 4.586 0 0 1-8.23-4.052c4.771-9.682 14.424-15.698 25.2-15.698 10.773 0 20.429 6.014 25.2 15.696a4.586 4.586 0 0 1-2.088 6.14M33.03 27.875a6.371 6.371 0 0 1 6.364 6.365 6.371 6.371 0 0 1-6.364 6.364c-3.509 0-6.36-2.856-6.36-6.364 0-3.509 2.851-6.365 6.36-6.365m33.938 0a6.37 6.37 0 0 1 6.363 6.365 6.37 6.37 0 0 1-6.363 6.364 6.37 6.37 0 0 1-6.362-6.364 6.37 6.37 0 0 1 6.362-6.365M50 0C22.43 0 0 22.43 0 50s22.43 50 50 50 50-22.43 50-50S77.57 0 50 0" fill="currentColor"/>'
  },
  offer_status: {
    width: 15,
    height: 15,
    block: '<path d="M81.83 18.48a2.4 2.4 0 0 0-.18-3.4 2.41 2.41 0 0 0-3.4.18l-11 12.24-5.64-4.99a2.41 2.41 0 0 0-3.4.2 2.4 2.4 0 0 0 .2 3.4l7.44 6.57a2.4 2.4 0 0 0 3.39-.19l12.6-14.01zM12.32 94.9L66.75 89V45.1a20.43 20.43 0 0 1-8.01-1.97 2.4 2.4 0 0 1-1.25.52l-35.4 3.8a2.4 2.4 0 0 1-2.65-2.13 2.4 2.4 0 0 1 2.13-2.65l31.77-3.41a20.13 20.13 0 0 1-5.78-14.27l-35.24 3.83v66.1zM92.5 20.3c0 11.8-9.28 22.5-20.93 24.49v46.37a2.4 2.4 0 0 1-2.15 2.4L10.17 100a2.42 2.42 0 0 1-1.87-.6 2.4 2.4 0 0 1-.8-1.8V26.66a2.4 2.4 0 0 1 2.15-2.39l38.42-4.18C50.23 9.87 59.13 1.36 69.76.15c6.07-.7 11.8 1.04 16.1 4.89a20.08 20.08 0 0 1 6.64 15.25zM56.98 54.64a2.4 2.4 0 0 1 .51 4.78l-35.4 3.8a2.4 2.4 0 0 1-2.66-2.13 2.4 2.4 0 0 1 2.14-2.64l35.4-3.8zm0 15.73a2.4 2.4 0 0 1 .51 4.78l-35.4 3.8a2.4 2.4 0 0 1-2.66-2.13 2.4 2.4 0 0 1 2.14-2.65l35.4-3.8z" fill="currentColor"/>'
  },
  'ordered-list': {
    width: 15,
    height: 15,
    block: '<path d="M39.733 7.653c0-2.542 2.072-4.602 4.624-4.602h76.02c2.551 0 4.623 2.06 4.623 4.602 0 2.542-2.07 4.602-4.624 4.602h-76.02c-2.551 0-4.623-2.06-4.623-4.602zm4.624 27.1H93.67c2.553 0 4.623-2.06 4.623-4.602 0-2.542-2.07-4.602-4.623-4.602H44.357c-2.552 0-4.624 2.058-4.624 4.602 0 2.544 2.072 4.603 4.624 4.603zm76.02 33.545h-76.02c-2.552 0-4.624 2.06-4.624 4.603 0 2.542 2.072 4.602 4.624 4.602h76.02c2.551 0 4.623-2.06 4.623-4.602 0-2.543-2.072-4.603-4.624-4.603zm-26.71 22.498h-49.31c-2.552 0-4.624 2.058-4.624 4.602 0 2.542 2.072 4.602 4.624 4.602H93.67c2.553 0 4.623-2.06 4.623-4.602 0-2.543-2.072-4.602-4.625-4.602zM11.103 37.015h7.339V0h-6.01c-.17 1.933-.022 3.488-1.54 4.659-1.517 1.172-4.708 1.756-7.59 1.756H2.251v5.117h8.85v25.483zm6.508 49.063c3.177-2.172 5.263-4.186 6.264-6.045a12.46 12.46 0 0 0 1.498-5.997c0-3.496-1.175-6.316-3.52-8.465-2.347-2.146-5.431-3.219-9.254-3.219-3.686 0-6.636 1.086-8.845 3.26C1.54 67.783.437 71.058.437 75.439h7.11c0-2.616.464-4.421 1.394-5.424.929-1 2.203-1.502 3.824-1.502 1.62 0 2.902.51 3.849 1.526.946 1.018 1.418 2.283 1.418 3.795 0 1.51-.438 2.875-1.318 4.097-.877 1.223-3.319 3.287-7.327 6.188C5.96 86.615 1.469 89.654.079 91.86L0 99.367h25.45v-6.465H8.393l9.217-6.824z" fill="currentColor"/>'
  },
  origine: {
    width: 15,
    height: 15,
    block: '<path d="M8.53 71.45a35.92 35.92 0 0 0 8.31 11.52 37.58 37.58 0 0 0 21.24 9.65c-4.17-5.03-7.4-13.34-9.11-23.5L8.53 71.45zm29-61.35A51.19 51.19 0 0 0 8.76 37.61l20.13-2.29c1.57-9.97 4.52-19.1 8.63-25.22zm50.92 18.45a35.92 35.92 0 0 0-8.82-11.96 37.6 37.6 0 0 0-20.69-9.2c4.2 4.96 7.4 13.25 9.1 23.48l20.4-2.32zM34.1 34.73l28.87-3.28C61.2 20.85 57.73 12.58 53.4 9c-1.55-1.28-3.06-1.82-4.63-1.64-5.72.65-11.94 11.34-14.67 27.36zM28.26 64.1a107 107 0 0 1-.67-12c0-3.85.22-7.75.63-11.58L6.87 42.94a45.05 45.05 0 0 0-1.32 6.07c-.02.07-.02.16-.03.24a42.57 42.57 0 0 0-.28 2.52l-.05.67a42.6 42.6 0 0 0-.01 5.4l.05.62c.06.82.14 1.64.26 2.45v.1c.14.92.3 1.82.5 2.72l.03.16c.2.9.42 1.78.68 2.65l21.56-2.45zm20.67 32.47l-.1.14c-.05.08-.1.17-.17.24l-.13.14-.2.2-.17.11-.22.15-.19.09a2.6 2.6 0 0 1-.45.15c-.09.03-.19.04-.28.05l-.12.03a50.14 50.14 0 0 1-3.78.14c-11.33 0-21.77-3.95-29.74-11.31A41.49 41.49 0 0 1 .67 63.01a44.17 44.17 0 0 1-.49-3.74l-.03-.51A47.29 47.29 0 0 1 0 55.23c0-1.17.06-2.32.14-3.47a47.68 47.68 0 0 1 .47-4.13l.09-.46c.18-1.08.4-2.15.65-3.2l.1-.48c.28-1.1.6-2.19.94-3.26.05-.14.07-.28.12-.41.01-.05.04-.08.06-.12C9.03 20.27 27.04 4.73 48.2 2.33 61.4.83 73.76 4.55 83.02 12.8a41.4 41.4 0 0 1 13.3 24.28l.03.12c.19 1.16.34 2.33.44 3.52l.04.53c.09 1.16.14 2.34.14 3.53a2.54 2.54 0 0 1-2.54 2.54 2.54 2.54 0 0 1-2.55-2.54c0-.89-.03-1.76-.09-2.63l-.04-.61a40.22 40.22 0 0 0-.26-2.42l-.02-.14a38.83 38.83 0 0 0-1.2-5.52L68.73 35.9c.12 1.16.24 2.33.33 3.53a2.54 2.54 0 0 1-2.34 2.72 2.55 2.55 0 0 1-2.73-2.34 98.64 98.64 0 0 0-.32-3.34l-30.3 3.45a106.84 106.84 0 0 0-.69 12.16c0 4.03.23 7.85.64 11.43l5.37-.61a2.54 2.54 0 1 1 .58 5.04l-5.24.6c2.44 14.27 7.85 23.58 12.99 24.25h.01a2.54 2.54 0 0 1 2.09 1.74c0 .03.03.06.03.1.04.12.06.25.07.38l.02.11c.02.24 0 .47-.05.69-.02.1-.03.2-.07.3l-.06.15-.13.29zM60.8 82.69c5.27 4.57 13.99 3.43 19.44-2.55a15.2 15.2 0 0 0 4.13-10.97 11.2 11.2 0 0 0-3.77-7.91 11.78 11.78 0 0 0-7.82-2.8c-4.09 0-8.42 1.84-11.62 5.35a15.21 15.21 0 0 0-4.13 10.97 11.2 11.2 0 0 0 3.77 7.9zm37.7 7.66a4.35 4.35 0 0 1 .42 6.14 4.36 4.36 0 0 1-3.3 1.5 4.35 4.35 0 0 1-2.86-1.07l-9.23-8.03a24.4 24.4 0 0 1-14.93 5.28c-4.92 0-9.72-1.61-13.52-4.92a19.82 19.82 0 0 1-6.75-13.96 23.94 23.94 0 0 1 6.38-17.34c8.63-9.46 22.81-10.92 31.62-3.26a19.82 19.82 0 0 1 6.75 13.97c.28 4.76-1.05 9.6-3.7 13.78l9.11 7.91z" fill="currentColor"/>'
  },
  paperplane: {
    width: 15,
    height: 15,
    block: '<path d="M81.4 85.26L52.9 73.95l39.45-58.83L81.4 85.26zm-2.68-60.05l-32.5 48.46-.03.04-.14.25-.11.22-.02.05-.07.21-.08.27-2.76 13.2-8.33-18.85 44.04-43.85zm.05-8.09L30.59 65.1l-19.33-7.67 67.51-40.3zM100 2.83v-.07l-.02-.14a2.72 2.72 0 0 0-.04-.34c-.01-.03 0-.07-.02-.1l-.03-.09a2.81 2.81 0 0 0-.26-.66l-.04-.04a2.8 2.8 0 0 0-.43-.54c-.02-.03-.03-.06-.06-.08l-.1-.1c-.02 0-.02-.02-.03-.03l-.03-.01-.04-.04-.06-.03a2.88 2.88 0 0 0-.75-.4l-.04-.01a2.81 2.81 0 0 0-.82-.14h-.07c-.02 0-.05-.01-.07 0h-.14c-.06 0-.13 0-.2.02l-.1.03a2.9 2.9 0 0 0-.33.08 3 3 0 0 0-.2.07c-.12.04-.23.1-.33.15l-.14.07L3.38 55.51a2.83 2.83 0 0 0 .41 5.07l25.35 10.06L41.38 98.3v.01c.04.07.1.13.13.2.1.18.2.36.35.52.05.06.13.12.2.18.15.13.3.26.46.36l.06.05c.12.07.25.1.38.15l.26.11c.25.07.5.1.76.1v.01H44l.3-.01.06-.02c.26-.04.52-.1.76-.2l.12-.07c.23-.1.45-.24.64-.41l.04-.03a.45.45 0 0 0 .02-.01L62.57 83.9l20.05 7.96a2.88 2.88 0 0 0 2.47-.17 2.84 2.84 0 0 0 1.4-2.03L99.97 3.33l.01-.16a2.88 2.88 0 0 0 .02-.34z" fill="currentColor"/>'
  },
  pencil: {
    width: 15,
    height: 15,
    block: '<path d="M36.89 78.23l-5.36-4.76 39.53-44.14 5.36 4.76L36.9 78.23zM22.66 86.3l-6.84-6.07 3.88-10.32L32.5 81.3l-9.85 5.01zm39.15-65.2l5.36 4.77L27.64 70l-5.37-4.76L61.81 21.1zM96 18.9a2.6 2.6 0 0 0-.88-1.8L76.62.66a2.6 2.6 0 0 0-3.66.2l-13.3 14.85-43 48.01-.13.17-.11.16a2.58 2.58 0 0 0-.2.4c-.02.03-.05.06-.06.1l-12 31.93a2.6 2.6 0 0 0 3.61 3.24l30.5-15.5.12-.09a2.62 2.62 0 0 0 .5-.38c.05-.04.1-.07.14-.12l43.01-48.01 13.3-14.84a2.61 2.61 0 0 0 .66-1.9z" fill="currentColor"/>'
  },
  phone: {
    width: 15,
    height: 15,
    block: '<path d="M95.221 72.964L79.675 54.205a3.41 3.41 0 0 0-2.349-1.223 3.434 3.434 0 0 0-2.518.818L59.71 66.826c-5.88-2.8-10.964-6.725-15.112-11.671-4.146-5.064-7.116-10.892-8.845-17.35l15.168-13.09a3.38 3.38 0 0 0 .4-4.721L35.775 1.234a3.426 3.426 0 0 0-3.898-.992L25.445 2.8C14.997 6.954 7.02 15.911 4.632 26.177c-.79 3.392-.839 6.138-.15 8.39 4.231 13.85 10.942 26.437 19.947 37.414a4.897 4.897 0 0 0 .39.467c9.105 10.856 20.139 19.675 32.8 26.222 1.726.892 3.854 1.33 6.47 1.33.573 0 1.17-.02 1.79-.062 10.36-.702 20.368-7.24 26.12-17.063l3.538-6.045a3.38 3.38 0 0 0-.316-3.866" fill="currentColor" fill-rule="evenodd"/>'
  },
  phone_outline: {
    width: 15,
    height: 15,
    block: '<path d="M86.1 79.46c-4.63 7.9-12.55 13.16-20.68 13.7-2.81.2-4.12-.24-4.65-.51a99.5 99.5 0 0 1-30.85-24.71 1.75 1.75 0 0 0-.08-.09 1.2 1.2 0 0 0-.06-.08A101.95 101.95 0 0 1 11.01 32.6c-.18-.6-.4-2.04.27-4.88 1.9-8.14 8.3-15.27 16.7-18.6l4.11-1.65 11.85 14.3-14.23 12.27a3.38 3.38 0 0 0-1.1 3.3 52.85 52.85 0 0 0 10.73 22.14 51.48 51.48 0 0 0 19.62 14.46 3.42 3.42 0 0 0 3.57-.56l14.1-12.17 11.81 14.26-2.34 4zm9.12-6.5L79.67 54.21a3.41 3.41 0 0 0-2.35-1.23 3.41 3.41 0 0 0-2.51.82L59.7 66.82a44.52 44.52 0 0 1-15.1-11.66 45.88 45.88 0 0 1-8.85-17.35l15.17-13.1a3.38 3.38 0 0 0 .4-4.72L35.77 1.23a3.43 3.43 0 0 0-3.9-.99L25.46 2.8C15 6.95 7.02 15.91 4.63 26.18c-.79 3.39-.84 6.14-.15 8.39a108.69 108.69 0 0 0 20 37.48l.13.16.2.24a106.26 106.26 0 0 0 32.81 26.22c1.72.89 3.85 1.33 6.47 1.33.57 0 1.17-.02 1.79-.06 10.36-.7 20.37-7.24 26.11-17.06l3.55-6.05a3.38 3.38 0 0 0-.32-3.87z" fill="currentColor"/>'
  },
  piechart: {
    width: 15,
    height: 15,
    block: '<path d="M19.83 85.04c15.75 11.82 39.48 9 55.28-6.65l-27.4-24.27-27.88 30.92zM5.63 57.7c.52 9.19 4.08 17.47 10.05 23.65l29.74-32.98 29.73-32.98A37.28 37.28 0 0 0 52.59 8.1c-12.34 0-25.23 5.5-34.71 16.02C9.4 33.52 4.94 45.76 5.62 57.7zM51.4 50l29.54 26.16c.55.5.89 1.18.93 1.92a2.76 2.76 0 0 1-.71 2C70.6 91.76 56.2 97.85 42.37 97.85c-10.38 0-20.45-3.41-28.4-10.43h-.01v-.01C5.66 80.09.74 69.66.07 58c-.77-13.4 4.2-27.1 13.66-37.59C32.22-.08 62.4-3.4 81 13.02a2.76 2.76 0 0 1 .23 3.91L51.4 50zM93 21.08c9.1 14.06 9.11 32.75.05 48.76a2.77 2.77 0 0 1-2.42 1.41 2.78 2.78 0 0 1-1.84-.7L65.77 50.24a2.76 2.76 0 0 1-.22-3.92l23.07-25.59a2.8 2.8 0 0 1 2.29-.9 2.78 2.78 0 0 1 2.1 1.25z" fill="currentColor"/>'
  },
  pizza: {
    width: 15,
    height: 15,
    block: '<path d="M55.2 39.38a8.27 8.27 0 0 1 2.74 6.27 9.9 9.9 0 0 1-9.75 9.76 8.26 8.26 0 0 1-5.56-2.09 8.27 8.27 0 0 1-2.75-6.27 9.9 9.9 0 0 1 8.7-9.7 8.38 8.38 0 0 1 6.61 2.03zM84.16 77a74.67 74.67 0 0 0-10.52-35.8 69.4 69.4 0 0 0-26.47-25.1l5.31-9.45a77.02 77.02 0 0 1 29.96 28.22c7.33 12.08 11.38 26.2 11.8 41L84.17 77zm-23.23 2.65c.5-1.18.82-2.46.82-3.8 0-2.45-.98-4.68-2.75-6.26a8.36 8.36 0 0 0-6.6-2.03 9.9 9.9 0 0 0-8.71 9.7c0 1.54.42 2.96 1.14 4.22L8.09 85.67l6.68-11.9c.43.72.92 1.4 1.56 1.97a8.26 8.26 0 0 0 6.6 2.03 9.9 9.9 0 0 0 8.71-9.7c0-2.47-.97-4.7-2.75-6.27a8.32 8.32 0 0 0-6.23-2.06l21.73-38.7a63.72 63.72 0 0 1 24.37 23.13 69.03 69.03 0 0 1 9.75 33.49l-17.57 2zm26.4-47.75A82.76 82.76 0 0 0 52.57.3a2.87 2.87 0 0 0-3.74 1.17L.37 87.74a2.86 2.86 0 0 0 2.82 4.24l94.27-10.73a2.86 2.86 0 0 0 2.54-2.84c0-16.76-4.38-32.84-12.66-46.5z" fill="currentColor"/>'
  },
  play: {
    width: 15,
    height: 15,
    block: '<path d="M16.148 98.172C7.23 102.777 0 98.382 0 88.352V11.659C0 1.63 7.18-2.792 16.148 1.838l77.145 39.83c8.918 4.605 8.967 12.045 0 16.675l-77.145 39.83z" fill="currentColor"/>'
  },
  positive: {
    width: 15,
    height: 15,
    block: '<path d="M75.24 59.95C70.58 69.88 61.11 76.8 50.52 78c-1.06.11-2.1.17-3.14.17-9.56 0-18.19-4.99-22.53-13.26a4.54 4.54 0 0 1 1.94-6.15 4.6 4.6 0 0 1 6.19 1.93c3.1 5.9 9.42 9.06 16.5 8.25 7.33-.83 14.18-5.87 17.45-12.84a4.6 4.6 0 0 1 6.1-2.2 4.54 4.54 0 0 1 2.21 6.05m-42.42-30a5.76 5.76 0 0 1 6.57 5.8c0 3.43-2.7 6.43-6.15 6.82a6.72 6.72 0 0 1-.74.04 5.77 5.77 0 0 1-5.83-5.84c0-3.44 2.7-6.43 6.15-6.82m33.94-3.85a5.76 5.76 0 0 1 6.57 5.8c0 3.44-2.7 6.44-6.16 6.83a6.72 6.72 0 0 1-.73.04 5.77 5.77 0 0 1-5.83-5.84c0-3.44 2.7-6.44 6.15-6.83m18.57-15C75.8 2.62 63.11-1.2 49.63.33 22.28 3.43 0 28.09 0 55.3c0 13.29 5.2 25.22 14.67 33.62C22.84 96.15 33.3 100 44.59 100c1.9 0 3.83-.11 5.77-.33C77.73 96.57 100 71.91 100 44.7c0-13.28-5.21-25.22-14.67-33.61" fill="currentColor"/>'
  },
  positive_outline: {
    width: 15,
    height: 15,
    block: '<path d="M49.636 93.332C73.868 90.59 93.58 68.772 93.58 44.701c0-11.443-4.448-21.69-12.525-28.855-6.974-6.184-15.95-9.465-25.676-9.465-1.654 0-3.329.095-5.018.286C26.132 9.41 6.42 31.227 6.42 55.298c0 11.444 4.446 21.691 12.525 28.855 8.158 7.236 19.055 10.494 30.692 9.18zM85.33 11.087c9.459 8.39 14.67 20.33 14.67 33.614 0 27.212-22.268 51.87-49.638 54.97-1.94.22-3.866.329-5.768.329-11.296 0-21.758-3.842-29.925-11.086C5.209 80.522 0 68.584 0 55.298 0 28.088 22.266 3.428 49.636.33c13.47-1.527 26.152 2.295 35.695 10.758zM32.504 42.612c-1.467 0-2.832-.504-3.907-1.458-1.245-1.104-1.929-2.661-1.929-4.383 0-3.438 2.705-6.435 6.157-6.827 1.744-.19 3.388.306 4.64 1.417 1.244 1.104 1.93 2.66 1.93 4.383 0 3.436-2.704 6.435-6.155 6.827a6.657 6.657 0 0 1-.736.041zM66.44 38.77c-1.467 0-2.834-.505-3.907-1.458-1.245-1.103-1.929-2.66-1.929-4.384 0-3.436 2.705-6.434 6.157-6.824 1.755-.195 3.388.304 4.64 1.416 1.246 1.103 1.932 2.66 1.932 4.382 0 3.438-2.706 6.436-6.157 6.826a6.683 6.683 0 0 1-.736.042zm6.584 15.124a4.542 4.542 0 0 1 2.217 6.055C70.58 69.88 61.106 76.796 50.518 77.995c-1.053.12-2.1.179-3.135.179-9.56 0-18.188-4.99-22.535-13.268a4.544 4.544 0 0 1 1.946-6.148c2.245-1.163 5.014-.3 6.186 1.932 3.095 5.891 9.422 9.052 16.5 8.25 7.327-.83 14.18-5.871 17.451-12.844 1.07-2.28 3.8-3.268 6.093-2.203z" fill="currentColor"/>'
  },
  positive_straigth: {
    width: 15,
    height: 15,
    block: '<path d="M75.2 62.502C70.428 72.184 60.773 78.2 50 78.2s-20.429-6.016-25.2-15.698a4.59 4.59 0 0 1 2.09-6.14 4.59 4.59 0 0 1 6.14 2.089C36.243 64.976 42.747 69.03 50 69.03c7.255 0 13.758-4.056 16.975-10.581a4.585 4.585 0 1 1 8.224 4.053zM33.031 27.876a6.37 6.37 0 0 1 6.364 6.363 6.372 6.372 0 0 1-6.364 6.364 6.37 6.37 0 0 1-6.363-6.364 6.37 6.37 0 0 1 6.363-6.363zm33.938 0a6.368 6.368 0 0 1 6.36 6.363c0 3.508-2.851 6.364-6.36 6.364a6.372 6.372 0 0 1-6.364-6.364 6.37 6.37 0 0 1 6.364-6.363zM50 0C22.43 0 0 22.43 0 50s22.43 50 50 50 50-22.43 50-50S77.57 0 50 0z" fill="currentColor"/>'
  },
  print: {
    width: 15,
    height: 15,
    block: '<path d="M57.88 83.46l-11.64-8.13 32.99-4.29 11.64 8.13-32.99 4.29zm-23.3-1.69c-1.52.2-2.94-.2-4-1.11a4.94 4.94 0 0 1-1.63-3.8V60.41a7.5 7.5 0 0 1 6.28-7.12l50.9-6.7c.26-.03.51-.04.77-.04 1.22 0 2.35.4 3.22 1.16a4.94 4.94 0 0 1 1.64 3.8v16.45c0 1.66-.7 3.27-1.8 4.55l-8.67-6.06a2.5 2.5 0 0 0-1.75-.43l-40.27 5.24a2.46 2.46 0 1 0-1.1 4.47l6.71 4.69-10.3 1.35zm-9.41-60.4l35.31-4.59v15.13l-35.31 4.6V21.36zm14.41 43.11a2.48 2.48 0 0 1-2.45-2.15 2.47 2.47 0 0 1 2.14-2.76l6.9-.88a2.47 2.47 0 1 1 .63 4.9l-6.9.87a2.49 2.49 0 0 1-.31.02zm59.36 14.3l-4.9-3.43a11.96 11.96 0 0 0 2.68-7.4V51.52A9.8 9.8 0 0 0 93.39 44a9.7 9.7 0 0 0-1.71-1.2c-2.5-1.85-20.9-15.52-22.43-16.67-1.2-.9-2.48-1.5-3.8-1.86v-10.3a2.46 2.46 0 0 0-.85-1.85 2.5 2.5 0 0 0-1.96-.6l-40.27 5.24a2.47 2.47 0 0 0-2.16 2.44v10.2l-9.62 1.26C4.75 31.42 0 36.81 0 42.67v16.45a9.8 9.8 0 0 0 3.32 7.51c1.56 1.37 22.73 17 25.14 18.77.36.27.78.4 1.2.44a9.91 9.91 0 0 0 4.13.92c.48 0 .96-.03 1.44-.1l15.66-2.05 4.93 3.44a2.5 2.5 0 0 0 1.75.43l40.27-5.23a2.48 2.48 0 0 0 2.09-1.86 2.46 2.46 0 0 0-.99-2.61z" fill="currentColor"/>'
  },
  promote: {
    width: 15,
    height: 15,
    block: '<path d="M82.059 38.875a2.551 2.551 0 0 0-2.398-1.096L53.098 40.8V2.543A2.544 2.544 0 0 0 51.167.076a2.549 2.549 0 0 0-2.868 1.272l-30.5 57.149a2.54 2.54 0 0 0 .142 2.627 2.55 2.55 0 0 0 2.397 1.097l26.564-3.02v38.255A2.544 2.544 0 0 0 49.45 100c.926 0 1.8-.503 2.25-1.348l30.5-57.15a2.544 2.544 0 0 0-.142-2.627" fill="currentColor" fill-rule="evenodd"/>'
  },
  questions: {
    width: 15,
    height: 15,
    block: '<path d="M6.55 86.65a2.56 2.56 0 0 1-1.7-.65A2.53 2.53 0 0 1 4 84.11V9.33c0-1.3.98-2.38 2.27-2.52L68.9 0a2.5 2.5 0 0 1 1.98.64c.53.48.84 1.17.84 1.89v30.5a2.54 2.54 0 0 1-2.54 2.53 2.54 2.54 0 0 1-2.55-2.53V5.37L9.09 11.6v69.68l19.64-2.13c1.39-.17 2.65.86 2.8 2.25a2.54 2.54 0 0 1-2.25 2.8L6.82 86.63a2.2 2.2 0 0 1-.27.02zm12.6-55.39A2.54 2.54 0 0 1 16.62 29a2.54 2.54 0 0 1 2.26-2.8l36.23-3.88a2.55 2.55 0 0 1 2.81 2.25 2.54 2.54 0 0 1-2.26 2.8l-36.24 3.88-.27.01zm0 16.63a2.54 2.54 0 0 1-2.53-2.26 2.54 2.54 0 0 1 2.26-2.8l28.94-3.1c1.4-.14 2.66.86 2.8 2.26a2.54 2.54 0 0 1-2.25 2.79l-28.95 3.1-.27.01zm0 16.58a2.54 2.54 0 0 1-2.53-2.26 2.54 2.54 0 0 1 2.26-2.8l15.38-1.65a2.55 2.55 0 0 1 2.8 2.25 2.54 2.54 0 0 1-2.25 2.8l-15.39 1.64-.27.02zm53.03 14.56A13.2 13.2 0 0 0 81 66.83c0-3.19-1.26-6.07-3.55-8.1a10.87 10.87 0 0 0-8.57-2.61 13.2 13.2 0 0 0-11.55 12.82 2.54 2.54 0 0 0 2.55 2.53 2.54 2.54 0 0 0 2.55-2.53 8.08 8.08 0 0 1 7.03-7.78c1.75-.2 3.39.28 4.6 1.35a5.67 5.67 0 0 1 1.84 4.32c0 3.2-2.28 6.31-5.42 7.41a5.7 5.7 0 0 0-3.86 5.33v1.86a2.54 2.54 0 0 0 2.55 2.54 2.54 2.54 0 0 0 2.54-2.54v-1.86c0-.28.25-.47.46-.54zM70.98 92c.48-.48.74-1.12.74-1.8a2.54 2.54 0 0 0-3.04-2.48 3.1 3.1 0 0 0-.48.15 2.02 2.02 0 0 0-.44.23 2 2 0 0 0-.4.32 2.54 2.54 0 0 0-.73 1.78 2.51 2.51 0 0 0 1.57 2.35 2.5 2.5 0 0 0 1.47.14c.17-.03.33-.07.48-.14.14-.06.3-.13.43-.24.15-.08.28-.2.4-.32zm17.38-38.12C93.29 58.26 96 64.49 96 71.4c0 14.07-11.49 26.82-25.61 28.43a26.12 26.12 0 0 1-3 .17c-5.86 0-11.3-2-15.56-5.79-4.93-4.37-7.64-10.6-7.64-17.5 0-14.08 11.5-26.83 25.62-28.44 7-.8 13.58 1.2 18.55 5.61z" fill="currentColor"/>'
  },
  quote: {
    width: 15,
    height: 15,
    block: '<path d="M0 41.346C0 25.415 14.442 12.5 32.258 12.5c3.563 0 6.452 2.583 6.452 5.77-.079 3.184-2.97 5.738-6.533 5.768-10.657.04-19.274 7.777-19.274 17.308v2.885h19.355c5.345 0 9.677 3.874 9.677 8.654v25.961c0 4.78-4.332 8.654-9.677 8.654H9.678C4.332 87.5 0 83.626 0 78.846v-37.5zm58.065 37.5c0 4.78 4.332 8.654 9.677 8.654h22.58c5.345 0 9.678-3.874 9.678-8.654V52.885c0-4.78-4.333-8.654-9.677-8.654H70.968v-2.885c0-9.53 8.616-17.268 19.274-17.308 3.562-.03 6.454-2.584 6.532-5.769 0-3.186-2.888-5.769-6.451-5.769-17.816 0-32.258 12.915-32.258 28.846v37.5z" fill="currentColor"/>'
  },
  refuse_candidate: {
    width: 15,
    height: 15,
    block: '<path d="M72.461 78.32l10.874 9.669a4.975 4.975 0 0 1 .422 7.003 4.93 4.93 0 0 1-6.98.422l-10.921-9.71-11.315 12.649A4.924 4.924 0 0 1 50.86 100a4.917 4.917 0 0 1-3.301-1.268 4.974 4.974 0 0 1-.378-7.007l11.273-12.602-10.872-9.666a4.975 4.975 0 0 1-.422-7.004 4.934 4.934 0 0 1 6.98-.423l10.92 9.71 11.316-12.65a4.93 4.93 0 0 1 6.981-.376 4.972 4.972 0 0 1 .377 7.005L72.461 78.321zm-32.23-31.84a2.89 2.89 0 0 1 2.257 2.632 2.896 2.896 0 0 1-1.886 2.913c-9.458 3.471-17.012 11.659-19.717 21.37a3.11 3.11 0 0 0 .636 2.885 3.107 3.107 0 0 0 2.76 1.097l11.013-1.26a2.872 2.872 0 0 1 3.19 2.548 2.89 2.89 0 0 1-2.537 3.203l-11.013 1.259a8.906 8.906 0 0 1-7.803-3.093 8.941 8.941 0 0 1-1.801-8.197c2.572-9.238 8.861-17.31 17.042-22.247-7.088-4.056-11.518-11.664-11.518-20.57 0-14.28 11.57-27.22 25.793-28.846 7.078-.807 13.713 1.222 18.728 5.714 4.974 4.455 7.715 10.784 7.715 17.82 0 8.825-4.417 17.346-11.467 22.861 1.618.64 3.17 1.424 4.655 2.348a2.9 2.9 0 0 1 .93 3.984 2.877 2.877 0 0 1-3.972.933c-2.806-1.748-5.941-2.87-9.313-3.334a2.898 2.898 0 0 1-.786-5.51c8.484-3.807 14.185-12.36 14.185-21.283 0-5.363-2.056-10.159-5.788-13.501C57.76 6.825 52.7 5.302 47.3 5.923 35.899 7.227 26.622 17.587 26.622 29.018c0 8.643 5.47 15.661 13.61 17.46z" fill="currentColor" fill-rule="evenodd"/>'
  },
  remote: {
    width: 15,
    height: 15,
    block: '<path d="M78.512 45.657A2.485 2.485 0 0 1 81 48.141v38.722c0 1.264-.95 2.326-2.206 2.47L52.75 92.295h-.001l-13.873 1.579-27.336 3.11a2.497 2.497 0 0 1-1.94-.614 2.484 2.484 0 0 1-.832-1.853V48.553l-4.447 4.85a2.481 2.481 0 0 1-1.835.806c-.6 0-1.201-.215-1.679-.652a2.482 2.482 0 0 1-.156-3.51l42.397-46.24a2.491 2.491 0 0 1 3.462-.203l4.872 4.205a2.482 2.482 0 0 1 .256 3.503 2.492 2.492 0 0 1-3.51.256l-3.043-2.625-31.341 34.183v48.606l21.07-2.396v-25.81c0-1.264.949-2.326 2.205-2.468l15.164-1.726a2.484 2.484 0 0 1 2.771 2.469v25.242l21.07-2.396V48.14a2.485 2.485 0 0 1 2.487-2.484zm-33.792-.602c2.352-.267 4.339-2.463 4.339-4.796 0-1.017-.38-1.915-1.072-2.529-.595-.53-1.38-.812-2.242-.812-.153 0-.307.01-.465.028-2.352.266-4.339 2.461-4.339 4.795 0 1.017.381 1.915 1.073 2.53.703.624 1.662.902 2.706.784zm6.558-10.994C53.034 35.62 54 37.823 54 40.259c0 4.875-3.83 9.127-8.72 9.682a9.32 9.32 0 0 1-1.04.059c-2.072 0-4-.715-5.517-2.06C36.967 46.38 36 44.176 36 41.74c0-4.874 3.83-9.125 8.72-9.68 2.463-.281 4.792.431 6.558 2zm29.389-2.557A3.023 3.023 0 0 1 82 33.999c0 .786-.32 1.56-.88 2.12a2.413 2.413 0 0 1-.453.374 3.007 3.007 0 0 1-1.08.454c-.2.04-.387.053-.587.053-.199 0-.387-.013-.585-.053a2.7 2.7 0 0 1-.56-.174 3.183 3.183 0 0 1-.522-.28 2.413 2.413 0 0 1-.453-.373 3.157 3.157 0 0 1-.373-.454c-.107-.16-.2-.334-.28-.52a3.467 3.467 0 0 1-.174-.56 2.842 2.842 0 0 1-.053-.588c0-.2.013-.387.053-.587.04-.186.107-.373.174-.56.08-.187.173-.36.28-.52a3.07 3.07 0 0 1 1.348-1.107c.173-.067.372-.134.56-.174a3.457 3.457 0 0 1 1.172 0c.186.04.374.107.56.173.186.08.36.174.52.28zm18.483-21.06a2.38 2.38 0 0 1 .214 3.443c-.92 1.007-2.515 1.102-3.559.207-4.662-3.991-10.896-5.788-17.52-5.056C71.543 9.78 65.19 13.03 60.4 18.19a2.56 2.56 0 0 1-1.878.81c-.6 0-1.202-.206-1.684-.626a2.38 2.38 0 0 1-.19-3.444c5.614-6.047 13.097-9.86 21.067-10.738 8.078-.89 15.69 1.33 21.436 6.252zm-21.427 7.672c4.309-.539 8.371.812 11.452 3.803 1.011.982 1.107 2.68.21 3.79-.899 1.109-2.444 1.215-3.459.23-2.026-1.967-4.747-2.85-7.65-2.485-3.01.376-5.853 2.028-8.003 4.654-.484.591-1.152.892-1.825.892a2.326 2.326 0 0 1-1.634-.686c-1.008-.991-1.09-2.689-.188-3.794 2.953-3.605 6.893-5.88 11.097-6.404z" fill="currentColor"/>'
  },
  reset: {
    width: 15,
    height: 15,
    block: '<path d="M84.41 11.13C74.93 2.63 62.33-1.2 48.96.33 35.21 1.9 22.53 8.97 13.44 19.62V8.65A4.44 4.44 0 0 0 9.02 4.2a4.44 4.44 0 0 0-4.43 4.45v25.5a4.43 4.43 0 0 0 2.26 4.46l.25.14.18.07c.16.07.33.12.5.18l.24.06a4.4 4.4 0 0 0 1.5.1l26.01-2.97a4.45 4.45 0 0 0 3.9-4.92 4.43 4.43 0 0 0-4.9-3.92l-17.34 1.98C24.9 18.3 37.06 10.64 49.97 9.17c10.83-1.23 20.96 1.82 28.54 8.6C86 24.48 90.13 34.1 90.13 44.85c0 22.76-18.47 43.39-41.17 45.98-10.45 1.2-20.33-1.64-27.82-7.98-7.35-6.22-11.71-15.24-12.28-25.4a4.46 4.46 0 0 0-4.67-4.2A4.44 4.44 0 0 0 0 57.95c.7 12.63 6.17 23.89 15.4 31.7C23.42 96.43 33.5 100 44.3 100c1.87 0 3.77-.1 5.68-.33C77 96.58 99 72 99 44.85c0-13.32-5.18-25.3-14.59-33.72" fill="currentColor"/>'
  },
  resume: {
    width: 15,
    height: 15,
    block: '<path d="M28.73 79.16c1.4-.18 2.65.85 2.8 2.24a2.54 2.54 0 0 1-2.25 2.8L6.82 86.63A2.56 2.56 0 0 1 4.85 86 2.53 2.53 0 0 1 4 84.11V9.33c0-1.3.98-2.38 2.27-2.52L68.9.01a2.52 2.52 0 0 1 1.97.64c.54.48.85 1.17.85 1.89v30.5a2.54 2.54 0 0 1-2.55 2.53 2.54 2.54 0 0 1-2.54-2.53V5.37L9.09 11.6v69.7l19.64-2.13zm29.19-54.59a2.54 2.54 0 0 1-2.26 2.8l-36.24 3.88a2.54 2.54 0 0 1-2.8-2.25 2.54 2.54 0 0 1 2.26-2.8l36.23-3.88a2.54 2.54 0 0 1 2.8 2.25zm-10.1 15.17a2.55 2.55 0 0 1 2.8 2.25 2.54 2.54 0 0 1-2.25 2.79l-28.95 3.1a2.54 2.54 0 0 1-2.8-2.25 2.54 2.54 0 0 1 2.26-2.8l28.94-3.1zM34.26 57.76a2.54 2.54 0 0 1 2.8 2.25 2.54 2.54 0 0 1-2.25 2.8l-15.39 1.65a2.54 2.54 0 0 1-2.8-2.25 2.54 2.54 0 0 1 2.26-2.8l15.38-1.65zm44.59 28.8a2.2 2.2 0 0 0 1.9-2.64 9.5 9.5 0 0 0-9.36-7.38 9.78 9.78 0 0 0 7.14-9.16c0-4.68-3.8-8.04-8.5-7.5a9.76 9.76 0 0 0-8.5 9.43c0 4.24 3.13 7.4 7.22 7.54a12.77 12.77 0 0 0-9.29 8.86 2.2 2.2 0 0 0 2.38 2.77l17-1.93zm9.51-32.67C93.29 58.26 96 64.49 96 71.4c0 14.07-11.5 26.83-25.61 28.43a26.45 26.45 0 0 1-3 .17c-5.86 0-11.3-2-15.56-5.79-4.92-4.37-7.64-10.6-7.64-17.5 0-14.08 11.5-26.83 25.62-28.44 7-.79 13.58 1.2 18.55 5.62z" fill="currentColor"/>'
  },
  review: {
    width: 15,
    height: 15,
    block: '<path d="M74.865 41.935L63.37 52.825l3.666 13.968a3.092 3.092 0 0 1-1.05 3.195 3.052 3.052 0 0 1-3.331.328l-12.36-6.452-12.523 9.41c-.544.41-1.19.615-1.838.615-.59 0-1.181-.171-1.699-.515a3.09 3.09 0 0 1-1.278-3.313l3.624-14.654-11.124-7.995a3.091 3.091 0 0 1-1.208-3.188 3.07 3.07 0 0 1 2.456-2.356l14.905-2.663 5.524-14.626a3.07 3.07 0 0 1 2.82-1.99c1.283-.072 2.4.735 2.882 1.902l5.313 12.85 14.459-.73c1.33-.014 2.474.682 2.975 1.87a3.096 3.096 0 0 1-.717 3.454m9.054-31.171C74.76 2.548 62.6-1.164 49.653.32 23.378 3.328 2 27.27 2 53.692c0 8.58 2.262 16.72 6.556 23.633L3.297 96.08a3.093 3.093 0 0 0 .861 3.093 3.066 3.066 0 0 0 3.128.647l18.897-6.818c7.345 3.442 15.67 4.746 24.166 3.771C76.624 93.765 98 69.823 98 43.401c0-12.899-5-24.488-14.08-32.637" fill="currentColor" fill-rule="evenodd"/>'
  },
  review_outline: {
    width: 15,
    height: 15,
    block: '<path d="M49.653 90.645c23.275-2.666 42.21-23.858 42.21-47.245 0-11.116-4.272-21.074-12.03-28.033-6.698-6.01-15.323-9.198-24.664-9.198-1.59 0-3.198.092-4.822.278-23.275 2.665-42.21 23.86-42.21 47.244 0 7.856 2.177 15.256 6.294 21.405.501.753.652 1.689.408 2.56L10.82 91.99l14.509-5.234a3.072 3.072 0 0 1 2.42.152c6.558 3.334 14.129 4.626 21.905 3.737zm34.266-79.88C93 18.913 98 30.502 98 43.4c0 26.423-21.376 50.365-47.653 53.373-8.495.973-16.82-.331-24.164-3.773L7.286 99.818a3.056 3.056 0 0 1-3.128-.646 3.092 3.092 0 0 1-.86-3.093l5.258-18.755C4.262 70.408 2 62.27 2 53.69 2 27.27 23.378 3.328 49.653.32 62.6-1.164 74.758 2.55 83.919 10.765zM58.513 49.84l7.634-7.233-9.43.476c-1.275.049-2.49-.695-2.988-1.897l-3.6-8.706-3.822 10.12a3.066 3.066 0 0 1-2.332 1.94l-10.572 1.888 7.763 5.577a3.095 3.095 0 0 1 1.194 3.254l-2.335 9.439 8.139-6.114a3.056 3.056 0 0 1 3.25-.266l8.883 4.637L57.65 52.87a3.095 3.095 0 0 1 .862-3.031zm15.65-13.816c1.286-.035 2.473.682 2.976 1.872a3.094 3.094 0 0 1-.717 3.454L64.049 53.07l3.946 15.045a3.092 3.092 0 0 1-1.05 3.195 3.059 3.059 0 0 1-3.331.328l-13.318-6.954-13.487 10.132a3.05 3.05 0 0 1-3.534.1 3.09 3.09 0 0 1-1.28-3.313l3.908-15.796L23.9 47.184a3.092 3.092 0 0 1-1.21-3.188 3.073 3.073 0 0 1 2.458-2.357l16.041-2.865 5.944-15.736a3.07 3.07 0 0 1 2.82-1.99H50a3.07 3.07 0 0 1 2.834 1.9l5.73 13.864 15.598-.788z" fill="currentColor" fill-rule="evenodd"/>'
  },
  right: {
    width: 15,
    height: 15,
    block: '<path d="M28.07 100a6.56 6.56 0 0 1-4.39-1.67 6.47 6.47 0 0 1-.5-9.2l39.45-43.56-38.92-34.19a6.47 6.47 0 0 1-.56-9.19 6.61 6.61 0 0 1 9.27-.56L76.3 40.17a6.5 6.5 0 0 1 2.2 4.5 6.48 6.48 0 0 1-1.67 4.73L32.96 97.84a6.58 6.58 0 0 1-4.9 2.16" fill="currentColor"/>'
  },
  search: {
    width: 15,
    height: 15,
    block: '<path d="M99.2 84.45a2.4 2.4 0 0 1 .19 3.4l-7.91 8.85a2.38 2.38 0 0 1-3.37.2L62.08 73.72C54.16 79.9 44.75 83.1 35.6 83.1c-8.7 0-17.14-2.89-23.81-8.83C4.79 68.05.62 59.2.06 49.38-.58 38.1 3.62 26.5 11.6 17.59 27.1.25 52.4-2.56 68 11.33c7 6.23 11.16 15.07 11.72 24.9a43.55 43.55 0 0 1-6.53 25.05L99.2 84.45zM14.96 70.68C28.6 82.83 50.88 80.2 64.62 64.8c7.13-7.97 10.89-18.28 10.32-28.3-.48-8.54-4.08-16.2-10.12-21.58-5.77-5.14-13.1-7.63-20.65-7.63-10.32 0-21.09 4.63-29.02 13.51C8.03 28.77 4.27 39.09 4.84 49.1c.48 8.54 4.08 16.2 10.12 21.58z" fill="currentColor"/>'
  },
  settings: {
    width: 15,
    height: 15,
    block: '<path d="M94.86 49.58v-9.84c0-.69-.37-1.18-.98-1.32l-4.86-1.13a6.28 6.28 0 0 1-4.47-3.8 31.05 31.05 0 0 0-1.23-2.76c-.9-1.78-.9-3.92.01-5.88L85.58 20c.34-.74.25-1.52-.23-1.93l-7.04-6.17c-.49-.43-1.3-.42-2.02 0l-4.87 2.87a7.07 7.07 0 0 1-5.82.7 32.78 32.78 0 0 0-2.67-.77 6.29 6.29 0 0 1-4.4-3.94l-1.8-4.86c-.2-.57-.75-.89-1.46-.8l-9.96 1.1c-.89.1-1.72.8-2.03 1.69l-1.9 5.58a7.63 7.63 0 0 1-3.83 4.37c-.77.38-1.54.79-2.29 1.21a7.03 7.03 0 0 1-5.9.56l-5.22-1.9c-.7-.25-1.62.05-2.24.73l-7.04 7.76c-.62.67-.81 1.59-.48 2.23l2.62 5.1c.9 1.74.94 3.88.09 5.85-.27.62-.52 1.25-.75 1.88a7.8 7.8 0 0 1-4.02 4.4l-5.7 2.6a2.5 2.5 0 0 0-1.48 2.16v9.84c0 .68.37 1.18.98 1.32l5.71 1.33a6.35 6.35 0 0 1 4.48 3.88c.23.57.48 1.13.74 1.68a6.88 6.88 0 0 1 0 5.85L14.43 80c-.35.74-.26 1.52.22 1.93l7.04 6.17c.49.42 1.3.42 2.03 0l5.2-3.07a7.35 7.35 0 0 1 3.73-1.05c.74 0 1.47.12 2.17.37.74.25 1.5.48 2.26.68a6.22 6.22 0 0 1 4.28 3.91l1.9 5.16c.21.57.76.88 1.47.8l9.96-1.12c.9-.1 1.72-.79 2.03-1.68l1.79-5.27a7.6 7.6 0 0 1 3.94-4.42c.9-.42 1.82-.89 2.7-1.39A7.03 7.03 0 0 1 71 80.5l4.87 1.77c.7.25 1.62-.04 2.24-.73l7.04-7.75c.62-.67.81-1.6.49-2.23l-2.25-4.35a6.7 6.7 0 0 1-.1-5.87 40.8 40.8 0 0 0 1.25-3.1 7.59 7.59 0 0 1 4-4.28l4.86-2.23a2.49 2.49 0 0 0 1.47-2.15zm.2-16.1a6.31 6.31 0 0 1 4.94 6.26v9.84a7.61 7.61 0 0 1-4.45 6.76l-4.86 2.23c-.62.28-1.1.8-1.31 1.37a46.34 46.34 0 0 1-1.41 3.48c-.23.5-.23 1.05 0 1.48l2.23 4.35c1.3 2.51.8 5.7-1.23 7.94l-7.04 7.75a7.36 7.36 0 0 1-7.85 2.1l-4.86-1.77a1.87 1.87 0 0 0-1.52.17A45.97 45.97 0 0 1 64.65 87a2.5 2.5 0 0 0-1.27 1.45l-1.79 5.27a7.72 7.72 0 0 1-6.32 5.11l-9.96 1.12a7.26 7.26 0 0 1-.8.05 6.35 6.35 0 0 1-6.08-4.16l-1.9-5.16a1.15 1.15 0 0 0-.79-.74 37.5 37.5 0 0 1-2.61-.8 1.93 1.93 0 0 0-1.57.25l-5.21 3.07a6.9 6.9 0 0 1-8.07-.56l-7.04-6.17a6.62 6.62 0 0 1-1.5-7.84l2.63-5.68c.24-.52.25-1.1.02-1.59a35.53 35.53 0 0 1-.86-1.96c-.12-.3-.37-.69-.88-.8l-5.7-1.34A6.31 6.31 0 0 1 0 60.26v-9.84a7.62 7.62 0 0 1 4.46-6.77l5.7-2.61c.6-.28 1.1-.83 1.35-1.52.26-.7.54-1.41.84-2.12.25-.58.28-1.16.07-1.56L9.8 30.75a7.08 7.08 0 0 1 1.24-7.94l7.04-7.75a7.36 7.36 0 0 1 7.85-2.1l5.21 1.9c.47.17 1.05.1 1.56-.2a48.39 48.39 0 0 1 2.57-1.36 2.52 2.52 0 0 0 1.25-1.43l1.9-5.59a7.72 7.72 0 0 1 6.32-5.11L54.69.05a6.4 6.4 0 0 1 6.88 4.1l1.8 4.87c.08.23.3.63.8.75a37.8 37.8 0 0 1 3.08.9c.44.14 1.01.04 1.54-.27l4.86-2.86a6.9 6.9 0 0 1 8.07.56l7.04 6.16a6.63 6.63 0 0 1 1.5 7.85L88 26.96c-.25.54-.28 1.11-.09 1.5a35.54 35.54 0 0 1 1.43 3.21c.18.45.6.61.85.67l4.86 1.13zm-45.2 34.69c10.42-1.18 18.9-10.5 18.9-20.78 0-4.73-1.84-8.95-5.16-11.89a15.87 15.87 0 0 0-10.63-3.87c-.7 0-1.4.04-2.11.12-10.42 1.18-18.9 10.5-18.9 20.78 0 4.73 1.83 8.95 5.15 11.88 3.37 2.97 7.9 4.3 12.75 3.76zM69.47 29a24.12 24.12 0 0 1 8.1 18.4c0 14.56-11.98 27.76-26.71 29.42-1.06.12-2.11.18-3.15.18a24.6 24.6 0 0 1-16.47-6.09 24.12 24.12 0 0 1-8.1-18.38c0-14.57 11.99-27.77 26.72-29.43 7.39-.84 14.35 1.26 19.61 5.9z" fill="currentColor"/>'
  },
  shield: {
    width: 15,
    height: 15,
    block: '<path d="M50.22 75a32.42 32.42 0 0 1-6.89-5.4l26.48-26a122.28 122.28 0 0 1-3.47 9.25C60.9 65.7 53.23 72.63 50.22 74.99M32.17 51.14l24.44-24.02a39.82 39.82 0 0 0 13.6 1.5L36.97 61.3a49.13 49.13 0 0 1-2.34-4.41 95.07 95.07 0 0 1-2.45-5.75m44.11-29.32c-.46.17-11.34 3.98-24.46-2.66a2.93 2.93 0 0 0-3.06.26c-13.13 9.75-24.5 8.27-24.6 8.26a2.92 2.92 0 0 0-2.43.74 2.8 2.8 0 0 0-.88 2.35c.05.54 1.48 13.39 8.53 28.48C37.11 75.8 48.9 80.73 49.4 80.93a2.91 2.91 0 0 0 2.65-.23c.5-.3 12.01-7.7 19.61-25.69 7.01-16.58 8.44-29.7 8.5-30.24a2.8 2.8 0 0 0-1.11-2.53 2.93 2.93 0 0 0-2.77-.42m4.65 33.38C70.89 78.95 54.68 91 50.2 93.97c-4.54-2.03-20.34-10.38-30.18-31.46A123.1 123.1 0 0 1 8.91 20.53c6.92.16 23.33-1.15 41.89-14.39 18.18 8.64 34.04 6.77 41.24 5.15-.55 7.23-2.71 24.03-11.11 43.9M96.76 5.17a2.93 2.93 0 0 0-2.66-.32c-.2.07-19.5 7-42.28-4.53a2.94 2.94 0 0 0-3.06.26C26.15 17.37 6.51 14.7 6.33 14.68a2.92 2.92 0 0 0-2.32.65A2.8 2.8 0 0 0 3 17.48c0 .9.12 22.4 11.79 47.4 12.6 26.97 33.85 34.64 34.75 34.96a2.94 2.94 0 0 0 2.41-.23c.89-.5 21.84-12.76 34.3-42.24C97.9 29.87 98 8.4 98 7.5c0-.93-.47-1.8-1.24-2.33" fill="currentColor"/>'
  },
  source: {
    width: 15,
    height: 15,
    block: '<path d="M39.61 22.41c.05-.23.08-.47.08-.7a3.61 3.61 0 0 0-1.07-2.54 3.63 3.63 0 0 0-3.24-.98 3.6 3.6 0 0 0-.68.2 3.16 3.16 0 0 0-.62.34 3.61 3.61 0 0 0-1.6 2.98c0 .23.02.48.06.7.06.23.12.46.22.68a3.77 3.77 0 0 0 .78 1.16c.67.66 1.6 1.05 2.55 1.05.93 0 1.87-.39 2.53-1.05a3.77 3.77 0 0 0 .78-1.16c.1-.21.15-.45.21-.68zM27.9 23.75c.05-.24.07-.47.07-.7a3.75 3.75 0 0 0-.27-1.38c-.1-.22-.2-.43-.33-.62a3.42 3.42 0 0 0-.45-.54 3.75 3.75 0 0 0-5.1 0 3.35 3.35 0 0 0-.77 1.16 3.5 3.5 0 0 0-.2 2.08 3.68 3.68 0 0 0 .53 1.28 3.62 3.62 0 0 0 3 1.6c.22 0 .47-.02.7-.07.23-.04.45-.11.68-.21.21-.09.41-.19.62-.33a3.42 3.42 0 0 0 .99-1c.13-.18.23-.4.33-.6.09-.23.16-.45.2-.67zm-12.43 1.44a3.76 3.76 0 0 0 .08-.7c0-.95-.39-1.87-1.05-2.55a5.3 5.3 0 0 0-.55-.44 5.14 5.14 0 0 0-.62-.33 4.02 4.02 0 0 0-.68-.2 3.67 3.67 0 0 0-3.25.97 3.59 3.59 0 0 0-1.05 2.54c0 .95.37 1.87 1.05 2.54a3.65 3.65 0 0 0 2.55 1.05 3.96 3.96 0 0 0 1.38-.27 3.75 3.75 0 0 0 1.17-.78c.15-.17.31-.34.44-.54s.23-.4.34-.62a3.75 3.75 0 0 0 .2-.67zm67.5-19.06c2.24 2 3.48 4.81 3.48 7.93v23.52a2.52 2.52 0 0 1-2.52 2.5 2.52 2.52 0 0 1-2.52-2.5v-8.3L5.04 37.95V84.5L35.8 81a2.52 2.52 0 0 1 2.78 2.22A2.51 2.51 0 0 1 36.37 86L2.8 89.8a2.52 2.52 0 0 1-1.97-.61A2.51 2.51 0 0 1 0 87.32v-64c0-6.22 5.06-11.85 11.28-12.55l63.3-7.2a10.6 10.6 0 0 1 8.38 2.56zM61.2 81.37c5.2 4.52 13.84 3.39 19.24-2.53A15.04 15.04 0 0 0 84.54 68c-.19-3.11-1.51-5.89-3.74-7.82a11.67 11.67 0 0 0-7.74-2.77c-4.05 0-8.34 1.82-11.5 5.3a15.04 15.04 0 0 0-4.1 10.85c.19 3.1 1.51 5.88 3.74 7.82zm37.32 7.58a4.3 4.3 0 0 1 .42 6.07 4.32 4.32 0 0 1-3.26 1.48 4.3 4.3 0 0 1-2.84-1.06L83.7 87.5a24.2 24.2 0 0 1-14.78 5.22c-4.88 0-9.63-1.59-13.4-4.86-3.99-3.47-6.36-8.37-6.68-13.82a23.67 23.67 0 0 1 6.32-17.14c8.54-9.36 22.59-10.8 31.32-3.22a19.6 19.6 0 0 1 6.68 13.81c.27 4.7-1.05 9.49-3.66 13.63l9.02 7.83z" fill="currentColor"/>'
  },
  spanner: {
    width: 15,
    height: 15,
    block: '<path d="M98.983 15.83a2.73 2.73 0 0 0-4.538-1.123L83.729 25.424a15.75 15.75 0 0 1-9.16-9.16l10.716-10.72a2.738 2.738 0 0 0 .72-2.587 2.735 2.735 0 0 0-1.843-1.952 22.576 22.576 0 0 0-23.616 6.671c-5.456 6.217-7.004 14.913-4.16 22.628L30.309 56.389c-8.17-3.018-17.487-1.044-23.715 5.184-5.921 5.921-8.057 14.579-5.577 22.595a2.73 2.73 0 0 0 4.54 1.124L16.27 74.574a15.757 15.757 0 0 1 9.16 9.162L14.715 94.454a2.738 2.738 0 0 0-.72 2.587c.23.929.93 1.668 1.843 1.952a22.468 22.468 0 0 0 6.65 1.007 22.587 22.587 0 0 0 16.966-7.678c5.457-6.219 7.004-14.914 4.16-22.628L69.691 43.61c8.168 3.018 17.487 1.046 23.717-5.184 5.92-5.922 8.055-14.58 5.574-22.595" fill="currentColor"/>'
  },
  special_pipeline: {
    width: 15,
    height: 15,
    block: '<path d="M81.76 82.96v-48.2c0-.82-.3-1.55-.85-2.03a2.54 2.54 0 0 0-1.7-.61c-.14 0-.28 0-.42.03L21.9 39.7a4.47 4.47 0 0 0-3.66 4.2v48.19c0 .83.3 1.55.85 2.04.55.48 1.3.69 2.12.58l56.89-7.55a4.46 4.46 0 0 0 3.66-4.2zm2.6-54.19a7.95 7.95 0 0 1 2.64 6v48.19c0 4.67-3.6 8.8-8.21 9.42L21.9 99.93a7.8 7.8 0 0 1-6.26-1.84 7.96 7.96 0 0 1-2.64-6v-48.2c0-4.66 3.6-8.8 8.21-9.41l56.89-7.55c2.31-.3 4.59.36 6.26 1.84zm-26.4 20.88a10.4 10.4 0 0 1 3.42 7.88c0 4.93-3.2 9.5-7.64 11.46v8.2A3.75 3.75 0 0 1 50 80.95a3.75 3.75 0 0 1-3.74-3.76v-7.56c-1.56-.4-3-1.13-4.22-2.22a10.42 10.42 0 0 1-3.42-7.88c0-6.15 4.97-11.72 11.08-12.42 3.1-.35 6.04.55 8.26 2.54zM31.42 27.77a2.63 2.63 0 0 1-2.62-2.63c0-12.61 9.38-23.35 21.82-24.99a18.17 18.17 0 0 1 14.39 4.4 18.36 18.36 0 0 1 6.2 13.76 2.63 2.63 0 0 1-2.62 2.63 2.63 2.63 0 0 1-2.63-2.63c0-3.76-1.6-7.33-4.41-9.8A12.93 12.93 0 0 0 51.3 5.38a19.95 19.95 0 0 0-17.26 19.76 2.63 2.63 0 0 1-2.62 2.63z" fill="currentColor"/>'
  },
  stackoverflow: {
    width: 15,
    height: 15,
    block: '<path d="M88.5 31.98l-6 3.82L59.7 3.82 65.48 0 88.5 31.98zm-8.17 7.17l-4.8 5.5-31.18-25.8 4.8-5.24 31.18 25.54zm-7.42 7.88l-3.13 5.96-35.25-17.9 3.35-5.96 35.03 17.9zm-4.08 10.26l-1.68 6.91-39.1-9.53 1.68-7.17 39.1 9.79zm-42.05 6.53l40.13 3.69-.67 7.13-40.14-3.69.68-7.13zm-8.08-4.39h-7.2V100h69.56V59.43h-7.2v33.42H18.7V59.43zm7.19 19.1h40.78v7.15H25.9v-7.15z" fill="currentColor"/>'
  },
  stackserver: {
    width: 15,
    height: 15,
    block: '<path d="M44.19 21.55v74.33-74.33zm29 61.88c0 1.36-1.11 2.6-2.49 2.75A2.17 2.17 0 0 1 68.22 84c0-1.37 1.11-2.6 2.48-2.75a2.17 2.17 0 0 1 2.49 2.19zM81 82.37c0 1.37-1.11 2.6-2.48 2.76a2.17 2.17 0 0 1-2.48-2.2c0-1.36 1.1-2.6 2.48-2.75a2.17 2.17 0 0 1 2.48 2.2zm-7.81-17.5c0 1.37-1.11 2.6-2.49 2.76a2.17 2.17 0 0 1-2.48-2.19c0-1.36 1.11-2.6 2.48-2.75a2.17 2.17 0 0 1 2.49 2.19zM81 63.83c0 1.37-1.11 2.6-2.48 2.76a2.17 2.17 0 0 1-2.48-2.2c0-1.36 1.1-2.6 2.48-2.75a2.17 2.17 0 0 1 2.48 2.2zm-7.81-17.5c0 1.37-1.11 2.61-2.49 2.77a2.17 2.17 0 0 1-2.48-2.2c0-1.36 1.11-2.6 2.48-2.75a2.17 2.17 0 0 1 2.49 2.19zM81 45.28c0 1.37-1.11 2.6-2.48 2.76a2.17 2.17 0 0 1-2.48-2.2c0-1.36 1.1-2.6 2.48-2.75a2.17 2.17 0 0 1 2.48 2.2zm-12.78-17c0-1.36 1.11-2.6 2.48-2.75a2.17 2.17 0 0 1 2.49 2.2c0 1.36-1.11 2.6-2.49 2.75a2.17 2.17 0 0 1-2.48-2.2zm7.82-1.05c0-1.36 1.1-2.6 2.48-2.75A2.17 2.17 0 0 1 81 26.66c0 1.37-1.11 2.6-2.48 2.76a2.17 2.17 0 0 1-2.49-2.2zM34.6 94.54v-13.4l50.26-6.49v13.4L34.6 94.54zM66.33 5.2l13.92 9.11-47.59 6.14-13.9-9.1L66.32 5.2zM34.61 62.6l50.26-6.48v13.33l-50.26 6.48V62.6zm0-18.61l50.26-6.49v13.4l-50.26 6.48v-13.4zm50.26-11.64l-50.26 6.48V25.36l50.26-6.48v13.46zm5.11-16.5c0-.06 0-.12-.02-.18a2.52 2.52 0 0 0-.12-.54l-.05-.14a2.62 2.62 0 0 0-.34-.58l-.1-.11c-.08-.08-.14-.17-.22-.24l-.2-.14c-.04-.02-.05-.05-.09-.08L68.36.42a2.57 2.57 0 0 0-1.74-.4L11.23 7.17l-.1.03a2.55 2.55 0 0 0-.45.13c-.09.03-.18.05-.26.1-.02 0-.05.01-.07.03-.13.06-.23.15-.34.24l-.2.14c-.17.16-.33.35-.45.56l-.02.05a2.58 2.58 0 0 0-.26.63l-.01.05c-.02.07 0 .13-.02.2-.02.12-.05.24-.05.37v74.16c0 .86.43 1.66 1.14 2.13l20.5 13.58.03.02c.19.12.38.21.6.28l.13.04a2.59 2.59 0 0 0 .98.07l55.39-7.15A2.56 2.56 0 0 0 90 90.3V15.97l-.01-.13z" fill="currentColor"/>'
  },
  strikethrough: {
    width: 15,
    height: 15,
    block: '<path d="M50.679 59.43h31.41c1.578 3.174 2.302 6.82 2.411 11.158C84.5 90.665 68.735 100 49.559 100 27.676 100 12.618 86.061 12.5 64.45h19.412c.117 13.683 7.647 19.054 17.647 19.054 9.882 0 15.412-4.092 15.412-11.381 0-6.461-3.921-9.114-14.292-12.692zM18.303 41.849c-2.321-3.843-3.332-8.391-3.332-13.97C15.324 10.357 30.265 0 48.147 0 68.03 0 82.735 12.66 83.441 32.992l-20 .128c0-11.125-5.294-16.752-15.059-16.752-8 0-14 3.837-14 11.637 0 6.396 6.181 9.147 19.136 13.843H18.303zm-4.332 3.996H87.5v9.59H13.97v-9.59z" fill="currentColor"/>'
  },
  sun: {
    width: 15,
    height: 15,
    block: '<path d="M47.03 14.71V3.17a3.17 3.17 0 0 1 6.33 0V14.7a3.17 3.17 0 0 1-6.33 0zm5.94 70.97v11.55a2.77 2.77 0 0 1-5.54 0V85.68a2.77 2.77 0 0 1 5.54 0zm-37.9-28.3L3.53 58.7a3.17 3.17 0 0 1-.72-6.29l11.55-1.32a3.17 3.17 0 0 1 .71 6.3zm82.47-9.79L86 48.91a2.77 2.77 0 0 1-3.07-2.44 2.77 2.77 0 0 1 2.44-3.07l11.55-1.31a2.76 2.76 0 0 1 3.06 2.43 2.77 2.77 0 0 1-2.44 3.07zM10.3 18.54a2.77 2.77 0 1 1 3.67-4.15l11.77 10.43a2.77 2.77 0 0 1-1.84 4.84c-.65 0-1.3-.23-1.83-.7L10.29 18.55zm79.82 63.32A2.77 2.77 0 1 1 86.43 86L74.66 75.58a2.77 2.77 0 0 1 3.68-4.15L90.1 81.86zm-64.36-4.42a2.77 2.77 0 0 1 .2 3.9L14.2 94.47c-.55.61-1.3.92-2.06.92a2.77 2.77 0 0 1-2.07-4.62l11.77-13.11a2.77 2.77 0 0 1 3.92-.21zm48.9-54.48a2.77 2.77 0 0 1-.21-3.91L86.21 5.94a2.77 2.77 0 1 1 4.12 3.7l-11.77 13.1a2.76 2.76 0 0 1-3.91.22zm-3.87 26.9c0 5.5-2.17 10.48-5.7 14.17-2.27.7-4.67.93-7.14.65-10.52-1.2-19.09-10.73-19.09-21.24 0-5.75 2.6-10.72 7.11-13.72a20.63 20.63 0 0 1 4.24-.44 20.6 20.6 0 0 1 20.58 20.58zm5.54 0A26.15 26.15 0 0 0 50.2 23.74c-2.07 0-4.08.27-6.01.72l-.05.01c-.08.02-.15.05-.23.06-.65.17-1.3.34-1.92.55l-.2.07a26.22 26.22 0 0 0-3.97 1.71l-.34.2c-.62.35-1.23.72-1.82 1.11l-.18.12a26 26 0 0 0-1.88 1.41l-.02.02a25.95 25.95 0 0 0-7.44 9.96l-.03.08a25.36 25.36 0 0 0-.78 2.13l-.15.5c-.18.6-.34 1.2-.47 1.8l-.15.7a25.4 25.4 0 0 0-.27 1.78c-.03.23-.07.46-.09.7a26.58 26.58 0 0 0-.12 2.5c0 .88.04 1.76.13 2.64.01.13.04.25.06.38a26.54 26.54 0 0 0 .35 2.27 25.94 25.94 0 0 0 7.1 13.17 25.94 25.94 0 0 0 13.2 7.12h.02c.75.16 1.5.26 2.27.35l.34.05a26.26 26.26 0 0 0 5.28 0c.2-.02.42-.07.63-.1.65-.07 1.3-.16 1.95-.3.18-.03.35-.08.53-.12a26.6 26.6 0 0 0 1.98-.51l.36-.13a26.1 26.1 0 0 0 2.05-.75l.23-.11a25.58 25.58 0 0 0 2.06-1l.2-.11a25.5 25.5 0 0 0 1.95-1.19l.29-.2a27.21 27.21 0 0 0 1.71-1.3c.14-.11.27-.24.4-.36.47-.4.94-.79 1.37-1.22l.04-.05a26.04 26.04 0 0 0 7.74-18.54z" fill="currentColor"/>'
  },
  tag: {
    width: 15,
    height: 15,
    block: '<path d="M74.56 44.97a2.44 2.44 0 0 0-1.06.38l-1.34-18.23a2.43 2.43 0 0 0-2.53-2.22l-15 .62c1.01-10.37 9.8-19.4 20.48-20.6 5.4-.6 10.46.9 14.23 4.22 3.74 3.28 5.8 8 5.8 13.26 0 11.17-9.24 21.3-20.58 22.57zm-19.23 8.6c-3.04 3.33-7.9 3.96-10.83 1.4a6.35 6.35 0 0 1-2.12-4.47 8.57 8.57 0 0 1 2.31-6.18 8.88 8.88 0 0 1 6.47-2.99c1.61 0 3.16.52 4.37 1.58a6.34 6.34 0 0 1 2.12 4.47 8.58 8.58 0 0 1-2.32 6.18zm-7.65 25.62l-28.1-24.54 21.66-23.78 8.63-.36c.27 2.12.8 4.16 1.6 6.06-3.7-.1-7.58 1.45-10.4 4.54a13.36 13.36 0 0 0-3.55 9.66 11.07 11.07 0 0 0 11.34 10.55c3.62 0 7.36-1.55 10.1-4.56a13.35 13.35 0 0 0 3.55-9.66 11.32 11.32 0 0 0-1.53-5.08 2.36 2.36 0 0 0-.75-1.34c-3-2.68-4.88-6.3-5.47-10.37l12.72-.53 1.88 25.61-21.68 23.8zm44.9-73.63C87.76 1.32 81.36-.6 74.56.16c-13.12 1.48-23.88 12.75-24.8 25.56l-9.74.4a2.45 2.45 0 0 0-1.7.8l-28.07 30.8a2.35 2.35 0 0 0-.38.57L.64 68.27A2.38 2.38 0 0 0 0 70.01a2.38 2.38 0 0 0 .82 1.67L32.56 99.4a2.44 2.44 0 0 0 1.62.6c.66 0 1.32-.26 1.8-.78L49.8 84.29c.2-.23.36-.48.46-.76l23.41-25.7a2.36 2.36 0 0 0 .62-1.77l-.48-6.55a2.44 2.44 0 0 0 1.3.22C88.83 48.2 100 35.93 100 22.4c0-6.65-2.64-12.63-7.42-16.84z" fill="currentColor"/>'
  },
  target: {
    width: 15,
    height: 15,
    block: '<path d="M32.22 47.98c-3.8 4.25-5.81 9.72-5.51 15.03a16.06 16.06 0 0 0 5.27 11.23c7.16 6.36 18.94 4.9 26.23-3.24 4.66-5.2 6.54-12 5.02-18.21a3.04 3.04 0 0 1 2.22-3.67 3.04 3.04 0 0 1 3.67 2.22c2 8.16-.4 17.02-6.4 23.72a27.06 27.06 0 0 1-19.97 9.2c-5.4 0-10.64-1.8-14.8-5.48a22.1 22.1 0 0 1-7.3-15.43c-.39-6.9 2.18-13.99 7.06-19.43 5.99-6.68 14.55-10.04 22.9-9.01a3.03 3.03 0 0 1 2.63 3.39 3.05 3.05 0 0 1-3.38 2.64c-6.4-.8-12.97 1.84-17.64 7.04zM80.9 37.13c8.1 14.74 5.24 33.93-7.13 47.73C64.85 94.82 52.69 100 40.97 100c-8.78 0-17.31-2.9-24.06-8.9C9.84 84.84 5.63 75.93 5.07 66.04c-.65-11.33 3.58-22.96 11.6-31.9 12.35-13.8 31.15-18.82 46.77-12.5a3.04 3.04 0 0 1 1.68 3.96 3.03 3.03 0 0 1-3.95 1.68c-13.26-5.37-29.33-.98-39.99 10.9-6.95 7.76-10.62 17.78-10.06 27.5.47 8.28 3.96 15.69 9.82 20.89 13.25 11.77 34.93 9.18 48.32-5.76 10.65-11.88 13.2-28.26 6.33-40.74a3.04 3.04 0 0 1 1.2-4.13 3.03 3.03 0 0 1 4.11 1.2zm3.46-13.54l-7.08.1-.7-6.97 7-7.8.45 4.58a2.69 2.69 0 0 0 2.68 2.39l4.6-.07-6.95 7.77zm15.4-11.62a2.68 2.68 0 0 0-2.45-1.56l-8.24.13-.81-8.15A2.65 2.65 0 0 0 83.64.9L71.85 14.03a2.66 2.66 0 0 0-.66 2.04l.88 8.9-23.71 26.46c-3-.88-6.57.13-9 2.84-3.24 3.62-3.24 8.88 0 11.75 3.23 2.88 8.48 2.28 11.72-1.34 2.44-2.71 3.04-6.36 1.82-9.22l23.7-26.45 9-.14a2.66 2.66 0 0 0 1.93-.88l11.79-13.15a2.66 2.66 0 0 0 .44-2.88z" fill="currentColor"/>'
  },
  thumbup: {
    width: 15,
    height: 15,
    block: '<path d="M95.48 46.92l-6.45 25.44c-1.63 6.43-7.27 11.44-13.72 12.17l-51.76 5.89v-49.8l16.47-33.5h.04c2.17 0 4.17.73 5.71 2.1a8.48 8.48 0 0 1 2.77 6.46v21.15c0 .58.25 1.14.7 1.53a2.08 2.08 0 0 0 1.6.52l34.67-3.95c3.2-.37 6.17.72 8.13 2.98 2.05 2.37 2.72 5.64 1.84 9m1.29-11.7a13.29 13.29 0 0 0-11.73-4.38l-32.36 3.68V15.68c0-3.76-1.48-7.14-4.16-9.53A12.74 12.74 0 0 0 38.46 3.1c-.7.08-1.3.5-1.62 1.14L20.13 38.22 1.83 40.3A2.06 2.06 0 0 0 0 42.35v52.59a2.06 2.06 0 0 0 2.3 2.05l73.48-8.36c8.12-.92 15.22-7.2 17.26-15.26l6.44-25.43c1.23-4.68.24-9.32-2.71-12.73" fill="currentColor"/>'
  },
  tree: {
    width: 15,
    height: 15,
    block: '<path d="M50 79.71c-13.66 0-28.89-5.28-28.89-12.87v-.13l.03-.14a2.71 2.71 0 0 1 .07-.29l.1-.3v-.01c.36-.93 1.3-2.6 3.76-5.3a67.97 67.97 0 0 1 2.14-2.22 83.63 83.63 0 0 1 1.32-1.27c.47-.44.97-.9 1.5-1.37a22.99 22.99 0 0 0 6.41 2.16 2.55 2.55 0 0 0 2.9-2.14 2.55 2.55 0 0 0-2.14-2.9 18 18 0 0 1-6.09-2.37 2.57 2.57 0 0 0-.46-.23 17.38 17.38 0 0 1-.66-.42l-.18-.12-.56-.4-.3-.24-.47-.38c-.13-.1-.25-.23-.37-.35l-.37-.35-.39-.45c-.1-.11-.2-.22-.28-.34-.12-.17-.23-.36-.34-.54l-.2-.32c-.1-.2-.17-.43-.25-.64-.03-.1-.08-.2-.1-.3a3.89 3.89 0 0 1-.14-.98c0-.3.34-3.2 10.81-11.65 1.3.5 2.7.9 3.07 1a2.56 2.56 0 0 0 3.15-1.76 2.55 2.55 0 0 0-1.78-3.15 22.56 22.56 0 0 1-3.48-1.24 2.54 2.54 0 0 0-.5-.22 10.7 10.7 0 0 1-2.07-1.47c-.02 0-.02-.02-.03-.03a6.4 6.4 0 0 1-.47-.48l-.06-.08a4.8 4.8 0 0 1-.33-.43l-.09-.16a3.35 3.35 0 0 1-.2-.36l-.09-.26c-.03-.09-.07-.17-.09-.26a2.25 2.25 0 0 1-.06-.52c.01-.14.05-.3.12-.5l.1-.2c.05-.13.1-.27.19-.42l.17-.3c.1-.14.17-.29.28-.44l.25-.37.34-.5.33-.42a27.77 27.77 0 0 1 .8-1.01c.15-.19.3-.38.47-.57l.46-.53.54-.6a78.06 78.06 0 0 1 1.1-1.22 94.81 94.81 0 0 1 1.82-1.9l.7-.7.64-.64.77-.75.66-.64.84-.79.66-.62c.3-.3.63-.58.95-.88a123.7 123.7 0 0 1 1.71-1.55l.52-.46 1.4-1.21.26-.24.1-.08c8.77 7.53 16.02 15.35 16.18 17.53 0 1.42-1.39 2.96-3.8 4.25a2.55 2.55 0 0 0-.38 4.25C73.63 41.1 73.96 44.18 73.96 44.5c0 2.77-3.07 4.95-4.9 6a2.55 2.55 0 0 0-.4 4.13c9.73 8.5 10.23 11.66 10.23 12.21 0 7.59-15.23 12.87-28.89 12.87m24.45-26.73c3-2.46 4.62-5.4 4.62-8.48 0-2.4-1.34-6.19-11.21-14.4 2.24-1.93 3.43-4.23 3.43-6.68 0-5.79-13.74-17.9-19.65-22.84h-.02c-.21-.18-.45-.3-.7-.4l-.1-.05a2.58 2.58 0 0 0-.89-.13 2.5 2.5 0 0 0-.75.13l-.1.04c-.25.1-.5.23-.72.41C42.45 5.52 28.7 17.63 28.7 23.42c0 2.45 1.2 4.75 3.43 6.68-9.87 8.21-11.21 12-11.21 14.4 0 3.09 1.61 6.02 4.61 8.48C17.04 60.85 16 64.64 16 66.84c0 .5.04.98.12 1.46l.03.23c.08.46.19.9.32 1.35l.09.25c.15.45.32.9.54 1.34l.06.13c.22.43.47.86.74 1.28l.07.12c.29.42.61.84.96 1.25l.16.2c.35.4.73.8 1.13 1.2l.14.12c.87.82 1.85 1.6 2.95 2.32l.11.08a28.24 28.24 0 0 0 1.86 1.12c1.88 1.05 4 1.97 6.33 2.75l.05.02a53.47 53.47 0 0 0 10.44 2.28V94.7c0 3.07 3.32 5.31 7.9 5.31s7.9-2.23 7.9-5.31V84.34C73.05 82.5 84 75.48 84 66.84c0-2.2-1.05-5.99-9.55-13.86" fill="currentColor"/>'
  },
  twitter: {
    width: 15,
    height: 15,
    block: '<path d="M97.73 18.46a37.87 37.87 0 0 1-4.83 1.77 21.42 21.42 0 0 0 4.35-7.67 1.62 1.62 0 0 0-.53-1.75 1.61 1.61 0 0 0-1.83-.13 38.03 38.03 0 0 1-11.25 4.45A21.56 21.56 0 0 0 68.61 9a21.5 21.5 0 0 0-21.29 24.28A54.94 54.94 0 0 1 9.6 13.23a1.61 1.61 0 0 0-2.64.21 21.52 21.52 0 0 0-2.91 10.81A21.5 21.5 0 0 0 9.16 38.2a18.17 18.17 0 0 1-2.87-1.28 1.62 1.62 0 0 0-2.4 1.37v.29c0 7.73 4.15 14.7 10.5 18.49a18.48 18.48 0 0 1-1.63-.24 1.62 1.62 0 0 0-1.83 2.08A21.47 21.47 0 0 0 26.65 73.3 37.94 37.94 0 0 1 1.8 78.85 1.61 1.61 0 0 0 .74 81.8a57.83 57.83 0 0 0 31.3 9.2C53.9 91 67.59 80.68 75.2 72.02a60.22 60.22 0 0 0 14.92-41 41.77 41.77 0 0 0 9.6-10.18 1.62 1.62 0 0 0-.1-1.94 1.61 1.61 0 0 0-1.89-.44z" fill="currentColor"/>'
  },
  'unordered-list': {
    width: 15,
    height: 15,
    block: '<path d="M23.106 28.251c0 6.49-5.174 11.752-11.553 11.752C5.175 40.003.001 34.742.001 28.25c0-6.49 5.174-11.751 11.552-11.751 6.38-.001 11.553 5.26 11.553 11.751zM11.552 57.46C5.174 57.46 0 62.722 0 69.21c0 6.49 5.174 11.752 11.552 11.752 6.38 0 11.552-5.262 11.552-11.752 0-6.49-5.172-11.751-11.552-11.751zm28.85-32.878h56.181c1.886 0 3.417-1.556 3.417-3.476s-1.53-3.476-3.417-3.476h-56.18c-1.886 0-3.417 1.556-3.417 3.476s1.53 3.476 3.417 3.476zm0 16.991h36.444c1.888 0 3.417-1.556 3.417-3.475 0-1.92-1.53-3.476-3.417-3.476H40.403c-1.886 0-3.417 1.554-3.417 3.476 0 1.92 1.53 3.475 3.417 3.475zm56.181 17.985h-56.18c-1.886 0-3.417 1.555-3.417 3.475 0 1.92 1.53 3.476 3.417 3.476h56.18c1.886 0 3.417-1.556 3.417-3.476s-1.53-3.475-3.417-3.475zm-19.737 16.99H40.403c-1.886 0-3.417 1.555-3.417 3.476 0 1.92 1.53 3.476 3.417 3.476h36.443c1.888 0 3.417-1.556 3.417-3.476s-1.53-3.475-3.417-3.475z" fill="currentColor"/>'
  },
  up: {
    width: 15,
    height: 15,
    block: '<path d="M6.51 80.5a6.49 6.49 0 0 1-4.35-1.66 6.43 6.43 0 0 1-.5-9.12l43.5-48.08a6.55 6.55 0 0 1 9.16-.52L97.8 59.38a6.42 6.42 0 0 1 .56 9.12 6.54 6.54 0 0 1-9.19.55L50.52 35.06l-39.16 43.3a6.53 6.53 0 0 1-4.85 2.14" fill="currentColor"/>'
  },
  update: {
    width: 15,
    height: 15,
    block: '<path d="M84.39 16.27a1.8 1.8 0 0 1-1.6 1.79l-6.7.76a1.8 1.8 0 0 1-2-1.58 1.8 1.8 0 0 1 1.59-2l3.02-.35a8.64 8.64 0 0 0-6.9-2.11c-3.6.4-6.94 2.75-8.73 6.12a1.8 1.8 0 0 1-2.44.74 1.8 1.8 0 0 1-.74-2.44 15.27 15.27 0 0 1 11.5-8c3.54-.41 6.9.65 9.4 2.77V9.54a1.8 1.8 0 1 1 3.6 0v6.72zM83.69 27a15.16 15.16 0 0 1-11.9 8.8 12.21 12.21 0 0 1-9.4-2.75v2.4a1.8 1.8 0 0 1-3.6 0v-6.72a1.8 1.8 0 0 1 1.6-1.79l6.7-.77c.97-.11 1.89.6 2 1.6a1.8 1.8 0 0 1-1.58 1.99l-3.03.34a8.62 8.62 0 0 0 6.9 2.12 11.7 11.7 0 0 0 9.04-6.73 1.8 1.8 0 0 1 2.38-.88 1.8 1.8 0 0 1 .89 2.4zM49.63 65.57c-.28.42-.42.9-.42 1.4v19.66l-8.33 5.95v-24.9a2.53 2.53 0 0 0-.52-1.54L13.23 30.78l36.06-4.12c.43 5.3 2.7 10.03 6.53 13.46a19.6 19.6 0 0 0 7.83 4.28L49.63 65.56zM87.38 5.05c-4.3-3.85-10-5.6-16.06-4.9-11.08 1.27-20.26 10.54-21.84 21.4L8.22 26.28a2.52 2.52 0 0 0-2.03 1.52 2.54 2.54 0 0 0 .32 2.52l29.32 38.23v28.93c0 .95.53 1.82 1.37 2.25a2.51 2.51 0 0 0 2.61-.19L53.2 90a2.53 2.53 0 0 0 1.06-2.05V67.73L69.2 45.16h.11c.86 0 1.72-.05 2.59-.15C84.08 43.62 94 32.54 94 20.31c0-6.02-2.35-11.45-6.62-15.26z" fill="currentColor"/>'
  },
  welcome_home: {
    width: 15,
    height: 15,
    block: '<path d="M68.71 90.83L64.7 70.25a5.87 5.87 0 0 0-6.57-4.68l-3.25.44a7.3 7.3 0 0 0-6.29 6.8l-1.14 20.43-14.23 1.63 8.1-31.6 9.13-35.68 32.9 61.58-14.64 1.67zM42.91 37.8L28.58 93.73l-12.53-8.55L42.9 37.8zm46.31 52.22L52.2 20.74l4.55-17.77a2.38 2.38 0 0 0-1.73-2.9 2.39 2.39 0 0 0-2.9 1.72l-3.13 12.23-2.1-4.5a2.39 2.39 0 0 0-3.18-1.14 2.38 2.38 0 0 0-1.15 3.16l4.41 9.4-36.16 63.8a2.38 2.38 0 0 0 .73 3.13L28.7 99.58l.09.05c.15.09.3.16.47.22l.17.06a2.36 2.36 0 0 0 .9.08l57.05-6.48a2.39 2.39 0 0 0 1.85-1.26 2.38 2.38 0 0 0-.01-2.23z" fill="currentColor"/>'
  },
  welcome_kit: {
    width: 15,
    height: 15,
    block: '<path d="M49.857 15.46c3.392 0 6.672.449 9.832 1.237l-.812 4.36a35.877 35.877 0 0 0-9.02-1.188c-20.457 0-37.1 16.982-37.1 37.86 0 20.877 16.646 37.865 37.1 37.865 20.46 0 37.106-16.988 37.106-37.865a38.055 38.055 0 0 0-15.249-30.526l1.109-4.629A42.478 42.478 0 0 1 91.286 57.73c0 23.307-18.589 42.27-41.429 42.27C27.011 100 8.43 81.037 8.43 57.729c0-23.3 18.585-42.269 41.428-42.269zM71.451.277c.21.219.298.527.235.823-7.36 36.086-10.472 70.349-10.715 78.1a.914.914 0 0 1-.734.874l-3.348.606a.883.883 0 0 1-.68-.157.923.923 0 0 1-.366-.609l-4.766-32.368-4.988 38.271a.903.903 0 0 1-.732.786l-3.1.554a.655.655 0 0 1-.157.02.873.873 0 0 1-.571-.211.949.949 0 0 1-.329-.7c-.151-22.083-4.417-48.486-6.243-58.812a.943.943 0 0 1 .146-.685.863.863 0 0 1 .58-.372l2.8-.523a.917.917 0 0 1 1.046.743c1.314 7.434 3.52 20.992 4.951 35.652l4.194-32.212c.055-.389.35-.7.735-.777l2.677-.486a.897.897 0 0 1 .683.152.92.92 0 0 1 .36.611l4.528 30.78c1.62-14.92 5.157-38.777 9.249-59.051a.914.914 0 0 1 .723-.715l3.028-.554a.891.891 0 0 1 .797.263l-.003-.003z" fill="currentColor" fill-rule="evenodd"/>'
  },
  write: {
    width: 15,
    height: 15,
    block: '<path d="M90.235 31.677l-8.893 10.021-27.896-25.012 8.9-10.03c.816-.921 1.921-1.465 3.107-1.534a3.938 3.938 0 0 1 2.891.993l21.742 19.496c1.698 1.524 1.765 4.245.149 6.066m3.249-9.88L71.742 2.3c-1.8-1.615-4.137-2.419-6.58-2.287-2.549.146-4.9 1.297-6.624 3.24L47.946 15.19c-.075.082-.13.174-.19.262-.029.042-.062.08-.089.124-.102.17-.182.348-.242.532-.002.007-.008.015-.011.025l-2.757 8.908-13.311 4.837c-6.057 2.2-10.854 7.202-12.832 13.379L3.622 89.797A2.563 2.563 0 0 0 4.785 92.8c1.048.6 2.368.382 3.17-.52l23.331-26.294c.665-.75.832-1.822.426-2.74-1.935-4.377-.697-9.526 3.083-12.813 3.68-3.202 9.114-3.584 12.92-.907 2.387 1.68 3.891 4.223 4.232 7.159.363 3.127-.657 6.304-2.798 8.716-2.9 3.268-7.355 4.57-11.348 3.306a2.548 2.548 0 0 0-2.67.74L11.797 95.74a2.566 2.566 0 0 0-.148 3.218 2.548 2.548 0 0 0 3.108.813l44.3-20.167c5.882-2.677 10.28-8.037 11.766-14.337l3.264-13.846 8.49-3.767c.012-.006.023-.015.034-.02.175-.081.34-.18.493-.3.035-.026.061-.058.095-.085.086-.075.174-.148.252-.234L94.044 35.08c3.482-3.925 3.231-9.884-.56-13.283" fill="currentColor" fill-rule="evenodd"/>'
  },
  xing: {
    width: 15,
    height: 15,
    block: '<path d="M33.63 22.43l9.9 17.3-15.51 27.56c-1.09 1.85-2.4 2.78-3.92 2.78H9.67c-.84 0-1.46-.34-1.87-1.02-.4-.7-.4-1.41 0-2.18l15.27-27.09c.04 0 .04-.02 0-.06l-9.72-16.87c-.48-.89-.5-1.63-.06-2.24.37-.6 1-.9 1.93-.9h14.43c1.6 0 2.93.9 3.98 2.72zM92.17 3.14L60.3 59.61v.06l20.28 37.18c.44.81.46 1.56.06 2.24-.4.6-1.04.9-1.93.9H64.3c-1.7 0-3.02-.9-3.99-2.71l-20.45-37.6L71.89 2.71C72.9.91 74.2 0 75.75 0H90.3c.88 0 1.5.3 1.87.9.44.65.44 1.4 0 2.24z" fill="currentColor"/>'
  },
  youtube: {
    width: 15,
    height: 15,
    block: '<path d="M98.27 26.26a12.66 12.66 0 0 0-10.8-9.87C75.06 15 62.5 15 50.01 15c-12.5 0-25.05 0-37.45 1.4a12.65 12.65 0 0 0-10.8 9.86C.01 33.86 0 42.16 0 50c0 7.83 0 16.13 1.74 23.74a12.65 12.65 0 0 0 10.8 9.87C24.95 85 37.5 85 50 85s25.04 0 37.44-1.4a12.66 12.66 0 0 0 10.81-9.86C99.99 66.14 100 57.83 100 50c0-7.83.01-16.13-1.73-23.74zM37.1 65.59V32.38l31.79 16.65-31.8 16.56z" fill="currentColor"/>'
  }
};

var Icon$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var dataTestId = _ref.dataTestId,
      name = _ref.name,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      title = _ref.title,
      props = _objectWithoutPropertiesLoose(_ref, ["dataTestId", "name", "size", "title"]);

  if (!name) {
    return null;
  }

  var iconConfig = icons[name];

  if (!iconConfig) {
    return null;
  }

  return React.createElement(Icon, _extends({
    dangerouslySetInnerHTML: {
      __html: iconConfig.block
    },
    "data-testid": dataTestId && "icon-" + dataTestId,
    ref: ref,
    role: "img",
    size: size,
    stroked: iconConfig.stroked,
    title: title || name,
    viewBox: iconConfig.viewBox || '0 0 100 100'
  }, props));
});
Icon$1.displayName = 'Icon';

var wrap = function wrap(children) {
  return React.Children.toArray(children).map(function (child) {
    return ['number', 'string'].includes(typeof child) ? React.createElement("span", {
      key: child
    }, child) : child;
  });
};

var overflowEllipsis =
/*#__PURE__*/
css(["white-space:nowrap;overflow:hidden;text-overflow:ellipsis;"]);

var getMax = function getMax(width, height) {
  if (height === void 0) {
    height = width;
  }

  var widthValue = parseInt(width, 10);
  var heightValue = parseInt(height, 10);
  var diff = widthValue - heightValue;
  return diff >= 0 ? width : height;
};

var centerContent =
/*#__PURE__*/
css(["display:flex;align-items:center;justify-content:center;"]);

var shapeStyles = function shapeStyles(size, width, height, shape) {
  if (shape === void 0) {
    shape = 'square';
  }

  return css(["", " width:", ";height:", ";padding:0;border-radius:", ";"], th("tags.shape." + shape + "." + size), width || height ? getMax(width || 0, height) : null, width || height ? getMax(width || 0, height) : null, shape === 'circle' && '50%');
};

var Tag =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Tag",
  componentId: "sc-12bthzp-0"
})(function (_ref) {
  var hasAction = _ref.hasAction,
      height = _ref.height,
      length = _ref.length,
      shape = _ref.shape,
      size = _ref.size,
      variant = _ref.variant,
      width = _ref.width;
  return css(["", ";", ";", " position:relative;display:inline-flex;align-items:center;justify-content:center;border-radius:md;padding-right:", ";", ";", ";", ";> *:not(:last-child){margin-right:xxs;}> *:not(:only-child){", ":last-child{cursor:pointer;path{transition:fill ", ";}&:hover{path,g{fill:", ";}}}}"], th('tags.default'), th("tags.variants." + variant), th("tags.sizes." + size), hasAction ? th('space.xl') : null, overflowEllipsis, system, (shape || length === 1) && shapeStyles(size, width, height, shape), Icon, th.transition('medium'), th('colors.danger.500'));
});
var ActionIcon =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__ActionIcon",
  componentId: "sc-12bthzp-1"
})(function (_ref2) {
  var size = _ref2.size;
  return css(["position:absolute;", ";top:0;bottom:0;right:0;", ";"], th("tags.sizes." + size), centerContent);
});

var Tag$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var children = _ref.children,
      dataTestId = _ref.dataTestId,
      onRemove = _ref.onRemove,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'default' : _ref$variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "dataTestId", "onRemove", "size", "variant"]);

  var content = wrap(children); // get size children for int and string

  var childrenLength = !!(children || children === 0) && ['number', 'string'].includes(typeof children) && children.toString().length;
  return React.createElement(Tag, _extends({
    "data-testid": dataTestId,
    hasAction: !!onRemove,
    length: childrenLength,
    ref: ref,
    role: "listitem",
    size: size,
    variant: variant
  }, rest), content, !!onRemove && React.createElement(ActionIcon, {
    size: size
  }, React.createElement(Icon$1, {
    name: "cross",
    onClick: onRemove,
    size: "xs",
    title: "Remove"
  })));
});
Tag$1.displayName = 'Tag';

var Badge =
/*#__PURE__*/
forwardRef(function (props, ref) {
  return React.createElement(Tag$1, _extends({
    ref: ref,
    size: "sm"
  }, props));
});
Badge.displayName = 'Badge';

var shapeStyles$1 = function shapeStyles(size, shape) {
  return css(["width:", ";padding:0;border-radius:", ";"], th("buttons.sizes." + size + ".height"), shape === 'circle' && th("buttons.sizes." + size + ".height"));
};

var Button =
/*#__PURE__*/
styled(filterComponent(Button$2))(function (_ref) {
  var disabled = _ref.disabled,
      shape = _ref.shape,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      variant = _ref.variant;
  return css(["", ";position:relative;display:inline-flex;align-items:center;justify-content:center;width:auto;", ";text-decoration:none;text-align:center;white-space:nowrap;cursor:pointer;outline:none;border-width:sm;border-style:solid;appearance:none;overflow:hidden;transition:medium;", ";", ";& > *:not(:only-child):not(:last-child){margin-right:sm;}", ";&[disabled]{cursor:not-allowed;}"], th("buttons." + variant), th("buttons.sizes." + size), shape && shapeStyles$1(size, shape), system, !disabled && css(["&:hover,&:focus{", ";}"], th("buttons.focused." + (variant || 'primary'))));
});

var Button$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var as = _ref.as,
      children = _ref.children,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'md' : _ref$size,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'primary' : _ref$variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["as", "children", "dataTestId", "disabled", "size", "variant"]);

  return React.createElement(Button, _extends({
    "data-testid": dataTestId,
    disabled: disabled,
    forwardedAs: as,
    ref: ref,
    size: size,
    variant: disabled ? 'disabled' : variant
  }, rest), children);
});
Button$1.displayName = 'Button';
Button$1.propTypes = {
  as: COMPONENT_TYPE,
  children: node,
  disabled: bool,
  shape: SHAPES_TYPE,
  size:
  /*#__PURE__*/
  oneOf(['xs', 'sm', 'md', 'lg', 'xl']),
  variant:
  /*#__PURE__*/
  oneOf(['primary', 'secondary', 'tertiary', 'quaternary', 'primary-warning', 'secondary-warning', 'primary-danger', 'secondary-danger'])
};

var fade =
/*#__PURE__*/
keyframes(["from{opacity:0;}to{opacity:1;}"]);
var ClearButton =
/*#__PURE__*/
styled(Button).withConfig({
  displayName: "styles__ClearButton",
  componentId: "sc-1igh7f1-0"
})(["pointer-events:auto;animation:", ";animation-name:", ";"],
/*#__PURE__*/
th('transitions.medium'), fade);

var ClearButton$1 = function ClearButton$1(props) {
  return React.createElement(ClearButton, _extends({
    height: 18,
    shape: "circle",
    title: "Clear",
    variant: "quaternary",
    width: 18
  }, props), React.createElement(Icon$1, {
    height: 8,
    name: "cross",
    width: 8
  }));
};

var getFlexStyles = function getFlexStyles(align, justify, direction) {
  return css(["display:flex;align-items:", ";justify-content:", ";"], align || direction === 'column' ? 'flex-start' : 'center', justify || 'flex-start');
};

var FlexContainer =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "layout__FlexContainer",
  componentId: "g939mo-0"
})(["flex-direction:", ";flex:", ";", ";"], function (props) {
  return props.direction || null;
}, function (props) {
  return props.flex || null;
}, function (_ref) {
  var align = _ref.align,
      direction = _ref.direction,
      justify = _ref.justify;
  return getFlexStyles(align, justify, direction);
});
var RowContainer =
/*#__PURE__*/
styled(function (_ref2) {
  var direction = _ref2.direction,
      rest = _objectWithoutPropertiesLoose(_ref2, ["direction"]);

  return React.createElement(FlexContainer, _extends({}, rest, {
    direction: "row"
  }));
}).withConfig({
  displayName: "layout__RowContainer",
  componentId: "g939mo-1"
})(["flex:", ";", ";"], function (props) {
  return props.flex || null;
}, function (_ref3) {
  var align = _ref3.align,
      justify = _ref3.justify;
  return getFlexStyles(align, justify);
});

var TYPES = {
  InputCheckbox: 'checkbox',
  InputRadio: 'radio',
  InputText: 'text',
  RadioTab: 'radio',
  Select: 'text',
  Toggle: 'checkbox'
};
var getBaseType = function getBaseType(type) {
  return TYPES[type] || type;
};

var isPristine = function isPristine(connected, touched) {
  return connected && !touched;
};

var getVariant = function getVariant(_ref) {
  var connected = _ref.connected,
      error = _ref.error,
      touched = _ref.touched,
      warning = _ref.warning;

  if (isPristine(connected, touched)) {
    return undefined;
  } else if (error) {
    return 'error';
  } else if (warning) {
    return 'warning';
  }

  return undefined;
};
var VARIANTS = {
  focused: 'colors.primary.500',
  error: 'colors.danger.500',
  warning: 'colors.warning.500',
  info: 'colors.info.500'
};
var getVariantStateColor = function getVariantStateColor(variant) {
  var variantColor = VARIANTS[variant];
  return variantColor ? th(variantColor) : null;
};
var variantColors =
/*#__PURE__*/
_extends({
  blue: 'colors.sub.blue',
  dark: 'colors.dark.500',
  "default": 'colors.nude.100',
  green: 'colors.sub.green',
  orange: 'colors.sub.orange',
  pink: 'colors.sub.pink',
  primary: 'colors.primary.500',
  purple: 'colors.sub.purple',
  red: 'colors.sub.red',
  secondary: 'colors.secondary.500',
  turquoize: 'colors.sub.turquoize',
  yellow: 'colors.sub.yellow'
}, VARIANTS);

var VariantIcon =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__VariantIcon",
  componentId: "clwgje-0"
})(function (_ref) {
  var variant = _ref.variant;
  return css(["display:inline-flex;margin-right:xxs;color:", ";fill:", ";flex-shrink:0;"], getVariantStateColor(variant), getVariantStateColor(variant));
});

var VariantIcon$1 = function VariantIcon$1(_ref) {
  var errorWarningIcon = _ref.errorWarningIcon,
      variant = _ref.variant;
  return ['error', 'warning'].includes(variant) ? React.createElement(VariantIcon, null, React.createElement(React.Fragment, null, errorWarningIcon && errorWarningIcon, !errorWarningIcon && React.createElement(Badge, {
    shape: "circle",
    variant: variant
  }, "!"))) : null;
};
VariantIcon$1.displayName = 'VariantIcon';

var Label =
/*#__PURE__*/
styled.label.withConfig({
  displayName: "styles__Label",
  componentId: "sc-112u1vj-0"
})(function (_ref) {
  var required = _ref.required;
  return css(["display:flex;flex-shrink:0;align-items:flex-start;line-height:body1;", ";", ";user-select:none;> *{&:not(:last-child){margin-right:xxs;}:last-child{", ";}}"], th('fields.label'), system, required && requiredStyles);
});
var requiredStyles =
/*#__PURE__*/
css(["&::after{content:'*';color:primary.500;margin-left:xxs;}"]);
var Disabled =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Disabled",
  componentId: "sc-112u1vj-1"
})(["display:inline-flex;margin-right:xxs;"]);

var Label$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var checkableField = _ref.checkableField,
      children = _ref.children,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      disabledIcon = _ref.disabledIcon,
      errorWarningIcon = _ref.errorWarningIcon,
      variant = _ref.variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["checkableField", "children", "dataTestId", "disabled", "disabledIcon", "errorWarningIcon", "variant"]);

  // Wrap strings in span to allow for required asterisk
  var content = wrap(children);
  return React.createElement(Label, _extends({
    "data-testid": dataTestId,
    disabled: disabled,
    disabledIcon: disabledIcon,
    ref: ref,
    variant: variant
  }, rest), !checkableField && React.createElement(VariantIcon$1, {
    errorWarningIcon: errorWarningIcon,
    variant: variant
  }), disabled && React.createElement(Disabled, null, disabledIcon || React.createElement(Icon$1, {
    name: "special_pipeline"
  })), content);
});
Label$1.displayName = 'Label';

var Hint =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Hint",
  componentId: "jda5mr-0"
})(function (props) {
  return css(["", ";color:", ";margin-top:sm;display:flex;align-items:center;", ";"], th('fields.hint'), getVariantStateColor(props.variant), system);
});

var Hint$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var checkableField = _ref.checkableField,
      children = _ref.children,
      dataTestId = _ref.dataTestId,
      variant = _ref.variant;
  return React.createElement(Hint, {
    "data-testid": dataTestId,
    ref: ref,
    variant: variant
  }, checkableField && React.createElement(VariantIcon$1, {
    variant: variant
  }), children);
});
Hint$1.displayName = 'Hint';

var FieldGroup =
/*#__PURE__*/
styled(filterComponent('fieldset')).withConfig({
  displayName: "styles__FieldGroup",
  componentId: "qf8tbk-0"
})(["width:100%;min-width:0;min-height:0;margin:0;padding:0;", ";", ";& > ", "{margin-bottom:sm;}"],
/*#__PURE__*/
th('fields.fieldset'), system, Label);

var rowStyles =
/*#__PURE__*/
css(["margin-right:sm;"]);
var columnStyles =
/*#__PURE__*/
css(["margin-bottom:sm;"]);
var checkableFieldStyles =
/*#__PURE__*/
css(["", ";margin-bottom:sm;"],
/*#__PURE__*/
th('fields.checkablelabel.default'));
var Field =
/*#__PURE__*/
styled(filterComponent('div', ['options', 'value', 'renderMultiple']))(function (props) {
  return css(["", "{margin-bottom:", ";}", "{", ";", ";", ";", "}", ";"], FieldGroup, props.checkableField && 'xxs', Label, props.flexDirection === 'row' && rowStyles, props.flexDirection === 'column' && columnStyles, props.checkableField && checkableFieldStyles, props.checked && th('fields.checkablelabel.checked'), wrapperSystem);
});
var IconWrapper =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__IconWrapper",
  componentId: "sc-1lznnai-0"
})(function (_ref) {
  var iconPlacement = _ref.iconPlacement,
      size = _ref.size,
      rest = _objectWithoutPropertiesLoose(_ref, ["iconPlacement", "size"]);

  return css(["position:absolute;top:0;left:", ";right:", ";bottom:0;display:flex;width:", ";justify-content:center;align-items:center;pointer-events:none;transition:medium;transition-timing-function:primary;", ";"], iconPlacement === 'left' ? 0 : null, iconPlacement === 'right' ? 0 : null, size ? th("fields.sizes." + size + ".height")(rest) : null, system);
});
var Input =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Input",
  componentId: "sc-1lznnai-1"
})(["flex-shrink:0;"]);
var Content =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Content",
  componentId: "sc-1lznnai-2"
})([""]);

var Field$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var checked = _ref.checked,
      children = _ref.children,
      Component = _ref.component,
      connected = _ref.connected,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      disabledIcon = _ref.disabledIcon,
      error = _ref.error,
      flexDirection = _ref.flexDirection,
      hint = _ref.hint,
      id = _ref.id,
      label = _ref.label,
      name = _ref.name,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      required = _ref.required,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'lg' : _ref$size,
      touched = _ref.touched,
      type = _ref.type,
      warning = _ref.warning,
      rest = _objectWithoutPropertiesLoose(_ref, ["checked", "children", "component", "connected", "dataTestId", "disabled", "disabledIcon", "error", "flexDirection", "hint", "id", "label", "name", "onChange", "onClick", "required", "size", "touched", "type", "warning"]);

  // Return early if no component
  if (!Component) {
    return null;
  }

  var baseType = getBaseType(type || Component.displayName);
  var variant = getVariant({
    connected: connected,
    touched: touched,
    warning: warning,
    error: error
  });
  var hintText = variant ? error || warning : hint;
  var isRadio = baseType === 'radio';
  var isCheckbox = baseType === 'checkbox';
  var isCheckable = isRadio || isCheckbox;
  var isGroup = ['FieldGroup', 'RadioGroup'].includes(baseType);
  var isShowRequired = isRadio ? null : required;
  var layout = flexDirection || (isCheckable ? 'row' : 'column');
  var Container = flexDirection === 'row' ? RowContainer : Fragment;
  var uniqueId = isRadio ? id : id || name;
  var inputRef = ref || React.createRef();

  var handleClick = function handleClick(e) {
    e.stopPropagation();
    onClick && onClick(e);

    if (isCheckbox) {
      e.target.checked = !e.target.checked;
    }

    if (isCheckbox || isGroup) {
      onChange && onChange(e);
    }
  };

  var handleLabelClick = function handleLabelClick() {
    var input = inputRef.current;

    if (input) {
      Component.displayName === 'MarkdownEditor' ? input.simpleMde.codemirror.focus() : input.focus();
    }
  };

  var Field$1 = React.createElement(Component, _extends({
    checked: checked,
    connected: true,
    dataTestId: dataTestId,
    disabled: disabled,
    flexDirection: layout,
    id: uniqueId,
    label: label,
    name: name,
    onChange: onChange,
    onClick: handleClick,
    ref: inputRef,
    required: required,
    size: size,
    type: baseType,
    variant: variant
  }, rest), children);
  return React.createElement(Field, _extends({
    checkableField: isCheckable,
    checked: checked,
    flexDirection: layout,
    size: size
  }, rest), React.createElement(Container, null, label && !isGroup && React.createElement(Label$1, {
    checkableField: isCheckable,
    disabled: disabled,
    disabledIcon: disabledIcon,
    htmlFor: isCheckable ? null : uniqueId,
    onClick: handleLabelClick,
    required: isShowRequired,
    variant: variant
  }, isCheckable && React.createElement(Input, null, Field$1), React.createElement(Content, null, label)), !isCheckable && Field$1, !label && isCheckable && Field$1), hintText && React.createElement(Hint$1, {
    checkableField: isCheckable,
    variant: variant
  }, hintText));
});
Field$1.displayName = 'Field';

var ConnectedField =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var children = _ref.children,
      component = _ref.component,
      type = _ref.type,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "component", "type"]);

  if (!children && !component) {
    return null;
  }

  return React.createElement(Field$2, _extends({
    type: getBaseType(component.type || type)
  }, rest), function (_ref2) {
    var input = _ref2.input,
        meta = _ref2.meta;
    return React.createElement(Field$1, _extends({
      ref: ref
    }, input, meta, {
      error: meta.error || meta.submitError
    }, rest, {
      component: component,
      connected: true
    }), children);
  });
});
ConnectedField.displayName = 'WelcomeField';

var createEvent = function createEvent(props) {
  return {
    preventDefault: function preventDefault() {},
    target: _extends({}, props)
  };
};

var fieldStyles = function fieldStyles(_ref) {
  var size = _ref.size,
      type = _ref.type,
      variant = _ref.variant;
  return css(["", ";width:100%;border-color:", ";transition:medium;appearance:none;", ";&::placeholder{", ";}&:focus{", ";}&[disabled]{", ";}&[aria-checked='true']{", ";}&:invalid,&:-moz-submit-invalid,&:-moz-ui-invalid{box-shadow:none;}"], th('fields.default'), getVariantStateColor(variant), size && th("fields.sizes." + size), th('fields.placeholder'), th('fields.focused'), th('fields.disabled'), ['radio', 'checkbox'].includes(type) && th("fields." + type + ".checked"));
};

var Wrapper =
/*#__PURE__*/
styled(filterComponent('div'))(function (_ref) {
  var connected = _ref.connected;
  return css(["position:relative;", ";"], connected ? null : wrapperSystem);
});
var InputWrapper =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__InputWrapper",
  componentId: "vjihhi-0"
})(["position:relative;"]);
var Input$1 =
/*#__PURE__*/
styled(filterComponent('div', ['hasIcon', 'inputValue', 'renderMultiple']))(function (_ref2) {
  var hasIcon = _ref2.hasIcon,
      size = _ref2.size;
  return css(["position:relative;", ";", ";padding-right:", ";padding-left:", ";cursor:default;", " br{display:none;}&::before{content:attr(data-spacer);visibility:hidden;display:block;height:0;}&:empty{&::after{content:attr(placeholder);position:absolute;top:0;right:0;bottom:0;left:0;", ";padding:inherit;opacity:0.5;}&::before{height:auto;}}"], fieldStyles, overflowEllipsis, th("fields.sizes." + size + ".height"), hasIcon && th("fields.sizes." + size + ".height"), componentSystem, overflowEllipsis);
});
var Menu =
/*#__PURE__*/
styled.ul.withConfig({
  displayName: "styles__Menu",
  componentId: "vjihhi-1"
})(["", ";position:absolute;z-index:2;right:0;left:0;margin:0;margin-top:md;padding:0;border:1px solid;border-color:nude.200;border-radius:sm;background-color:light.100;transition:medium;box-shadow:sm;overflow:auto;overflow-scrolling:touch;"],
/*#__PURE__*/
th('fields.select.default'));
var Item =
/*#__PURE__*/
styled.li.withConfig({
  displayName: "styles__Item",
  componentId: "vjihhi-2"
})(function (_ref3) {
  var isExisting = _ref3.isExisting,
      isHighlighted = _ref3.isHighlighted,
      isSelected = _ref3.isSelected;
  return css(["color:nude.800;", ";", ";", ";", ";padding:sm;list-style:none;text-decoration:none;font-size:body3;transition:background ", ";"], isHighlighted && th('fields.select.highlighted'), isSelected && th('fields.select.selected'), isExisting && th('fields.select.existing'), overflowEllipsis, th.transition('medium'));
});
var Icon$2 =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Icon",
  componentId: "vjihhi-3"
})(function (_ref4) {
  var size = _ref4.size;
  return css(["position:absolute;width:", ";padding:0;top:0;bottom:0;left:0;", ""], th("fields.sizes." + size + ".height"), centerContent);
});
var Indicators =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Indicators",
  componentId: "vjihhi-4"
})(["position:absolute;padding:0;top:0;bottom:0;right:0;display:flex;"]);
var DropDownIndicator =
/*#__PURE__*/
styled.button.withConfig({
  displayName: "styles__DropDownIndicator",
  componentId: "vjihhi-5"
})(function (_ref5) {
  var isOpen = _ref5.isOpen,
      size = _ref5.size;
  return css(["position:relative;height:100%;width:", ";padding:0;outline:none;appearance:none;cursor:pointer;border:none;background:transparent;", ";", "{transform:", ";transition:medium;}&:not(:last-child){width:auto;}"], th("fields.sizes." + size + ".height"), centerContent, Icon, isOpen ? 'rotate3d(0, 0, 1, 180deg)' : 'rotate3d(0)');
});
var Tags =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Tags",
  componentId: "vjihhi-6"
})(["margin-top:lg;", ":not(:last-child){margin-right:sm;margin-bottom:sm;}&:empty{display:none;}"], Tag);

var MultipleSelections = function MultipleSelections(values, handleRemove) {
  return React.createElement(Tags, null, values.map(function (tag) {
    return React.createElement(Tag$1, {
      key: tag.value,
      onRemove: function onRemove() {
        return handleRemove(tag.value);
      }
    }, tag.label);
  }));
};

var EMPTY_STRING = '';
var itemToString = function itemToString(item) {
  return item ? item.label : EMPTY_STRING;
};
var getSpacer = function getSpacer(options) {
  return options.reduce(function (prev, current) {
    return current.label && prev.length > current.label.length ? prev : current.label;
  }, EMPTY_STRING);
};
var getUniqueValue = function getUniqueValue(item, values) {
  return uniqBy([].concat(values, [item]), function (item) {
    return item.value;
  });
};
var isValueSelected = function isValueSelected(value, options) {
  return !!options.find(function (item) {
    return item.value === value;
  });
};
var getOption = function getOption(value, options) {
  if (options === void 0) {
    options = [];
  }

  var option = options.find(function (option) {
    return option.label === (value.label || value) || option.value === (value.value || value);
  }); // Create the option if it doesn't exist

  return option || {
    value: kebabCase(value),
    label: value
  };
};
var getOptionsFromSelected = function getOptionsFromSelected(selected, options) {
  if (!selected && selected !== 0) {
    return [];
  } else if (Array.isArray(selected)) {
    return selected.map(function (value) {
      return getOption(value, options);
    });
  } else {
    return [getOption(selected, options)];
  }
};

var getIsExisting = function getIsExisting(option, options) {
  return !!options.find(function (item) {
    return item.value === option.value;
  });
};

var getValue = function getValue(option, options) {
  return getIsExisting(option, options) ? option.value : option.label;
};

var getValuesFromOptions = function getValuesFromOptions(selected, options) {
  if (!selected) {
    return;
  }

  return selected.map(function (selected) {
    return getValue(selected, options);
  });
};
var getNewOptions = function getNewOptions(selected, options) {
  if (!selected) {
    return;
  }

  return differenceBy(selected, options, 'value');
};
var getInputValue = function getInputValue(_ref) {
  var inputValue = _ref.inputValue,
      isMultiple = _ref.isMultiple,
      isSearchable = _ref.isSearchable,
      options = _ref.options,
      renderItem = _ref.renderItem;
  var option = getOption(inputValue, options);

  if (isMultiple) {
    return inputValue;
  }

  if (option.label) {
    if (isSearchable) {
      return option.label;
    } else {
      return renderItem(option);
    }
  }

  return EMPTY_STRING;
};

var EMPTY_STRING$1 = '';
var Select =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var autoFocus = _ref.autoFocus,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      icon = _ref.icon,
      id = _ref.id,
      isClearable = _ref.isClearable,
      isCreatable = _ref.isCreatable,
      isMultiple = _ref.isMultiple,
      _ref$isSearchable = _ref.isSearchable,
      isSearchable = _ref$isSearchable === void 0 ? isCreatable || isSearchable : _ref$isSearchable,
      _ref$options = _ref.options,
      defaultOptions = _ref$options === void 0 ? [] : _ref$options,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      onCreate = _ref.onCreate,
      onFocus = _ref.onFocus,
      onKeyDown = _ref.onKeyDown,
      _ref$placeholder = _ref.placeholder,
      placeholder = _ref$placeholder === void 0 ? 'Choose from…' : _ref$placeholder,
      _ref$renderItem = _ref.renderItem,
      renderItem = _ref$renderItem === void 0 ? itemToString : _ref$renderItem,
      _ref$renderMultiple = _ref.renderMultiple,
      renderMultiple = _ref$renderMultiple === void 0 ? MultipleSelections : _ref$renderMultiple,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'lg' : _ref$size,
      type = _ref.type,
      defaultSelected = _ref.value,
      variant = _ref.variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["autoFocus", "dataTestId", "disabled", "icon", "id", "isClearable", "isCreatable", "isMultiple", "isSearchable", "options", "name", "onBlur", "onChange", "onClick", "onCreate", "onFocus", "onKeyDown", "placeholder", "renderItem", "renderMultiple", "size", "type", "value", "variant"]);

  var defaultSelecteds = useMemo(function () {
    return getOptionsFromSelected(defaultSelected, defaultOptions);
  }, [defaultSelected, defaultOptions]);
  var selectedItem = !isMultiple && defaultSelecteds[0] || null;
  var defaultInputValue = selectedItem ? selectedItem.label : EMPTY_STRING$1; // We keep 3 things in state:
  // a. selected = currently selected item(s)
  // b. inputValue = text in the select/search box
  // c. options = options in the dropdown

  var _useState = useState(defaultSelecteds),
      selected = _useState[0],
      setSelected = _useState[1];

  var _useState2 = useState(defaultInputValue),
      inputValue = _useState2[0],
      setInputValue = _useState2[1];

  var _useState3 = useState(defaultOptions),
      options = _useState3[0],
      setOptions = _useState3[1]; // Autofocus


  useEffect(function () {
    if (autoFocus) {
      ref.current.focus();
    }
  }, [autoFocus, ref]); // Ensure values are controlled by parent

  useEffect(function () {
    setSelected(defaultSelecteds);
    setInputValue(defaultInputValue);
    setOptions(defaultOptions);
  }, [defaultInputValue, defaultOptions, defaultSelecteds]); // Update options when searching

  var handleInputChange = function handleInputChange(value) {
    // Update
    if (isSearchable && value !== inputValue) {
      var _options = matchSorter(defaultOptions, value, {
        keys: ['label']
      });

      setInputValue(value);
      setOptions(_options);
    }
  }; // Send event to parent when value(s) changes


  var handleChange = function handleChange(options) {
    var values = getValuesFromOptions(options, defaultOptions);
    var value = isMultiple ? values : values[0];
    var event = createEvent({
      name: name,
      value: isMultiple ? options : options[0]
    });
    onChange && onChange(value, event); // If there are newly-created options, call `onCreate`

    if (isCreatable) {
      var newOptions = getNewOptions(options, defaultOptions);

      if (newOptions.length) {
        onCreate && onCreate(newOptions[0].label, event);
      }
    }
  }; // Update internal state when clicking/adding a select item


  var handleSelect = function handleSelect(option) {
    var newItems;
    var isClearInput;

    if (!option) {
      // If removing option
      newItems = isMultiple ? selected : [];
      isClearInput = true;
    } else {
      // If adding option
      newItems = isMultiple ? getUniqueValue(option, selected) : [option];
      isClearInput = isMultiple;
    }

    isClearInput && setInputValue(EMPTY_STRING$1);
    setOptions(defaultOptions);
    setSelected(newItems);
    handleChange(newItems);
  };

  var handleRemove = function handleRemove(value) {
    var newItems = selected.filter(function (item) {
      return item.value !== value;
    });
    setSelected(newItems);
    handleChange(newItems);
  };

  var handleOuterClick = function handleOuterClick(e) {
    // Reset input value if not selecting a new item
    if (isMultiple && e.selectedItem) {
      setInputValue(EMPTY_STRING$1);
    } else if (isSearchable && e.selectedItem) {
      setInputValue(e.selectedItem.label);
    }

    setOptions(defaultOptions);
  };

  var spacer = getSpacer(defaultOptions);
  var inputContent = getInputValue({
    inputValue: inputValue,
    isMultiple: isMultiple,
    isSearchable: isSearchable,
    options: defaultOptions,
    renderItem: renderItem
  });
  return React.createElement(Downshift, {
    inputValue: isSearchable ? inputContent : EMPTY_STRING$1,
    itemToString: itemToString,
    onInputValueChange: handleInputChange,
    onOuterClick: handleOuterClick,
    onSelect: handleSelect,
    selectedItem: selectedItem
  }, function (_ref2) {
    var clearSelection = _ref2.clearSelection,
        getInputProps = _ref2.getInputProps,
        getItemProps = _ref2.getItemProps,
        getMenuProps = _ref2.getMenuProps,
        getRootProps = _ref2.getRootProps,
        getToggleButtonProps = _ref2.getToggleButtonProps,
        highlightedIndex = _ref2.highlightedIndex,
        isOpen = _ref2.isOpen,
        toggleMenu = _ref2.toggleMenu;
    var isShowCreate = !!(isCreatable && inputValue && !isValueSelected(inputValue, selected));
    var isShowMenu = isOpen && (options.length || isShowCreate);
    var isShowDeleteIcon = isClearable && inputValue;
    var DeleteIcon = React.createElement(DropDownIndicator, {
      as: "div",
      size: size
    }, React.createElement(ClearButton$1, {
      onClick: clearSelection
    }));
    var Arrow = React.createElement(DropDownIndicator, _extends({
      disabled: disabled,
      isOpen: isOpen,
      size: size,
      tabIndex: -1
    }, getToggleButtonProps()), React.createElement(Icon$1, {
      color: "nude.800",
      name: "down",
      size: "xs"
    }));

    var handleInputClick = function handleInputClick(e) {
      onClick && onClick(e);
      toggleMenu();
    };

    var rootProps = getRootProps(rest);
    var inputProps = getInputProps(_extends({
      // HACK for chrome : https://bugs.chromium.org/p/chromium/issues/detail?id=914451
      autoComplete: 'new-password',
      autoFocus: autoFocus,
      'data-spacer': spacer || placeholder,
      'data-testid': dataTestId,
      disabled: disabled,
      hasIcon: !!icon,
      id: id,
      name: name,
      onBlur: onBlur,
      onClick: handleInputClick,
      onFocus: onFocus,
      placeholder: placeholder,
      ref: ref,
      size: size,
      tabIndex: 0,
      variant: isOpen ? 'focused' : variant
    }, rest));
    return React.createElement(Wrapper, rootProps, React.createElement(InputWrapper, null, isSearchable ? React.createElement(Input$1, _extends({
      as: "input",
      type: "text"
    }, inputProps)) : React.createElement(Input$1, inputProps, inputContent), icon && React.createElement(Icon$2, {
      size: size
    }, icon), React.createElement(Indicators, {
      size: size
    }, isShowDeleteIcon && DeleteIcon, Arrow)), isShowMenu && React.createElement(Menu, getMenuProps(), options.map(function (item, index) {
      return React.createElement(Item, _extends({
        key: item.value
      }, getItemProps({
        index: index,
        isExisting: isMultiple && isValueSelected(item.value, selected),
        isHighlighted: highlightedIndex === index,
        isSelected: !isMultiple && isEqual(selectedItem, item),
        item: item
      })), renderItem(item));
    }), isShowCreate && inputValue.length && React.createElement(Item, _extends({
      key: "add"
    }, getItemProps({
      index: options.length,
      isHighlighted: highlightedIndex === options.length,
      item: {
        value: kebabCase(inputValue),
        label: inputValue
      }
    })), "Create \"" + inputValue + "\"")), isMultiple && renderMultiple(selected, handleRemove));
  });
});
Select.displayName = 'Select';

var DatePicker =
/*#__PURE__*/
styled(ReactDatePicker).withConfig({
  displayName: "styles__DatePicker",
  componentId: "sc-1dtl08q-0"
})(["", ";", ";"], fieldStyles, componentSystem);

var TimePicker =
/*#__PURE__*/
styled(ReactDatePicker).withConfig({
  displayName: "styles__TimePicker",
  componentId: "sc-1n5mnf4-0"
})(["", ";text-align:center;", ";"], fieldStyles, componentSystem);

if (typeof window !== 'undefined') {
  require('react-datepicker/dist/react-datepicker.css');
}

var focusStyles =
/*#__PURE__*/
css(["&:focus{position:relative;z-index:1;}"]);
var DateTimePicker =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__DateTimePicker",
  componentId: "sc-1jfzdw8-0"
})(function (_ref) {
  var connected = _ref.connected,
      datePickerOnly = _ref.datePickerOnly,
      timePickerOnly = _ref.timePickerOnly,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? 'auto' : _ref$width;
  return css(["position:relative;display:", ";flex-wrap:nowrap;.react-datepicker-wrapper:first-child:not(:only-child){margin-right:-1px;}.react-datepicker-wrapper{flex-grow:1;", "{", ";border-top-right-radius:", ";border-bottom-right-radius:", ";}", "{", ";border-top-left-radius:", ";border-bottom-left-radius:", ";}}.react-datepicker__input-container{display:block;}.react-datepicker{font-family:inherit;}", ";"], width === 'auto' ? 'inline-flex' : 'flex', DatePicker, focusStyles, datePickerOnly ? null : 0, datePickerOnly ? null : 0, TimePicker, focusStyles, timePickerOnly ? null : 0, timePickerOnly ? null : 0, connected ? null : wrapperSystem);
});

var iconPlacementStyles = function iconPlacementStyles(placement, size, rest) {
  if (placement === 'right') {
    return css(["", "{&:not(:last-child){right:", ";width:", ";justify-content:flex-end;}&:only-of-type{right:0.625rem;}}", ",", "{padding-right:", ";}"], IconWrapper, th("fields.sizes." + size + ".height")(rest), "calc(0.5 * " + th("fields.sizes." + size + ".height")(rest) + ")", DatePicker, TimePicker, "calc(1.5 * " + th("fields.sizes." + size + ".height")(rest) + ")");
  }

  if (placement === 'left') {
    return css(["", ",", "{padding-left:", ";}"], DatePicker, TimePicker, th("fields.sizes." + size + ".height")(rest));
  }
};

var CustomHeader =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__CustomHeader",
  componentId: "sc-1jfzdw8-1"
})(["display:flex;align-items:center;justify-content:space-between;margin-bottom:lg;text-align:left;", "{width:25;height:25;", "{width:10;height:10;}}"], Button, Icon);
var Selects =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Selects",
  componentId: "sc-1jfzdw8-2"
})(["display:flex;", ":first-child{margin-right:sm;}"], Wrapper);
var CustomInput =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__CustomInput",
  componentId: "sc-1jfzdw8-3"
})(function (_ref2) {
  var focused = _ref2.focused,
      icon = _ref2.icon,
      iconPlacement = _ref2.iconPlacement,
      size = _ref2.size,
      rest = _objectWithoutPropertiesLoose(_ref2, ["focused", "icon", "iconPlacement", "size"]);

  return css(["position:relative;", ",", "{padding-right:", ";}", ";", "{z-index:", ";}"], DatePicker, TimePicker, th("fields.sizes." + size + ".height")(rest), icon && iconPlacementStyles(iconPlacement, size, rest), ClearButton, focused ? 1 : null);
});

var MONTHS = [{
  value: 0,
  label: 'January'
}, {
  value: 1,
  label: 'February'
}, {
  value: 2,
  label: 'March'
}, {
  value: 3,
  label: 'April'
}, {
  value: 4,
  label: 'May'
}, {
  value: 5,
  label: 'June'
}, {
  value: 6,
  label: 'July'
}, {
  value: 7,
  label: 'August'
}, {
  value: 8,
  label: 'September'
}, {
  value: 9,
  label: 'October'
}, {
  value: 10,
  label: 'November'
}, {
  value: 11,
  label: 'December'
}];
var getDate = function getDate(date, interval) {
  if (!date) {
    return null;
  } // If invalid date, use today


  var newDate = new Date(date);

  if (isNaN(newDate.getTime())) {
    newDate = new Date();
  } // Round to nearest interval


  var nextInterval = Math.ceil(newDate.getMinutes() / interval) * interval; // Set minutes to nearest interval

  return new Date(newDate.setMinutes(nextInterval, 0, 0));
};
var getMonths = function getMonths(locale) {
  if (!locale) {
    return MONTHS;
  }

  return MONTHS.map(function (item, index) {
    return _extends({}, item, {
      label: locale.localize.month(index)
    });
  });
};
var getYears = function getYears(startYear, endYear) {
  return range(startYear, endYear + 1).map(function (year) {
    return {
      label: year,
      value: year
    };
  }).reverse();
};

var CustomHeader$1 = function CustomHeader$1(_ref) {
  var changeMonth = _ref.changeMonth,
      changeYear = _ref.changeYear,
      date = _ref.date,
      decreaseMonth = _ref.decreaseMonth,
      endYear = _ref.endYear,
      increaseMonth = _ref.increaseMonth,
      locale = _ref.locale,
      startYear = _ref.startYear;

  var _useState = useState(null),
      month = _useState[0],
      setMonth = _useState[1];

  var _useState2 = useState(null),
      year = _useState2[0],
      setYear = _useState2[1];

  var months = useMemo(function () {
    return getMonths(locale);
  }, [locale]);
  var years = useMemo(function () {
    return getYears(startYear, endYear);
  }, [startYear, endYear]);
  useEffect(function () {
    var currentDate = new Date(date);
    var currentMonth = months[currentDate.getMonth()].label;
    var currentYear = currentDate.getFullYear();
    setMonth(currentMonth);
    setYear(currentYear);
  }, [date, months]);
  return React.createElement(CustomHeader, null, React.createElement(Button$1, {
    disabled: month === months[0].label && year === startYear,
    onClick: decreaseMonth,
    shape: "circle",
    title: "Previous month",
    variant: "secondary"
  }, React.createElement(Icon$1, {
    mr: 2,
    name: "left"
  })), React.createElement(Selects, null, React.createElement(Select, {
    onChange: changeMonth,
    options: months,
    size: "sm",
    value: month
  }), React.createElement(Select, {
    onChange: changeYear,
    options: years,
    size: "sm",
    value: year
  })), React.createElement(Button$1, {
    disabled: month === months[months.length - 1].label && year === endYear,
    onClick: increaseMonth,
    shape: "circle",
    title: "Next month",
    variant: "secondary"
  }, React.createElement(Icon$1, {
    ml: 2,
    name: "right"
  })));
};
CustomHeader$1.displayName = 'CustomHeader';

var CustomInput$1 =
/*#__PURE__*/
function (_PureComponent) {
  _inheritsLoose(CustomInput$1, _PureComponent);

  function CustomInput$1() {
    return _PureComponent.apply(this, arguments) || this;
  }

  var _proto = CustomInput$1.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        focused = _this$props.focused,
        handleBlur = _this$props.handleBlur,
        handleFocus = _this$props.handleFocus,
        icon = _this$props.icon,
        iconPlacement = _this$props.iconPlacement,
        inputRef = _this$props.inputRef,
        onReset = _this$props.onReset,
        size = _this$props.size,
        value = _this$props.value,
        rest = _objectWithoutPropertiesLoose(_this$props, ["focused", "handleBlur", "handleFocus", "icon", "iconPlacement", "inputRef", "onReset", "size", "value"]);

    return React.createElement(CustomInput, {
      focused: focused,
      icon: icon,
      iconPlacement: iconPlacement,
      onBlur: handleBlur,
      onFocus: handleFocus,
      size: size
    }, icon && React.createElement(IconWrapper, {
      iconPlacement: iconPlacement,
      size: size
    }, icon), React.createElement("input", _extends({
      ref: inputRef,
      value: value
    }, rest)), value && React.createElement(IconWrapper, {
      iconPlacement: "right",
      size: size
    }, React.createElement(ClearButton$1, {
      "aria-label": "clear date",
      onClick: onReset
    })));
  };

  return CustomInput$1;
}(PureComponent);

var DEFAULT_DATE =
/*#__PURE__*/
new Date();

var Popper =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Popper",
  componentId: "sc-80h3q5-0"
})(function (_ref) {
  var zIndex = _ref.zIndex;
  return css([".react-datepicker-popper{z-index:", ";}.react-datepicker{padding:lg;font-family:inherit;border-color:nude.200;&--time-only{padding:0;.react-datepicker__time-box{border-radius:0;}}}.react-datepicker-time__header,.react-datepicker__triangle{display:none;}.react-datepicker__time-container{width:100px;.react-datepicker__time .react-datepicker__time-box{width:100%;ul.react-datepicker__time-list li.react-datepicker__time-list-item{height:auto;padding:sm;}}}.react-datepicker__header{padding:0;background-color:light.100;border:none;}.react-datepicker__day,.react-datepicker__day-name,.react-datepicker__time-list-item{color:nude.800;font-weight:regular;}.react-datepicker__day{&,&-name{margin:0.166rem 0.45rem;}&-name{text-transform:uppercase;font-weight:medium;font-size:meta2;letter-spacing:1px;}&--outside-month{color:nude.600;}}.react-datepicker__day:hover,.react-datepicker__month-text:hover,.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item:hover{background-color:nude.100;}.react-datepicker__day,.react-datepicker__day--keyboard-selected,.react-datepicker__day--selected,.react-datepicker__day--in-selecting-range,.react-datepicker__day--in-range,.react-datepicker__month-text--selected,.react-datepicker__month-text--keyboard-selected,.react-datepicker__month-text--in-selecting-range,.react-datepicker__month-text--in-range,.react-datepicker__month-text:hover{border-radius:50%;&:hover{border-radius:50%;}}.react-datepicker__day--keyboard-selected,.react-datepicker__month-text--keyboard-selected,.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item--selected,.react-datepicker__day--selected,.react-datepicker__day--in-selecting-range,.react-datepicker__day--in-range,.react-datepicker__month-text--selected,.react-datepicker__month-text--in-selecting-range,.react-datepicker__month-text--in-range{color:light.100;font-weight:bold;background-color:primary.500;&:hover{color:light.100;font-weight:bold;background-color:primary.500;}}.react-datepicker__day-names,.react-datepicker__month{margin:0 -0.45rem;}.react-datepicker__day--today{font-weight:bold;}.react-datepicker__month-text--today,.react-datepicker__current-month,.react-datepicker-time__header,.react-datepicker-year-header{font-weight:medium;}"], zIndex);
});

var DatePickerPopper = function DatePickerPopper(props) {
  var children = props.children;
  if (!children) return null;
  return typeof window !== 'undefined' ? createPortal(React.createElement(Popper, children.props, children), document.querySelector('body')) : null;
};

var DatePicker$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var autoFocus = _ref.autoFocus,
      dataTestId = _ref.dataTestId,
      _ref$dateFormat = _ref.dateFormat,
      dateFormat = _ref$dateFormat === void 0 ? 'dd/MM/yyyy' : _ref$dateFormat,
      _ref$endYear = _ref.endYear,
      endYear = _ref$endYear === void 0 ? DEFAULT_DATE.getFullYear() : _ref$endYear,
      icon = _ref.icon,
      _ref$iconPlacement = _ref.iconPlacement,
      iconPlacement = _ref$iconPlacement === void 0 ? 'left' : _ref$iconPlacement,
      inputRef = _ref.inputRef,
      locale = _ref.locale,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      placeholder = _ref.placeholder,
      popperZIndex = _ref.popperZIndex,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'lg' : _ref$size,
      _ref$startYear = _ref.startYear,
      startYear = _ref$startYear === void 0 ? 1900 : _ref$startYear,
      _ref$useWeekdaysShort = _ref.useWeekdaysShort,
      useWeekdaysShort = _ref$useWeekdaysShort === void 0 ? true : _ref$useWeekdaysShort,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? DEFAULT_DATE : _ref$value,
      rest = _objectWithoutPropertiesLoose(_ref, ["autoFocus", "dataTestId", "dateFormat", "endYear", "icon", "iconPlacement", "inputRef", "locale", "onBlur", "onChange", "onFocus", "placeholder", "popperZIndex", "size", "startYear", "useWeekdaysShort", "value"]);

  var formatDate = function formatDate(date) {
    return getDate(date, 15);
  };

  var placeholderText = placeholder || rest.placeholderText;

  var _useState = useState(autoFocus && 'date' || null),
      focused = _useState[0],
      setFocused = _useState[1];

  var _useState2 = useState(formatDate(value)),
      date = _useState2[0],
      setDate = _useState2[1];

  var inputReference = inputRef || ref; // format date at component mount

  useEffect(function () {
    onChange && onChange(formatDate(value)); //eslint-disable-next-line
  }, []); // Ensure values are controlled by parent

  useEffect(function () {
    var formattedDate = formatDate(value);

    if (new Date(Date.parse(value)) - formattedDate !== 0 && onChange) {
      onChange(formattedDate);
    }

    setDate(formattedDate); //eslint-disable-next-line
  }, [value]);

  var blur = function blur() {
    return inputReference.current.blur();
  };

  var _handleFocus = function handleFocus(e) {
    setFocused('date');
    onFocus && onFocus(e);
  };

  var _handleBlur = function handleBlur(e) {
    setFocused(null);
    onBlur && onBlur(e);
  };

  var handleKeyDown = function handleKeyDown(e) {
    if (['Escape', 'Enter'].includes(e.key)) {
      blur();
    }
  };

  var handleReset = function handleReset(e) {
    e.preventDefault();
    blur();
    setDate(null);
    onChange && onChange();
  };

  var handleChange = function handleChange(newDate) {
    if (!newDate) return;
    var date = formatDate(newDate);
    newDate = newDate.setHours(date.getHours(), date.getMinutes());
    setDate(newDate);
    onChange && onChange(new Date(newDate));
  };

  return React.createElement(DatePicker, _extends({
    autoComplete: "off",
    calendarClassName: "date-picker-popper",
    customInput: React.createElement(CustomInput$1, {
      className: "date-picker",
      "data-testid": dataTestId,
      focused: focused,
      handleBlur: function handleBlur(e) {
        return _handleBlur('date', e);
      },
      handleFocus: function handleFocus(e) {
        return _handleFocus('date', e);
      },
      icon: icon,
      iconPlacement: iconPlacement,
      inputRef: inputReference,
      onReset: handleReset,
      size: size
    }),
    dateFormat: dateFormat,
    locale: locale,
    onChange: handleChange,
    onKeyDown: handleKeyDown,
    placeholderText: placeholderText,
    popperContainer: DatePickerPopper,
    popperProps: {
      zIndex: popperZIndex
    },
    renderCustomHeader: function renderCustomHeader(props) {
      return React.createElement(CustomHeader$1, _extends({
        endYear: endYear,
        locale: locale,
        startYear: startYear
      }, props));
    },
    selected: date,
    size: size,
    useWeekdaysShort: useWeekdaysShort
  }, rest, {
    isClearable: false
  }));
});
DatePicker$1.displayName = 'DatePicker';

var TimePicker$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var autoFocus = _ref.autoFocus,
      dataTestId = _ref.dataTestId,
      _ref$dateFormat = _ref.dateFormat,
      dateFormat = _ref$dateFormat === void 0 ? 'HH:mm' : _ref$dateFormat,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? DEFAULT_DATE : _ref$value,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'lg' : _ref$size,
      icon = _ref.icon,
      _ref$iconPlacement = _ref.iconPlacement,
      iconPlacement = _ref$iconPlacement === void 0 ? 'left' : _ref$iconPlacement,
      inputRef = _ref.inputRef,
      placeholder = _ref.placeholder,
      _ref$timeIntervals = _ref.timeIntervals,
      timeIntervals = _ref$timeIntervals === void 0 ? 15 : _ref$timeIntervals,
      rest = _objectWithoutPropertiesLoose(_ref, ["autoFocus", "dataTestId", "dateFormat", "value", "onBlur", "onChange", "onFocus", "size", "icon", "iconPlacement", "inputRef", "placeholder", "timeIntervals"]);

  var formatDate = function formatDate(date) {
    return getDate(date, timeIntervals);
  };

  var placeholderText = placeholder || rest.placeholderText;

  var _useState = useState(autoFocus && 'time' || null),
      focused = _useState[0],
      setFocused = _useState[1];

  var _useState2 = useState(formatDate(value)),
      date = _useState2[0],
      setDate = _useState2[1]; // format date at component mount


  useEffect(function () {
    onChange && onChange(formatDate(value)); //eslint-disable-next-line
  }, []); // Ensure values are controlled by parent

  useEffect(function () {
    var formattedDate = formatDate(value);

    if (new Date(value) - formattedDate !== 0 && onChange) {
      onChange(formattedDate);
    }

    setDate(formattedDate); //eslint-disable-next-line
  }, [value]);

  var handleFocus = function handleFocus(e) {
    setFocused('time');
    onFocus && onFocus(e);
  };

  var _handleBlur = function handleBlur(e) {
    setFocused(null);
    onBlur && onBlur(e);
  };

  var handleReset = function handleReset(e) {
    e.preventDefault();
    setDate(null);
    onChange && onChange();
  };

  var handleChange = function handleChange(newDate) {
    if (!newDate) return;
    var date = formatDate(newDate);
    newDate = newDate.setFullYear(date.getFullYear(), date.getMonth(), date.getDate());
    setDate(newDate);
    onChange && onChange(new Date(newDate));
  };

  return React.createElement(TimePicker, _extends({
    calendarClassName: "time-picker-popper",
    customInput: React.createElement(CustomInput$1, {
      className: "time-picker",
      "data-testid": dataTestId,
      focused: focused,
      handleBlur: function handleBlur(e) {
        return _handleBlur('date', e);
      },
      handleFocus: handleFocus,
      icon: icon,
      iconPlacement: iconPlacement,
      inputRef: inputRef || ref,
      onReset: handleReset,
      size: size
    }),
    dateFormat: dateFormat,
    onChange: handleChange,
    placeholderText: placeholderText,
    popperContainer: DatePickerPopper,
    selected: date,
    showTimeSelect: true,
    showTimeSelectOnly: true,
    size: size,
    timeIntervals: timeIntervals
  }, rest, {
    isClearable: false
  }));
});
TimePicker$1.displayName = 'TimePicker';

var DateTimePicker$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var children = _ref.children,
      dataTestId = _ref.dataTestId,
      locale = _ref.locale,
      onChange = _ref.onChange,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'lg' : _ref$size,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? DEFAULT_DATE : _ref$value;

  var formatDate = function formatDate(date) {
    return getDate(date, 15);
  };

  var _useState = useState(formatDate(value)),
      date = _useState[0],
      setDate = _useState[1];

  var handleChange = function handleChange(newDate) {
    setDate(newDate || null);
    onChange && onChange(newDate && new Date(newDate));
  }; // format date at component mount


  useEffect(function () {
    onChange && handleChange(formatDate(value)); //eslint-disable-next-line
  }, []); // Ensure values are controlled by parent

  useEffect(function () {
    var formattedDate = formatDate(value);

    if (new Date(value) - formattedDate !== 0 && onChange) {
      handleChange(formattedDate);
    }

    setDate(formattedDate); //eslint-disable-next-line
  }, [value]);
  return React.createElement(DateTimePicker, {
    "data-testid": dataTestId,
    size: size
  }, children && children.map(function (child, i) {
    return cloneElement(child, {
      key: i,
      onChange: handleChange,
      // give ref only to the first child
      inputRef: i < 1 && ref,
      locale: locale,
      value: date
    });
  }), !children && React.createElement(React.Fragment, null, React.createElement(DatePicker$1, {
    inputRef: ref,
    locale: locale,
    onChange: handleChange,
    size: size,
    value: value
  }), React.createElement(TimePicker$1, {
    locale: locale,
    onChange: handleChange,
    size: size,
    value: value
  })));
});
DateTimePicker$1.displayName = 'DateTimePicker';

var FieldGroup$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var children = _ref.children,
      label = _ref.label,
      required = _ref.required;
  return React.createElement(FieldGroup, {
    ref: ref
  }, label && React.createElement(Label$1, {
    as: "legend",
    required: required
  }, label), children);
});
FieldGroup$1.displayName = 'FieldGroup';
FieldGroup$1.propTypes = {
  children: node,
  label: string,
  required: bool
};

var validateMimeType = function validateMimeType(file, mimeTypes) {
  if (!file || !file.type) {
    return false;
  }

  var mimeTypeRegex = new RegExp(mimeTypes.replace('*', '[^\\/,]+'));
  return mimeTypeRegex.test(file.type);
};
var validateFileSize = function validateFileSize(file, size) {
  return file && file.size <= size;
};

var getBorderColor = function getBorderColor(_ref) {
  var isDragAccept = _ref.isDragAccept,
      isDragReject = _ref.isDragReject;

  if (isDragAccept) {
    return 'primary.default';
  }

  if (isDragReject) {
    return 'danger.default';
  }

  return null;
};

var disabledStyles =
/*#__PURE__*/
css(["background:light.500;h3,p{color:nude.700;}"]);
var FileDrop =
/*#__PURE__*/
styled(filterComponent('div'))(function (props) {
  return css(["", ";", ";border-color:", ";position:relative;display:flex;justify-content:space-between;align-items:center;padding:md;", ";h3{font-size:h3;font-weight:normal;}", ";"], fieldStyles, th('fields.fileupload'), getBorderColor(props), props.connected ? componentSystem : system, props.disabled && disabledStyles);
});
var FilePreview =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__FilePreview",
  componentId: "sc-1gujkgl-0"
})(["width:100%;height:100%;display:flex;flex-direction:column;align-items:center;justify-content:center;"]);
var FilePreviewImage =
/*#__PURE__*/
styled.img.withConfig({
  displayName: "styles__FilePreviewImage",
  componentId: "sc-1gujkgl-1"
})(["max-height:100%;max-width:100%;object-fit:contain;"]);
var Actions =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Actions",
  componentId: "sc-1gujkgl-2"
})(["position:absolute;top:", ";right:", ";display:flex;flex-direction:column;", "{margin-bottom:md;}"],
/*#__PURE__*/
th.space('xl'),
/*#__PURE__*/
th.space('xl'), Button);

var DefaultContent = function DefaultContent(_ref) {
  var error = _ref.error,
      fileUrl = _ref.fileUrl,
      isHoverAccept = _ref.isHoverAccept,
      isHoverReject = _ref.isHoverReject,
      openFile = _ref.openFile;

  if (isHoverAccept) {
    return React.createElement(Icon$1, {
      name: "positive"
    });
  } else if (isHoverReject) {
    return React.createElement(Icon$1, {
      name: "negative"
    });
  } else if (error) {
    return React.createElement(Message, {
      openFile: openFile
    });
  } else if (fileUrl) {
    return React.createElement(FilePreviewImage, {
      src: fileUrl
    });
  }

  return React.createElement(Message, {
    openFile: openFile
  });
};

var Message = function Message(_ref2) {
  var openFile = _ref2.openFile;
  return React.createElement(React.Fragment, null, React.createElement(Text$1, {
    m: "0",
    variant: "h3"
  }, "Add file"), React.createElement(Text$1, {
    variant: "body1"
  }, "Drag and drop a file here or\u2026"), React.createElement(Button$1, {
    onClick: openFile,
    type: "button"
  }, "Choose file"));
};

var FilePreviewImage$1 = FilePreviewImage;
var DEFAULT_MAX_FILE_SIZE = 2000000;
var ERROR_INVALID_TYPE = 'ERROR_INVALID_TYPE';
var ERROR_INVALID_SIZE = 'ERROR_INVALID_SIZE';

var getPreviewUrl = function getPreviewUrl(file) {
  var url = file.preview || file;
  return typeof url !== 'string' || url.startsWith('blob:') ? url : new URL(url);
};

var FileDrop$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var _ref$accept = _ref.accept,
      accept = _ref$accept === void 0 ? 'image/*' : _ref$accept,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? DefaultContent : _ref$children,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      isEditable = _ref.isEditable,
      isClearable = _ref.isClearable,
      _ref$maxSize = _ref.maxSize,
      maxSize = _ref$maxSize === void 0 ? DEFAULT_MAX_FILE_SIZE : _ref$maxSize,
      multiple = _ref.multiple,
      name = _ref.name,
      onAddFile = _ref.onAddFile,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onError = _ref.onError,
      onRemoveFile = _ref.onRemoveFile,
      value = _ref.value,
      rest = _objectWithoutPropertiesLoose(_ref, ["accept", "children", "dataTestId", "disabled", "isEditable", "isClearable", "maxSize", "multiple", "name", "onAddFile", "onBlur", "onChange", "onError", "onRemoveFile", "value"]);

  var _useState = useState(value),
      file = _useState[0],
      setFile = _useState[1];

  var _useState2 = useState(),
      error = _useState2[0],
      setError = _useState2[1];

  useEffect(function () {
    setFile(value);
  }, [value]); // Clean up URL

  useEffect(function () {
    return function () {
      return file && URL.revokeObjectURL(file.preview);
    };
  }, [file]);

  var handleDropAccepted = function handleDropAccepted(files) {
    var file = files[0];
    file.preview = URL.createObjectURL(file);
    setFile(file);
    setError(null);
    var event = createEvent({
      name: name,
      value: file
    });
    onChange && onChange(event);
    onAddFile && onAddFile(event);
  };

  var handleDropRejected = function handleDropRejected(files) {
    var file = files[0];
    var error;
    var event = createEvent({
      name: name,
      value: file
    });

    if (!validateMimeType(file, accept)) {
      error = ERROR_INVALID_TYPE;
    } else if (!validateFileSize(file, maxSize)) {
      error = ERROR_INVALID_SIZE;
    }

    setFile(null);
    setError(error);
    onError && onError(error);
    onChange && onChange(event);
    onBlur && onBlur(); // Trigger field touch
  };

  var handleRemoveFile = function handleRemoveFile(e) {
    e.preventDefault();
    setFile(null);
    setError(null);
    var event = createEvent({
      name: name,
      value: null
    });
    onChange && onChange(event);
    onRemoveFile && onRemoveFile(event);
  };

  var _useDropzone = useDropzone({
    onDropAccepted: handleDropAccepted,
    onDropRejected: handleDropRejected,
    noClick: true,
    multiple: multiple,
    accept: accept,
    disabled: disabled,
    maxSize: maxSize,
    children: children
  }),
      getInputProps = _useDropzone.getInputProps,
      getRootProps = _useDropzone.getRootProps,
      inputRef = _useDropzone.inputRef,
      isDragAccept = _useDropzone.isDragAccept,
      isDragActive = _useDropzone.isDragActive,
      isDragReject = _useDropzone.isDragReject,
      open = _useDropzone.open,
      rootRef = _useDropzone.rootRef;

  return React.createElement(FileDrop, _extends({}, getRootProps({
    'data-testid': dataTestId,
    handleRemoveFile: handleRemoveFile,
    isEditable: isEditable,
    isDragActive: isDragActive,
    isDragAccept: isDragAccept,
    isDragReject: isDragReject,
    isClearable: isClearable,
    ref: ref
  }), rest), React.createElement("input", _extends({}, getInputProps({
    disabled: disabled,
    multiple: multiple,
    name: name,
    onError: onError
  }), {
    // for extern validator we need to have access to this input
    style: {
      display: 'block',
      opacity: 0,
      height: 0
    }
  })), React.createElement(FilePreview, null, children({
    error: error,
    fileUrl: file && getPreviewUrl(file),
    isDefault: !file && !isDragActive,
    isHoverAccept: isDragAccept,
    isHoverReject: isDragReject,
    openFile: open,
    inputRef: inputRef,
    rootRef: rootRef
  }), React.createElement(Actions, null, (!!file || error) && isEditable && React.createElement(Button$1, {
    onClick: open,
    size: "sm",
    type: "button",
    variant: "secondary"
  }, React.createElement(Icon$1, {
    name: "pencil"
  })), !!file && isClearable && React.createElement(Button$1, {
    onClick: handleRemoveFile,
    size: "sm",
    type: "button",
    variant: "primary-danger"
  }, React.createElement(Icon$1, {
    name: "cross"
  })))));
});
FileDrop$1.type = 'FileDrop';
FileDrop$1.displayName = 'FileDrop';

var formatBytes = function formatBytes(bytes, decimals) {
  if (decimals === void 0) {
    decimals = 2;
  }

  if (bytes === 0) {
    return '0 Bytes';
  }

  var k = 1024;
  var dm = decimals < 0 ? 0 : decimals;
  var sizes = ['Bytes', 'KB', 'MB', 'GB'];
  var i = Math.floor(Math.log(bytes) / Math.log(k));
  return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
};

var removeQueryString = function removeQueryString(name) {
  return name.split('?')[0];
};

var getName = function getName(file) {
  return file.name || removeQueryString(file).split('/').pop();
};

var getMimeType = function getMimeType(file) {
  return file.type || mime.getType(getName(file).split('.')[1]);
};

var getSize = function getSize(file) {
  return file.size ? formatBytes(file.size, 0) : null;
};

var getIcon = function getIcon(file) {
  var mimeType = getMimeType(file);

  if (!mimeType) {
    return;
  }

  if (mimeType.startsWith('image/')) {
    return 'instagram';
  }

  if (mimeType.startsWith('audio/')) {
    return 'music';
  }

  if (mimeType.startsWith('video/')) {
    return 'youtube';
  }

  switch (mimeType) {
    case 'application/pdf':
      return 'attachment';

    case 'application/msword':
    case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
    case 'application/vnd.oasis.opendocument.text':
      return 'attachment';

    default:
      return 'attachment';
  }
};

var Preview = function Preview(_ref) {
  var file = _ref.file,
      onRemove = _ref.onRemove;
  var icon = getIcon(file);
  var name = getName(file);
  var size = getSize(file);
  return React.createElement(Tag$1, {
    "data-id": name,
    key: name,
    mr: "sm",
    mt: "sm",
    onRemove: onRemove,
    size: "lg"
  }, icon && React.createElement(Icon$1, {
    name: icon,
    size: "xs"
  }), name, size && React.createElement(Box, {
    color: "nude.600"
  }, "(", size, ")"));
};

var Input$2 =
/*#__PURE__*/
styled(filterComponent('input')).withConfig({
  displayName: "styles__Input",
  componentId: "sc-1lgfgg2-0"
})(["display:none;"]);

var DEFAULT_MAX_FILE_SIZE$1 = 2000000;
var DEFAULT_FILE_TYPES = '*/*';

var ensureArray = function ensureArray(value) {
  if (Array.isArray(value)) {
    return value;
  } else if (value) {
    return [value];
  }

  return [];
};

var FileUpload =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var _ref$accept = _ref.accept,
      accept = _ref$accept === void 0 ? DEFAULT_FILE_TYPES : _ref$accept,
      children = _ref.children,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      draggable = _ref.draggable,
      _ref$maxSize = _ref.maxSize,
      maxSize = _ref$maxSize === void 0 ? DEFAULT_MAX_FILE_SIZE$1 : _ref$maxSize,
      multiple = _ref.multiple,
      name = _ref.name,
      onAddFile = _ref.onAddFile,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onError = _ref.onError,
      onRemoveFile = _ref.onRemoveFile,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? [] : _ref$value,
      rest = _objectWithoutPropertiesLoose(_ref, ["accept", "children", "dataTestId", "disabled", "draggable", "maxSize", "multiple", "name", "onAddFile", "onBlur", "onChange", "onError", "onRemoveFile", "value"]);

  // We always keep an array of files
  var _useState = useState(ensureArray(value)),
      files = _useState[0],
      setFiles = _useState[1];

  var inputRef = ref || useRef(); // Ensure component is controlled

  useEffect(function () {
    setFiles(ensureArray(value));
  }, [value]); // Clean up URL on unmount

  useEffect(function () {
    return function () {
      return files && files.map(function (file) {
        return file && URL.revokeObjectURL(file.preview);
      });
    };
  }, [files]);

  var handleAddFile = function handleAddFile(e) {
    var newFiles = Array.from(e.target.files).map(function (file) {
      file.preview = URL.createObjectURL(file);
      return file;
    });
    setFiles(newFiles);

    if (newFiles.length === 1) {
      newFiles = newFiles[0];
    }

    var event = createEvent({
      name: name,
      value: newFiles
    });
    onChange && onChange(event);
    onAddFile && onAddFile(newFiles);
    onBlur && onBlur();
  };

  var handleRemoveFile = function handleRemoveFile(index) {
    var newFiles = [].concat(files);
    var file = newFiles.splice(index, 1);
    var value = multiple ? newFiles : undefined;
    setFiles(newFiles);
    var event = createEvent({
      name: name,
      value: value
    });
    onChange && onChange(event);
    onRemoveFile && onRemoveFile(file);
    onBlur && onBlur();
  };

  var handleClick = function handleClick() {
    inputRef.current.click();
  };

  return React.createElement(React.Fragment, null, children ? children({
    openFile: handleClick
  }) : React.createElement(Button$1, {
    onClick: handleClick
  }, "Upload file"), React.createElement("br", null), React.createElement(Input$2, _extends({
    accept: accept,
    "data-testid": dataTestId,
    maxSize: maxSize,
    multiple: multiple,
    name: name,
    onBlur: onBlur,
    onChange: handleAddFile,
    ref: inputRef
  }, rest, {
    type: "file"
  })), files.map(function (file) {
    return React.createElement(Preview, {
      file: file,
      key: file.name || file,
      onRemove: handleRemoveFile
    });
  }));
});
FileUpload.type = 'FileUpload';
FileUpload.displayName = 'FileUpload';

var Growl =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Growl",
  componentId: "firt47-0"
})(["position:relative;width:70%;max-width:25rem;padding:lg;", ";", ";"],
/*#__PURE__*/
th('growls.default'), system);
var Title$1 =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Title",
  componentId: "firt47-1"
})(function (_ref) {
  var variant = _ref.variant;
  return css(["display:flex;align-items:center;color:", ";padding-bottom:md;", ";& > *:first-child{flex-shrink:0;margin-right:sm;}"], getVariantStateColor(variant), th('growls.title'));
});
var Close =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Close",
  componentId: "firt47-2"
})(["float:right;margin-left:sm;"]);
var CloseContent =
/*#__PURE__*/
styled.button.withConfig({
  displayName: "styles__CloseContent",
  componentId: "firt47-3"
})(["display:flex;align-items:center;justify-content:center;width:1.87rem;height:1.87rem;", ";border:none;padding:0;transition:background ", ";cursor:pointer;"],
/*#__PURE__*/
th('growls.close'),
/*#__PURE__*/
th.transition('medium'));
var Action =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Action",
  componentId: "firt47-4"
})(["padding-top:md;"]);

var GrowlTitle = function GrowlTitle(_ref) {
  var children = _ref.children,
      dataTestId = _ref.dataTestId,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'info' : _ref$variant;
  return React.createElement(Title$1, {
    "data-testid": dataTestId,
    variant: variant
  }, children);
};

var GrowlAction = Action;
var GrowlClose = CloseContent;
var Growl$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var children = _ref.children,
      close = _ref.close,
      dataTestId = _ref.dataTestId,
      onClose = _ref.onClose;
  return React.createElement(Growl, {
    ref: ref
  }, onClose && React.createElement(Close, {
    "data-testid": dataTestId,
    onClick: onClose
  }, close || React.createElement(CloseContent, null, React.createElement(Icon$1, {
    name: "cross",
    size: "xs"
  }))), children);
});
Growl$1.displayName = 'Growl';
Growl$1.propTypes = {
  children: node.isRequired,
  close: node,
  onClose: func
};

var InputCheckbox =
/*#__PURE__*/
styled(filterComponent(Checkbox))(function (_ref) {
  var connected = _ref.connected,
      _ref$order = _ref.order,
      order = _ref$order === void 0 ? '-1' : _ref$order;
  return css(["", ";", " position:relative;padding:0;order:", ";cursor:pointer;transition:medium;&::after{content:url('data:image/svg+xml; utf8, <svg viewBox=\"0 0 9 9\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M2.711 6.328L7.487.8A.844.844 0 0 1 8.712.73l-.273.318.273-.317a.927.927 0 0 1 .066 1.274L3.427 8.2a.847.847 0 0 1-1.221.073L.291 6.511a.928.928 0 0 1-.074-1.274.845.845 0 0 1 1.225-.076L2.71 6.328z\" fill=\"white\" fill-rule=\"nonzero\"/></svg>');position:absolute;top:0;right:0;bottom:0;left:0;width:9;margin:auto;text-align:center;color:light.200;opacity:0;transition:medium;}", ";"], fieldStyles, th('fields.checkbox.default'), order, connected ? componentSystem : system);
});

var InputCheckbox$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var _ref$checked = _ref.checked,
      checked = _ref$checked === void 0 ? false : _ref$checked,
      _ref$Component = _ref.Component,
      Component = _ref$Component === void 0 ? InputCheckbox : _ref$Component,
      dataTestId = _ref.dataTestId,
      name = _ref.name,
      onChange = _ref.onChange,
      rest = _objectWithoutPropertiesLoose(_ref, ["checked", "Component", "dataTestId", "name", "onChange"]);

  var handleChange = function handleChange(e) {
    e.target.checked = !e.target.checked;
    onChange && onChange(e);
  };

  return React.createElement(Component, _extends({
    checked: checked,
    "data-testid": dataTestId,
    id: name,
    name: name,
    onChange: handleChange,
    ref: ref
  }, rest));
});
InputCheckbox$1.type = 'InputCheckbox';
InputCheckbox$1.displayName = 'InputCheckbox';

var InputRadio =
/*#__PURE__*/
styled(filterComponent(Radio))(function (_ref) {
  var connected = _ref.connected,
      _ref$order = _ref.order,
      order = _ref$order === void 0 ? '-1' : _ref$order;
  return css(["", ";", " position:relative;padding:0;order:", ";cursor:pointer;border-radius:50%;transition:medium;&::after{content:url('data:image/svg+xml; utf8, <svg viewBox=\"0 0 10 8\" xmlns=\"http://www.w3.org/2000/svg\"><path d=\"M8.48.751a.914.914 0 0 1 1.26 0 .837.837 0 0 1 0 1.215L4.26 7.249a.913.913 0 0 1-1.319-.064L.201 3.96A.838.838 0 0 1 .326 2.75a.913.913 0 0 1 1.253.12l2.117 2.493L8.48.75z\" fill=\"white\" fill-rule=\"evenodd\"/></svg> ');position:absolute;top:0;right:0;bottom:0;left:0;width:10;margin:auto;text-align:center;color:light.200;opacity:0;transition:medium;}", ";"], fieldStyles, th('fields.radio.default'), order, connected ? componentSystem : system);
});
var Input$3 =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Input",
  componentId: "xst7a7-0"
})(["flex-shrink:0;position:relative;"]);
var Content$1 =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Content",
  componentId: "xst7a7-1"
})([""]);

var InputRadio$1 =
/*#__PURE__*/
forwardRef(function (props, ref) {
  var dataTestId = props.dataTestId,
      disabled = props.disabled,
      disabledIcon = props.disabledIcon,
      flexDirection = props.flexDirection,
      label = props.label,
      onChange = props.onChange,
      onClick = props.onClick,
      variant = props.variant,
      rest = _objectWithoutPropertiesLoose(props, ["dataTestId", "disabled", "disabledIcon", "flexDirection", "label", "onChange", "onClick", "variant"]);

  var handleClick = function handleClick(e) {
    e.stopPropagation();
    onClick && onClick(e);
    onChange && onChange(e);
  };

  return React.createElement(Label$1, {
    checkableField: true,
    disabled: disabled,
    disabledIcon: disabledIcon,
    flexDirection: flexDirection,
    onClick: handleClick,
    variant: variant
  }, React.createElement(Input$3, null, React.createElement(InputRadio, _extends({
    "data-testid": dataTestId,
    disabled: disabled,
    label: label,
    ref: ref,
    variant: variant
  }, rest))), React.createElement(Content$1, null, label));
});
InputRadio$1.type = 'InputRadio';
InputRadio$1.displayName = 'InputRadio';

var InputText =
/*#__PURE__*/
styled(filterComponent('input'))(function (_ref) {
  var connected = _ref.connected,
      icon = _ref.icon,
      iconPlacement = _ref.iconPlacement,
      isClearable = _ref.isClearable,
      size = _ref.size,
      rest = _objectWithoutPropertiesLoose(_ref, ["connected", "icon", "iconPlacement", "isClearable", "size"]);

  return css(["", ";", " ", " ", ";"], fieldStyles, icon && iconPlacement === 'left' && css(["padding-left:", ";"], icon ? th("fields.sizes." + size + ".height")(rest) : null), (icon && iconPlacement === 'right' || isClearable) && css(["padding-right:", ";"], icon ? th("fields.sizes." + size + ".height")(rest) : null), connected ? componentSystem : system);
});
var Wrapper$1 =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Wrapper",
  componentId: "zznoga-0"
})(["position:relative;"]);

var InputText$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var autoFocus = _ref.autoFocus,
      connected = _ref.connected,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      icon = _ref.icon,
      _ref$iconPlacement = _ref.iconPlacement,
      iconPlacement = _ref$iconPlacement === void 0 ? 'left' : _ref$iconPlacement,
      isClearable = _ref.isClearable,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onKeyDown = _ref.onKeyDown,
      placeholder = _ref.placeholder,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'lg' : _ref$size,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      value = _ref.value,
      variant = _ref.variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["autoFocus", "connected", "dataTestId", "disabled", "icon", "iconPlacement", "isClearable", "name", "onBlur", "onChange", "onFocus", "onKeyDown", "placeholder", "size", "type", "value", "variant"]);

  var handleReset = function handleReset() {
    var event = createEvent({
      name: name,
      value: ''
    });
    onChange && onChange(event);
  };

  return React.createElement(Wrapper$1, null, React.createElement(InputText, _extends({
    autoFocus: autoFocus,
    connected: connected,
    "data-testid": dataTestId,
    disabled: disabled,
    icon: !!icon,
    iconPlacement: iconPlacement,
    id: name,
    isClearable: isClearable,
    name: name,
    onBlur: onBlur,
    onChange: onChange,
    onFocus: onFocus,
    onKeyDown: onKeyDown,
    placeholder: placeholder,
    ref: ref,
    size: size,
    type: type,
    value: value,
    variant: variant
  }, rest)), icon && React.createElement(IconWrapper, {
    iconPlacement: iconPlacement,
    size: size
  }, icon), isClearable && value && React.createElement(IconWrapper, {
    iconPlacement: "right",
    size: size
  }, React.createElement(ClearButton$1, {
    onClick: handleReset
  })));
});
InputText$1.displayName = 'InputText';

var Textarea =
/*#__PURE__*/
styled(filterComponent('textarea'))(function (_ref) {
  var connected = _ref.connected;
  return css(["", ";", ";line-height:body1;padding:sm;", ";"], fieldStyles, th('fields.textarea'), connected ? componentSystem : system);
});

var InputTextarea =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var autoFocus = _ref.autoFocus,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      maxLength = _ref.maxLength,
      _ref$minRows = _ref.minRows,
      minRows = _ref$minRows === void 0 ? 5 : _ref$minRows,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onKeyDown = _ref.onKeyDown,
      placeholder = _ref.placeholder,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'lg' : _ref$size,
      value = _ref.value,
      variant = _ref.variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["autoFocus", "dataTestId", "disabled", "maxLength", "minRows", "name", "onBlur", "onChange", "onFocus", "onKeyDown", "placeholder", "size", "value", "variant"]);

  return React.createElement(Textarea, _extends({
    autoFocus: autoFocus,
    "data-testid": dataTestId,
    disabled: disabled,
    maxLength: maxLength,
    minRows: minRows,
    name: name,
    onBlur: onBlur,
    onChange: onChange,
    onFocus: onFocus,
    onKeyDown: onKeyDown,
    placeholder: placeholder,
    ref: ref,
    size: size,
    value: value,
    variant: variant
  }, rest));
});
InputTextarea.type = 'InputTextarea';
InputTextarea.displayName = 'InputTextarea';
InputTextarea.propTypes = {
  autoFocus: bool,
  disabled: bool,
  maxLength: number,
  minRows: number,
  name: string,
  onBlur: func,
  onChange: func,
  onFocus: func,
  onKeyDown: func,
  placeholder: string,
  size: SIZES_TYPE,
  value: string,
  variant: VARIANTS_TYPE
};

var UniversalLink =
/*#__PURE__*/
styled.a.withConfig({
  displayName: "styled__UniversalLink",
  componentId: "kr42py-0"
})(["color:inherit;text-decoration:none;"]);

var UniversalLink$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var children = _ref.children,
      dataTestId = _ref.dataTestId,
      target = _ref.target,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "dataTestId", "target"]);

  return React.createElement(UniversalLink, _extends({
    color: "inherit" // for security
    ,
    "data-testid": dataTestId,
    ref: ref,
    rel: target === '_blank' ? 'noopener noreferrer' : undefined,
    target: target
  }, rest), children);
});
UniversalLink$1.displayName = 'UniversalLink';
UniversalLink$1.propTypes = {
  children: node,
  target: string
};

var Link =
/*#__PURE__*/
styled(UniversalLink$1)(function (_ref) {
  var variant = _ref.variant;
  return css(["display:inline-flex;flex-direction:row;align-items:center;opacity:1;text-decoration:none;cursor:pointer;transition:opacity 300ms;&:hover,&:focus{opacity:0.6;outline:none;}&[disabled]{opacity:0.5;pointer-events:none;}", ";", ";", ";& > *:not(:only-child):not(:last-child){margin-right:xs;}"], th('links.default'), th("links." + (variant || 'primary')), system);
});

var Wrapper$2 =
/*#__PURE__*/
styled(filterComponent('div'))(function (_ref) {
  var connected = _ref.connected,
      disabled = _ref.disabled,
      focused = _ref.focused;
  return css(["", ";position:relative;pointer-events:", ";", ";", ";height:auto;padding:0;.editor-statusbar{display:none;}.CodeMirror{border:none;background:inherit;z-index:0;}.cm-strong{font-weight:bold;}", ";"], fieldStyles, disabled && 'none', focused && th('fields.focused'), disabled && th('fields.disabled'), connected ? componentSystem : system);
});
var Toolbar =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Toolbar",
  componentId: "sc-977ef6-0"
})(function (_ref2) {
  var borderRadius = _ref2.borderRadius;
  return css(["display:flex;align-items:center;justify-content:flex-start;padding:md md;opacity:1;background-color:light.100;border-bottom:", " solid ", ";border-radius:sm;position:sticky;top:0;overflow:auto;z-index:1;box-shadow:", ";border-radius:", ";border-bottom-right-radius:0;border-bottom-left-radius:0;"], th('borderWidths.sm'), th('colors.nude.200'), th('shadows.sm'), borderRadius);
});
var ToolbarIcon =
/*#__PURE__*/
styled.a.withConfig({
  displayName: "styles__ToolbarIcon",
  componentId: "sc-977ef6-1"
})(function (props) {
  return css(["padding:0 xxs;margin-right:xxs;cursor:pointer;color:", ";transition:medium;&:hover{color:", ";}"], props.active ? th('colors.primary.500') : 'inherit', th('colors.primary.500'));
});
var Divider =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Divider",
  componentId: "sc-977ef6-2"
})(["display:inline-block;width:1px;height:1rem;margin-right:xxs;background-color:nude.200;"]);
var EmojiPicker =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__EmojiPicker",
  componentId: "sc-977ef6-3"
})(["position:absolute;z-index:2;top:", ";right:", ";"],
/*#__PURE__*/
th('space.md'),
/*#__PURE__*/
th('space.md'));
var Editor =
/*#__PURE__*/
styled(SimpleMDE).withConfig({
  displayName: "styles__Editor",
  componentId: "sc-977ef6-4"
})([""]);

var getTooltip = function getTooltip(item) {
  return ("" + item.charAt(0).toUpperCase() + item.substr(1).toLowerCase()).replace('-', ' ');
};

var Toolbar$1 = function Toolbar$1(_ref) {
  var _ref$active = _ref.active,
      active = _ref$active === void 0 ? [] : _ref$active,
      dataTestId = _ref.dataTestId,
      _ref$items = _ref.items,
      items = _ref$items === void 0 ? [] : _ref$items,
      onClick = _ref.onClick,
      rest = _objectWithoutPropertiesLoose(_ref, ["active", "dataTestId", "items", "onClick"]);

  var handleClick = function handleClick(e) {
    var item = e.currentTarget.dataset.id;
    onClick(item, e);
  };

  return React.createElement(Toolbar, _extends({
    "data-testid": dataTestId
  }, rest), items.map(function (_ref2, i) {
    var icon = _ref2.icon,
        name = _ref2.name;

    if (name === 'divider') {
      // eslint-disable-next-line react/no-array-index-key
      return React.createElement(Divider, {
        key: i
      });
    }

    return React.createElement(ToolbarIcon, {
      active: active.includes(name),
      "data-id": name,
      key: name,
      onClick: handleClick,
      title: getTooltip(name)
    }, icon);
  }));
};

var EmojiPicker$1 = function EmojiPicker$1(_ref) {
  var onSelect = _ref.onSelect;
  return React.createElement(EmojiPicker, null, React.createElement(NimblePicker, {
    autoFocus: true,
    data: data,
    emoji: "ok_hand",
    onSelect: onSelect,
    set: "apple",
    title: "Pick an emoji"
  }));
};

// Taken from https://github.com/sparksuite/simplemde-markdown-editor/blob/6abda7ab68cc20f4aca870eb243747951b90ab04/src/js/simplemde.js#L140
var getCurrentToolsFromEditor = function getCurrentToolsFromEditor(editor) {
  var pos = editor.getCursor('start');
  var token = editor.getTokenAt(pos);
  var line = editor.getLine(pos.line);
  var CODE_MIRROR_TYPES = {
    strong: 'bold',
    atom: 'quote',
    em: 'italic',
    quote: 'quote',
    strikethrough: 'strikethrough',
    'variable-2': /^\s*\d+\.\s/.test(line) ? 'ordered-list' : 'unordered-list',
    comment: 'code',
    link: 'link',
    tag: 'image',
    'header-1': 'heading-1',
    'header-2': 'heading-2'
  };

  if (!token.type) {
    return [];
  }

  return token.type.split(' ').map(function (type) {
    return CODE_MIRROR_TYPES[type];
  }).filter(function (type) {
    return type;
  });
};

var DEFAULT_TOOLBAR = [{
  name: 'bold'
}, {
  name: 'italic'
}, {
  name: 'strikethrough'
}, {
  name: 'link'
}, {
  name: 'divider'
}, {
  name: 'heading-1'
}, {
  name: 'heading-2'
}, {
  name: 'divider'
}, {
  name: 'unordered-list'
}, {
  name: 'ordered-list'
}, {
  name: 'divider'
}, {
  name: 'code'
}, {
  name: 'quote'
}, {
  name: 'divider'
}, {
  name: 'emoji',
  icon: '🙂'
}];

// Only require CSS on client
if (typeof window !== 'undefined') {
  require('emoji-mart/css/emoji-mart.css');

  require('easymde/dist/easymde.min.css');
}
var MarkdownEditor =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var autoFocus = _ref.autoFocus,
      dataTestId = _ref.dataTestId,
      disabled = _ref.disabled,
      name = _ref.name,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      placeholder = _ref.placeholder,
      _ref$toolbar = _ref.toolbar,
      toolbar = _ref$toolbar === void 0 ? DEFAULT_TOOLBAR : _ref$toolbar,
      value = _ref.value,
      variant = _ref.variant,
      rest = _objectWithoutPropertiesLoose(_ref, ["autoFocus", "dataTestId", "disabled", "name", "onBlur", "onChange", "onFocus", "placeholder", "toolbar", "value", "variant"]);

  var _useState = useState(autoFocus || false),
      focused = _useState[0],
      setFocused = _useState[1];

  var _useState2 = useState(null),
      instance = _useState2[0],
      setInstance = _useState2[1];

  var _useState3 = useState(false),
      showEmojiPicker = _useState3[0],
      setShowEmojiPicker = _useState3[1];

  var _useState4 = useState([]),
      currentTools = _useState4[0],
      setCurrentTools = _useState4[1];

  var _useState5 = useState([]),
      toolbarItems = _useState5[0],
      setToolbarItems = _useState5[1];
  /* EMOJI PICKER */


  var toggleEmojiPicker = function toggleEmojiPicker() {
    setShowEmojiPicker(!showEmojiPicker);
  };

  useEffect(function () {
    // Add emoji to currentTools if we're showing emoji picker
    if (showEmojiPicker && !currentTools.includes('emoji')) {
      setCurrentTools([].concat(currentTools, ['emoji']));
    }
  }, [currentTools, showEmojiPicker]);
  /* TOOLBAR */

  var DEFAULT_TOOLBAR_ACTIONS = {
    bold: 'toggleBold',
    emoji: toggleEmojiPicker,
    italic: 'toggleItalic',
    strikethrough: 'toggleStrikethrough',
    link: 'drawLink',
    'heading-1': 'toggleHeading1',
    'heading-2': 'toggleHeading2',
    code: 'toggleCodeBlock',
    quote: 'toggleBlockquote',
    'unordered-list': 'toggleUnorderedList',
    'ordered-list': 'toggleOrderedList',
    'horizontal-rule': 'drawHorizontalRule'
  };
  useEffect(function () {
    // Set toolbar items on mount
    setToolbarItems(toolbar.map(function (_ref2) {
      var action = _ref2.action,
          icon = _ref2.icon,
          name = _ref2.name;
      return {
        name: name,
        icon: icon || React.createElement(Icon$1, {
          name: name
        }),
        action: action || DEFAULT_TOOLBAR_ACTIONS[name] || null
      };
    })); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  var handleFocus = function handleFocus() {
    instance && instance.codemirror.focus();
    onFocus && onFocus(value);
    setFocused(true);
    setShowEmojiPicker(false);
  };

  var handleBlur = function handleBlur() {
    onBlur && onBlur(value);
    setFocused(false);
  };

  var handleChange = function handleChange(value) {
    var event = createEvent({
      name: name,
      value: value
    });
    onChange && onChange(event);
    updateCurrentTools(instance.codemirror);
  };

  var handleToolbarClick = function handleToolbarClick(item) {
    var _toolbarItems$find = toolbarItems.find(function (toolbarItem) {
      return toolbarItem.name === item;
    }),
        action = _toolbarItems$find.action; // Use actions from the MDE instance or provided action


    action && typeof action === 'string' ? instance[action]() : action();
    updateCurrentTools(instance.codemirror);
  };

  var updateCurrentTools = function updateCurrentTools(cm) {
    setCurrentTools(getCurrentToolsFromEditor(cm));
  };

  var addEmoji = function addEmoji(emoji) {
    var cm = instance.codemirror;
    var doc = cm.getDoc();
    var position = doc.getCursor();
    doc.replaceRange(emoji["native"], position);
    var nextValue = instance.value();
    handleChange(nextValue); // Close picker and position cursor after our emoji

    toggleEmojiPicker();
    cm.focus();
    setTimeout(function () {
      return doc.setCursor({
        line: position.line,
        ch: position.ch + 2
      });
    }, 50);
  };

  return React.createElement(Wrapper$2, _extends({
    "data-testid": dataTestId,
    disabled: disabled,
    focused: focused,
    variant: variant
  }, rest), React.createElement(Toolbar$1, {
    active: currentTools,
    borderRadius: rest.borderRadius,
    items: toolbarItems,
    onClick: handleToolbarClick,
    role: "toolbar"
  }), showEmojiPicker && React.createElement(EmojiPicker$1, {
    onSelect: addEmoji
  }), React.createElement(Editor, {
    events: {
      blur: handleBlur,
      focus: handleFocus,
      cursorActivity: updateCurrentTools
    },
    extraKeys: {
      Tab: false
    },
    getMdeInstance: setInstance,
    onChange: handleChange,
    onFocus: onFocus,
    options: {
      autoDownloadFontAwesome: false,
      autofocus: autoFocus,
      placeholder: placeholder,
      toolbar: false,
      tabSize: 4,
      spellChecker: false,
      status: false
    },
    ref: ref,
    value: value
  }));
});
MarkdownEditor.type = 'MarkdownEditor';
MarkdownEditor.displayName = 'MarkdownEditor';

var Pagination =
/*#__PURE__*/
styled.nav.withConfig({
  displayName: "styles__Pagination",
  componentId: "sc-7t3ce5-0"
})(system);
var List =
/*#__PURE__*/
styled.ul.withConfig({
  displayName: "styles__List",
  componentId: "sc-7t3ce5-1"
})(["list-style-type:none;padding:0;margin:0;"]);
var Item$1 =
/*#__PURE__*/
styled.li.withConfig({
  displayName: "styles__Item",
  componentId: "sc-7t3ce5-2"
})(["display:inline-block;padding:0;margin:0 xxs;", ""], function (p) {
  return p.hidden && css(["display:none;"]);
});
var Dots =
/*#__PURE__*/
styled.span.withConfig({
  displayName: "styles__Dots",
  componentId: "sc-7t3ce5-3"
})(["", ";", " display:flex;justify-content:center;align-items:center;cursor:pointer;"],
/*#__PURE__*/
th('paginations.default'),
/*#__PURE__*/
th('paginations.dots'));
var AbstractLink =
/*#__PURE__*/
styled.a.withConfig({
  displayName: "styles__AbstractLink",
  componentId: "sc-7t3ce5-4"
})(["", ";display:flex;align-items:center;justify-content:center;cursor:pointer;border-radius:50%;transition:medium;transition-property:color;text-decoration:none;&:focus{outline:none;transition:none;}"],
/*#__PURE__*/
th('paginations.default'));
var ArrowLink =
/*#__PURE__*/
styled(AbstractLink).withConfig({
  displayName: "styles__ArrowLink",
  componentId: "sc-7t3ce5-5"
})(["", ";"],
/*#__PURE__*/
th('paginations.arrow'));
var PageLink =
/*#__PURE__*/
styled(AbstractLink).withConfig({
  displayName: "styles__PageLink",
  componentId: "sc-7t3ce5-6"
})(["", " ", ""],
/*#__PURE__*/
th('paginations.number'), function (p) {
  return p['aria-current'] && th('paginations.active')(p);
});

function fill(length, transform) {
  return Array.from({
    length: length
  }, function (_, i) {
    return transform(i);
  });
}

function joinArrays(arrays, separator) {
  return arrays.reduce(function (all, array, i) {
    var next = [].concat(all, array);
    if (array.length && i < arrays.length - 1) next.push(separator);
    return next;
  }, []);
}

var RANGE = 4;

function usePages(_ref) {
  var page = _ref.page,
      pageCount = _ref.pageCount,
      rangeDisplay = _ref.rangeDisplay;
  return useMemo(function () {
    if (pageCount <= rangeDisplay) {
      return fill(pageCount, function (i) {
        return i + 1;
      });
    }

    var before = page < RANGE ? fill(Math.min(pageCount, page + 1), function (i) {
      return i + 1;
    }) : [1];
    var center = page >= RANGE && page <= pageCount - RANGE + 1 ? fill(RANGE - 1, function (i) {
      return i + page - 1;
    }) : [];
    var after = page > pageCount - RANGE + 1 ? fill(Math.min(RANGE, pageCount - page + RANGE / 2), function (i) {
      return i + page - 1;
    }) : [pageCount];
    return joinArrays([before, center, after], '-');
  }, [page, pageCount, rangeDisplay]);
}

var Pagination$1 =
/*#__PURE__*/
forwardRef(function (_ref2, ref) {
  var ariaLabel = _ref2['aria-label'],
      getHref = _ref2.getHref,
      leftArrow = _ref2.leftArrow,
      onChange = _ref2.onChange,
      page = _ref2.page,
      pageCount = _ref2.pageCount,
      _ref2$rangeDisplay = _ref2.rangeDisplay,
      rangeDisplay = _ref2$rangeDisplay === void 0 ? 5 : _ref2$rangeDisplay,
      rightArrow = _ref2.rightArrow;
  var rover = useRoverState();
  var pages = usePages({
    page: page,
    pageCount: pageCount,
    rangeDisplay: rangeDisplay
  });
  var firstPageRef = useRef();
  var lastPageRef = useRef();
  var handlePrevious = useCallback(function (event) {
    event.preventDefault();
    var previousPage = page - 1;

    if (previousPage === 1) {
      firstPageRef.current.focus();
    }

    onChange(previousPage);
  }, [page, onChange]);
  var handleNext = useCallback(function (event) {
    event.preventDefault();
    var nextPage = page + 1;

    if (nextPage === pageCount) {
      lastPageRef.current.focus();
    }

    onChange(nextPage);
  }, [page, pageCount, onChange]);
  return React.createElement(Pagination, {
    "aria-label": ariaLabel,
    ref: ref,
    role: "navigation"
  }, React.createElement(List, null, React.createElement(Item$1, {
    hidden: page === 1
  }, React.createElement(Rover, _extends({
    disabled: page === 1
  }, rover), function (roverProps) {
    return React.createElement(ArrowLink, _extends({}, roverProps, {
      href: getHref && getHref(page - 1),
      onClick: handlePrevious
    }), leftArrow || React.createElement(Icon$1, {
      name: "left",
      size: "xs"
    }));
  })), pages.map(function (iPage, i) {
    return iPage === '-' ? React.createElement(Item$1, {
      key: i + "-"
    }, React.createElement(Dots, null, "...")) : React.createElement(Item$1, {
      key: iPage
    }, React.createElement(Rover, _extends({
      ref: iPage === 1 ? firstPageRef : iPage === pageCount ? lastPageRef : null
    }, rover), function (roverProps) {
      return React.createElement(PageLink, _extends({}, roverProps, {
        "aria-current": iPage === page,
        href: getHref && getHref(iPage),
        onClick: function onClick(event) {
          event.preventDefault();
          onChange(iPage);
        }
      }), iPage);
    }));
  }), React.createElement(Item$1, {
    hidden: page === pageCount
  }, React.createElement(Rover, _extends({
    disabled: page === pageCount
  }, rover), function (roverProps) {
    return React.createElement(ArrowLink, _extends({}, roverProps, {
      href: getHref && getHref(page + 1),
      onClick: handleNext
    }), rightArrow || React.createElement(Icon$1, {
      name: "right",
      size: "xs"
    }));
  }))));
});

var Radios =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Radios",
  componentId: "sc-52lyux-0"
})(function (_ref) {
  var flexDirection = _ref.flexDirection;
  return css(["display:flex;flex-direction:", ";flex-wrap:wrap;", ";"], flexDirection, system);
});

var RadioGroup = function RadioGroup(_ref) {
  var flexDirection = _ref.flexDirection,
      label = _ref.label,
      name = _ref.name,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      _ref$renderOption = _ref.renderOption,
      Component = _ref$renderOption === void 0 ? InputRadio$1 : _ref$renderOption,
      required = _ref.required,
      value = _ref.value,
      rest = _objectWithoutPropertiesLoose(_ref, ["flexDirection", "label", "name", "options", "renderOption", "required", "value"]);

  var radio = useRadioState({
    currentId: value
  });
  return React.createElement(FieldGroup$1, {
    as: RadioGroup$1,
    label: label,
    mb: 0,
    required: required
  }, React.createElement(Radios, {
    flexDirection: flexDirection
  }, options.map(function (option) {
    return React.createElement(Component, _extends({}, rest, {
      checked: option.value === value,
      flexDirection: flexDirection,
      id: name + "." + option.value,
      key: option.value,
      label: option.label,
      name: name,
      type: "radio",
      value: option.value
    }, radio));
  })));
};
RadioGroup.type = 'RadioGroup';
RadioGroup.displayName = 'RadioGroup';

var InputRadio$2 =
/*#__PURE__*/
styled(filterComponent(Radio))(function (_ref) {
  var connected = _ref.connected;
  return css(["position:absolute;top:0;left:0;visibility:hidden;", ";"], connected ? componentSystem : system);
});
var checkedStyles =
/*#__PURE__*/
css(["", ";z-index:2;"],
/*#__PURE__*/
th('fields.radiotabs.checked'));
var columnStyles$1 =
/*#__PURE__*/
css(["margin-top:-", ";border-radius:0;&:first-of-type{border-radius:md;border-bottom-right-radius:0;border-bottom-left-radius:0;}&:last-of-type{border-radius:md;border-top-right-radius:0;border-top-left-radius:0;}"],
/*#__PURE__*/
th.borderWidth('sm'));
var rowStyles$1 =
/*#__PURE__*/
css(["margin-left:-", ";border-radius:0;&:first-of-type{border-radius:md;border-top-right-radius:0;border-bottom-right-radius:0;}&:last-of-type{border-radius:md;border-top-left-radius:0;border-bottom-left-radius:0;}"],
/*#__PURE__*/
th.borderWidth('sm'));
var Label$2 =
/*#__PURE__*/
styled.label.withConfig({
  displayName: "styles__Label",
  componentId: "sc-1e1ytbx-0"
})(function (_ref2) {
  var checked = _ref2.checked,
      flexDirection = _ref2.flexDirection;
  return css(["flex:1;min-width:0;min-height:0;max-width:100%;margin:0;text-align:center;position:relative;cursor:pointer;transition:medium;", ";", ";", ";", ";", ";&:hover{", ";}"], fieldStyles, checked && checkedStyles, flexDirection === 'column' && columnStyles$1, flexDirection === 'row' && rowStyles$1, componentSystem, th('fields.radiotabs.hover'));
});
var Input$4 =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Input",
  componentId: "sc-1e1ytbx-1"
})(["flex-shrink:0;position:relative;"]);
var Content$2 =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Content",
  componentId: "sc-1e1ytbx-2"
})(["", ";"], overflowEllipsis);

var RadioTab =
/*#__PURE__*/
forwardRef(function (props, ref) {
  var checked = props.checked,
      dataTestId = props.dataTestId,
      disabled = props.disabled,
      disabledIcon = props.disabledIcon,
      flexDirection = props.flexDirection,
      label = props.label,
      onChange = props.onChange,
      onClick = props.onClick,
      size = props.size,
      variant = props.variant,
      rest = _objectWithoutPropertiesLoose(props, ["checked", "dataTestId", "disabled", "disabledIcon", "flexDirection", "label", "onChange", "onClick", "size", "variant"]);

  var handleClick = function handleClick(e) {
    e.stopPropagation();
    onClick && onClick(e);
    onChange && onChange(e);
  };

  return React.createElement(Label$2, {
    checkableField: true,
    checked: checked,
    disabled: disabled,
    disabledIcon: disabledIcon,
    flexDirection: flexDirection,
    onClick: handleClick,
    size: size,
    variant: variant
  }, React.createElement(Input$4, null, React.createElement(InputRadio$2, _extends({
    "data-testid": dataTestId,
    disabled: disabled,
    label: label,
    ref: ref,
    variant: variant
  }, rest))), React.createElement(Content$2, null, label));
});
RadioTab.type = 'RadioTab';
RadioTab.displayName = 'RadioTab';

var shapeStyles$2 = function shapeStyles(width, height, shape) {
  return css(["width:", ";height:", ";border-radius:", ";"], getMax(width, height), getMax(width, height), shape === 'circle' && '50%');
};

var Shape =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__Shape",
  componentId: "qqapdx-0"
})(function (_ref) {
  var height = _ref.height,
      shape = _ref.shape,
      width = _ref.width;
  return css(["position:relative;overflow:hidden;display:flex;align-items:center;justify-content:center;", " ", " img{object-fit:cover;overflow:hidden;width:100%;height:100%;}"], system, shape && shapeStyles$2(width, height, shape));
});

var Shape$1 =
/*#__PURE__*/
forwardRef(function (_ref, ref) {
  var children = _ref.children,
      dataTestId = _ref.dataTestId,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "dataTestId"]);

  return React.createElement(Shape, _extends({
    "data-testid": dataTestId,
    ref: ref
  }, rest), children);
});
Shape$1.displayName = 'Shape';
Shape$1.propTypes = {
  children: node.isRequired,
  height:
  /*#__PURE__*/
  oneOfType([string, number]),
  shape: SHAPES_TYPE,
  width:
  /*#__PURE__*/
  oneOfType([string, number]).isRequired
};

function setRef(ref, value) {
  if (typeof ref === 'function') {
    ref(value);
  } else if (ref) {
    ref.current = value;
  }
}
function useForkRef(refA, refB) {
  /**
   * This will create a new function if the ref props change and are defined.
   * This means react will call the old forkRef with `null` and the new forkRef
   * with the ref. Cleanup naturally emerges from this behavior
   */
  return useMemo(function () {
    if (refA == null && refB == null) {
      return null;
    }

    return function (instance) {
      setRef(refA, instance);
      setRef(refB, instance);
    };
  }, [refA, refB]);
}

function useViewportSize() {
  var _useState = useState({}),
      size = _useState[0],
      setSize = _useState[1];

  useLayoutEffect(function () {
    setSize({
      width: window.innerWidth,
      height: window.innerHeight
    });

    function handleResize() {
      setSize({
        width: window.innerWidth,
        height: window.innerHeight
      });
    }

    window.addEventListener('resize', handleResize);
    return function () {
      return window.removeEventListener('resize', handleResize);
    };
  }, []);
  return size;
}

var TabList =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__TabList",
  componentId: "sc-1j63mtv-0"
})(["position:relative;width:100%;overflow-x:auto;display:flex;border:0;", ";&::before{content:'';position:absolute;", ";}"], system,
/*#__PURE__*/
th('tabs.tabsBorder'));
var Tab =
/*#__PURE__*/
styled.button.withConfig({
  displayName: "styles__Tab",
  componentId: "sc-1j63mtv-1"
})(["border:0;background:none;", ";display:flex;align-items:center;flex:none;margin-right:xl;padding:lg 0;transition:medium;text-transform:none;cursor:pointer;&[aria-selected='true']{", ";}&[aria-disabled='true']{", ";cursor:auto;}&:hover:not([aria-selected='true']):not([aria-disabled='true']){", ";}&:focus{outline:none;&:not([aria-selected='true']){", ";}}"],
/*#__PURE__*/
th('tabs.item.default'),
/*#__PURE__*/
th('tabs.item.active'),
/*#__PURE__*/
th('tabs.item.disabled'),
/*#__PURE__*/
th('tabs.item.focus'),
/*#__PURE__*/
th('tabs.item.focus'));
var TabPanel =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "styles__TabPanel",
  componentId: "sc-1j63mtv-2"
})(["", ";"],
/*#__PURE__*/
th('tabs.panel'));
var ActiveBar =
/*#__PURE__*/
styled.span.withConfig({
  displayName: "styles__ActiveBar",
  componentId: "sc-1j63mtv-3"
})(function (_ref) {
  var _ref$left = _ref.left,
      left = _ref$left === void 0 ? 0 : _ref$left,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? 0 : _ref$width;
  return css(["", ";position:absolute;left:0;width:", ";transform:translateX(", "px);will-change:width,transform;transition:medium;transition-property:transform,width;"], th('tabs.activeBar'), width + "px", left);
});

function useTrackActiveTabs(state, children) {
  var _useState = useState(null),
      activeTab = _useState[0],
      setActiveTab = _useState[1];

  var tabs = flattenChildren(children).map(function (child) {
    if (child.props.stopId === state.selectedId) {
      return cloneElement(child, {
        ref: setActiveTab
      });
    }

    return child;
  });
  return [tabs, activeTab];
}

function useActiveBarState(listRef, activeTab) {
  var _useState2 = useState({}),
      state = _useState2[0],
      setState = _useState2[1];

  var _useViewportSize = useViewportSize(),
      viewportWidth = _useViewportSize.width;

  useLayoutEffect(function () {
    var list = listRef.current;
    if (!list || !activeTab) return;
    var listRect = list.getBoundingClientRect();
    var activeTabRect = activeTab.getBoundingClientRect();
    var left = activeTabRect.left - listRect.left + list.scrollLeft;
    var width = activeTabRect.width;
    setState({
      width: width,
      left: left
    });
  }, [listRef, activeTab, viewportWidth]);
  return state;
}

var ActiveBar$1 = function ActiveBar$1(_ref) {
  var activeTab = _ref.activeTab,
      listRef = _ref.listRef;
  var activeBar = useActiveBarState(listRef, activeTab);
  return React.createElement(ActiveBar, activeBar);
};

ActiveBar$1.displayName = 'ActiveBar';
var TabList$1 =
/*#__PURE__*/
React.forwardRef(function (_ref2, ref) {
  var as = _ref2.as,
      children = _ref2.children,
      props = _objectWithoutPropertiesLoose(_ref2, ["as", "children"]);

  var listRef = React.useRef();
  var listForkedRef = useForkRef(ref, listRef);

  var _useTrackActiveTabs = useTrackActiveTabs(props, children),
      tabs = _useTrackActiveTabs[0],
      activeTab = _useTrackActiveTabs[1];

  return React.createElement(TabList$2, _extends({
    ref: listForkedRef
  }, props), function (tabListProps) {
    return React.createElement(TabList, _extends({
      as: as
    }, tabListProps), tabs, tabs.length > 1 && React.createElement(ActiveBar$1, {
      activeTab: activeTab,
      listRef: listRef
    }));
  });
});
TabList$1.displayName = 'TabList';
var Tab$1 =
/*#__PURE__*/
React.forwardRef(function (_ref3, ref) {
  var as = _ref3.as,
      children = _ref3.children,
      stopId = _ref3.stopId,
      props = _objectWithoutPropertiesLoose(_ref3, ["as", "children", "stopId"]);

  return React.createElement(Tab$2, _extends({
    ref: ref,
    stopId: stopId
  }, props), function (tabProps) {
    return React.createElement(Tab, _extends({
      as: as
    }, tabProps), children);
  });
});
Tab$1.displayName = 'Tab';
var TabPanel$1 =
/*#__PURE__*/
React.forwardRef(function (_ref4, ref) {
  var as = _ref4.as,
      children = _ref4.children,
      stopId = _ref4.stopId,
      props = _objectWithoutPropertiesLoose(_ref4, ["as", "children", "stopId"]);

  return React.createElement(TabPanel$2, _extends({
    ref: ref,
    stopId: stopId
  }, props), function (tabPanelProps) {
    return React.createElement(TabPanel, _extends({
      as: as
    }, tabPanelProps), children);
  });
});
TabPanel$1.displayName = 'TabPanel';

var afterCheckedStyles =
/*#__PURE__*/
css(["&::after{left:100%;transform:translateX(-100%);}"]);
var checkedStyles$1 =
/*#__PURE__*/
css(["", ";", ""],
/*#__PURE__*/
th('fields.toggles.checked'), afterCheckedStyles);
var checkedDisabledStyles =
/*#__PURE__*/
css(["", ";", ""],
/*#__PURE__*/
th('fields.toggles.checkedDisabled'), afterCheckedStyles);
var Toggle =
/*#__PURE__*/
styled(filterComponent(Checkbox))(function (_ref) {
  var checked = _ref.checked,
      connected = _ref.connected,
      disabled = _ref.disabled,
      _ref$order = _ref.order,
      order = _ref$order === void 0 ? '-1' : _ref$order;
  var toggleSize = th('fields.toggles.default.width');
  return css(["appearance:none;background:transparent;border:", " solid;outline:none;", ";", ";position:relative;display:block;width:calc(", " * 2);height:calc(", " + 2 * ", ");cursor:", ";border-radius:", ";transition:0.3s;order:", ";&::after{content:'';position:absolute;top:0;left:0;width:", ";height:", ";border-radius:", ";transition:0.3s;}&:active::after{width:", ";}&:focus{border-color:", ";}", " ", " ", ";"], th.borderWidth('sm'), th('fields.toggles.default'), disabled && th('fields.toggles.disabled'), toggleSize, toggleSize, th.borderWidth('sm'), disabled ? 'not-allowed' : 'pointer', toggleSize, order, toggleSize, toggleSize, toggleSize, disabled ? null : '55%', th('colors.primary.500'), checked && !disabled && checkedStyles$1, checked && disabled && checkedDisabledStyles, connected ? componentSystem : system);
});

var Toggle$1 =
/*#__PURE__*/
forwardRef(function (props, ref) {
  return React.createElement(InputCheckbox$1, _extends({}, props, {
    Component: Toggle,
    ref: ref
  }));
});
Toggle$1.type = 'Toggle';
Toggle$1.displayName = 'Toggle';

var Tooltip =
/*#__PURE__*/
styled(filterComponent(Tooltip$2)).withConfig({
  displayName: "styles__Tooltip",
  componentId: "sc-6dl0tf-0"
})(["", ";padding:sm;font-size:body4;", ";"],
/*#__PURE__*/
th('tooltips'), system);

var TOOLTIP_VISIBILITY_DELAY = 50;

var useDelayedVisibility = function useDelayedVisibility(value, duration) {
  var _useState = useState(null),
      visibility = _useState[0],
      setVisibility = _useState[1];

  useEffect(function () {
    var id;

    if (value) {
      id = setTimeout(function () {
        setVisibility({
          visibility: 'visible'
        });
      }, duration);
    } else {
      setVisibility({
        visibility: 'hidden'
      });
    }

    return function () {
      return id && clearTimeout(id);
    };
  }, [value, duration]);
  return visibility;
};

var useMouseTooltipState = function useMouseTooltipState(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      originalPlacement = _ref.placement,
      rest = _objectWithoutPropertiesLoose(_ref, ["placement"]);

  var popper = useRef(null);
  var referenceRef = useRef(null);
  var mouseRef = useRef(null);
  var popoverRef = useRef(null);

  var _useState2 = useState(originalPlacement),
      placement = _useState2[0],
      setPlacement = _useState2[1];

  var _useState3 = useState({}),
      popoverStyles = _useState3[0],
      setPopoverStyles = _useState3[1];

  var dialog = useDialogState(rest);
  var createPopper = useCallback(function () {
    if ((mouseRef.current || referenceRef.current) && popoverRef.current) {
      popper.current = new Popper$1(mouseRef.current || referenceRef.current, popoverRef.current, {
        placement: originalPlacement,
        eventsEnabled: dialog.visible,
        modifiers: {
          applyStyle: {
            enabled: false
          },
          updateStateModifier: {
            order: 900,
            enabled: true,
            fn: function fn(data) {
              setPlacement(data.placement);
              setPopoverStyles(data.styles);
              return data;
            }
          }
        }
      });
    }
  }, [originalPlacement, dialog.visible]);
  useLayoutEffect(function () {
    createPopper();
    return function () {
      if (popper.current) {
        popper.current.destroy();
      }
    };
  }, [createPopper]);
  useEffect(function () {
    var reference = referenceRef.current;
    var paddingTop = placement.startsWith('top') ? 5 : 0;
    var paddingBottom = placement.startsWith('bottom') ? 20 : 0;
    var paddingLeft = placement.startsWith('left') ? 5 : 0;
    var paddingRight = placement.startsWith('right') ? 15 : 0;

    var onMouseMove = function onMouseMove(event) {
      mouseRef.current = {
        getBoundingClientRect: function getBoundingClientRect() {
          return _extends({}, reference.getBoundingClientRect(), {
            top: event.clientY - paddingTop,
            bottom: event.clientY + paddingBottom,
            left: event.clientX - paddingLeft,
            right: event.clientX + paddingRight
          });
        }
      };
      createPopper();
    };

    if (reference) {
      reference.addEventListener('mousemove', onMouseMove);
    }

    return function () {
      mouseRef.current = null;

      if (reference) {
        reference.removeEventListener('mousemove', onMouseMove);
      }
    };
  }, [createPopper, placement]);
  return _extends({}, dialog, {
    unstable_referenceRef: referenceRef,
    unstable_popoverRef: popoverRef,
    unstable_popoverStyles: popoverStyles,
    placement: placement
  });
};

var Tooltip$1 =
/*#__PURE__*/
forwardRef(function (_ref2, ref) {
  var children = _ref2.children,
      content = _ref2.content,
      _ref2$fixed = _ref2.fixed,
      fixed = _ref2$fixed === void 0 ? false : _ref2$fixed,
      _ref2$placement = _ref2.placement,
      placement = _ref2$placement === void 0 ? fixed ? 'top' : 'bottom-start' : _ref2$placement,
      props = _objectWithoutPropertiesLoose(_ref2, ["children", "content", "fixed", "placement"]);

  var useCorrectTooltipState = fixed ? useTooltipState : useMouseTooltipState;
  var tooltip = useCorrectTooltipState({
    placement: placement
  });
  var visibilityStyles = useDelayedVisibility(tooltip.visible, TOOLTIP_VISIBILITY_DELAY);
  return React.createElement(React.Fragment, null, React.createElement(TooltipReference, tooltip, function (referenceProps) {
    return cloneElement(React.Children.only(children), referenceProps);
  }), React.createElement(Tooltip, _extends({
    ref: ref,
    style: visibilityStyles
  }, tooltip, props), content));
});

function getFormat(extension) {
  return extension === 'ttf' ? 'truetype' : extension;
}

function getUrl(url, extension) {
  return "url('" + url + "." + extension + "') format('" + getFormat(extension) + "')";
}

function getSrc(descriptor) {
  return descriptor.extensions.map(function (extension) {
    return getUrl(descriptor.url, extension);
  }).join(', ');
}

function getFont(descriptor) {
  return css(["@font-face{font-family:", ";src:", ";font-display:fallback;", " ", "}"], descriptor.name, getSrc(descriptor), descriptor.weight && css(["font-weight:", ";"], descriptor.weight), descriptor.style && css(["font-style:", ";"], descriptor.style));
}

var fonts = function fonts() {
  return function (_ref) {
    var theme = _ref.theme;
    if (!theme || !theme.fontFaces) return null;
    return Object.entries(theme.fontFaces) // Ignore anything else than array
    .filter(function (_ref2) {
      var variations = _ref2[1];
      return Array.isArray(variations);
    }).map(function (_ref3) {
      var name = _ref3[0],
          variations = _ref3[1];
      return variations.map(function (variation) {
        return getFont(_extends({
          name: name
        }, variation));
      });
    });
  };
};

var resetStyles =
/*#__PURE__*/
css(["html,body,div,span,applet,object,iframe,h1,h2,h3,h4,h5,h6,p,blockquote,pre,a,abbr,acronym,address,big,cite,code,del,dfn,em,img,ins,kbd,q,s,samp,small,strike,strong,sub,sup,tt,var,b,u,i,center,dl,dt,dd,ol,ul,li,fieldset,form,label,legend,table,caption,tbody,tfoot,thead,tr,th,td,article,aside,canvas,details,embed,figure,figcaption,footer,header,hgroup,menu,nav,output,ruby,section,summary,time,mark,audio,video{min-width:0;min-height:0;margin:0;padding:0;border:0;font-size:100%;font:inherit;vertical-align:baseline;}article,aside,details,figcaption,figure,footer,header,hgroup,menu,nav,section{display:block;}ol,ul{list-style:none;}blockquote,q{quotes:none;}blockquote::before,blockquote::after,q::before,q::after{content:'';content:none;}table{border-collapse:collapse;border-spacing:0;}a{text-decoration:none;}img{overflow:hidden;}input{-webkit-appearance:none;-moz-appearance:none;appearance:none;}input::-webkit-search-cancel-button{display:none;}:focus{outline:none;}*,*::after,*::before{box-sizing:border-box;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;}html{height:100%;}body{min-height:100%;padding-top:1px;margin-top:-1px;}"]);

function getFontFamilies() {
  for (var _len = arguments.length, fonts = new Array(_len), _key = 0; _key < _len; _key++) {
    fonts[_key] = arguments[_key];
  }

  return fonts.filter(Boolean).join(', ');
}

var baseBoxSizing =
/*#__PURE__*/
css(["*{&,&::before,&::after{box-sizing:border-box;}}"]);

function baseFonts(props) {
  var texts = getFont$1('texts')(props);
  var headings = getFont$1('headings')(props);
  var sansSerif = 'sans-serif';
  return css(["@media (max-width:1200px){html{font-size:87.5%;}}@media (max-width:1300px) and (max-height:700px){html{font-size:87.5%;}}@media (max-width:600px){html{font-size:100%;}}body,button,input,select,textarea{font-family:", ";-webkit-font-smoothing:antialiased;}h1,h2,h3,h4,h5,h6{font-family:", ";}"], getFontFamilies(texts, sansSerif), getFontFamilies(headings, texts, sansSerif));
}

function baseSelection(props) {
  var selectionBgColor = getColor('primary.500')(props) || null;
  var selectionColor = getColor('light.100')(props) || null;
  return css(["::selection{", ";", ";}"], selectionBgColor && "background-color: " + selectionBgColor, selectionColor && "color: " + selectionColor);
}

var GlobalStyle =
/*#__PURE__*/
createGlobalStyle(function (_ref) {
  var useReset = _ref.useReset;
  return css(["", ";", ";", ";", ";", ";"], normalize(), useReset ? resetStyles : baseBoxSizing, fonts(), baseFonts, baseSelection);
});

var getAlerts = function getAlerts(theme) {
  var colors = theme.colors,
      fontSizes = theme.fontSizes,
      radii = theme.radii,
      space = theme.space;
  return {
    "default": {
      'font-size': fontSizes.body3,
      'border-radius': radii.md,
      padding: space.lg
    },
    error: {
      'background-color': colors.danger[100],
      color: colors.danger[500]
    },
    warning: {
      'background-color': colors.warning[100],
      color: colors.warning[500]
    },
    info: {
      'background-color': colors.info[100],
      color: colors.info[500]
    },
    success: {
      'background-color': colors.success[100],
      color: colors.success[500]
    }
  };
};

var getButtons = function getButtons(theme) {
  var colors = theme.colors,
      fontSizes = theme.fontSizes,
      fontWeights = theme.fontWeights,
      letterSpacings = theme.letterSpacings,
      radii = theme.radii,
      shadows = theme.shadows,
      space = theme.space;
  var defaults = {
    color: colors.light[200],
    'font-size': fontSizes.button,
    'font-weight': fontWeights.bold,
    'text-transform': 'uppercase',
    'letter-spacing': letterSpacings.md,
    'background-color': colors.primary[500],
    'border-color': colors.primary[500],
    'border-radius': radii.md,
    'line-height': '100%',
    '&:hover': {
      'box-shadow': shadows.sm
    },
    '&:focus': {
      'box-shadow': shadows.sm
    }
  };
  return {
    primary: defaults,
    secondary: _extends({}, defaults, {
      color: colors.secondary[700],
      'background-color': colors.light[200],
      'border-color': colors.nude[200]
    }),
    tertiary: _extends({}, defaults, {
      color: colors.light[200],
      'background-color': colors.secondary[700],
      'border-color': colors.secondary[700]
    }),
    'primary-warning': _extends({}, defaults, {
      color: colors.light[200],
      'background-color': colors.warning[500],
      'border-color': colors.warning[500]
    }),
    'secondary-warning': _extends({}, defaults, {
      color: colors.warning[500],
      'background-color': colors.light[200],
      'border-color': colors.warning[500]
    }),
    'primary-danger': _extends({}, defaults, {
      color: colors.light[200],
      'background-color': colors.danger[500],
      'border-color': colors.danger[500]
    }),
    'secondary-danger': _extends({}, defaults, {
      color: colors.danger[500],
      'background-color': colors.light[200],
      'border-color': colors.danger[500]
    }),
    quaternary: _extends({}, defaults, {
      color: colors.nude[700],
      'background-color': colors.nude[200],
      'border-color': colors.nude[200]
    }),
    focused: {
      primary: {
        'background-color': colors.primary[200],
        'border-color': colors.primary[200]
      },
      secondary: {
        color: colors.secondary[500],
        'border-color': colors.nude[400]
      },
      tertiary: {
        'background-color': colors.secondary[500],
        'border-color': colors.secondary[500]
      },
      'primary-warning': {
        'background-color': colors.warning[200],
        'border-color': colors.warning[200]
      },
      'secondary-warning': {
        color: colors.warning[200],
        'border-color': colors.warning[200]
      },
      'primary-danger': {
        'background-color': colors.danger[200],
        'border-color': colors.danger[200]
      },
      'secondary-danger': {
        color: colors.danger[200],
        'border-color': colors.danger[200]
      },
      quaternary: {
        color: colors.nude[800],
        'background-color': colors.nude[400],
        'border-color': colors.nude[400]
      }
    },
    disabled: _extends({}, defaults, {
      color: colors.nude[700],
      'background-color': colors.light[700],
      'border-color': colors.light[700]
    }),
    sizes: {
      xs: {
        height: '1.25rem',
        padding: "0 " + space.sm
      },
      sm: {
        height: '2rem',
        padding: "0 " + space.sm
      },
      md: {
        height: '2.25rem',
        padding: "0 " + space.md
      },
      lg: {
        height: '2.5rem',
        padding: "0 " + space.lg
      },
      xl: {
        height: '4.375rem',
        padding: "0 " + space.lg
      }
    }
  };
};

// To allow for line-height of text in label
var LINE_HEIGHT_ADJUSTMENTS = '0.15rem';
var getFields = function getFields(theme) {
  var colors = theme.colors,
      fontSizes = theme.fontSizes,
      fontWeights = theme.fontWeights,
      radii = theme.radii,
      shadows = theme.shadows,
      space = theme.space,
      toRem = theme.toRem;
  var defaults = {
    color: colors.nude[800],
    'font-size': fontSizes.body3,
    'line-height': toRem(16),
    'font-weight': fontWeights.regular,
    'background-color': colors.light[100],
    'border-color': colors.nude[200],
    'border-width': '1px',
    'border-style': 'solid',
    'border-radius': radii.md,
    outline: 'none'
  };
  var checked = {
    'background-color': colors.primary[500],
    'border-color': colors.primary[500],
    color: colors.light[100],
    '&::after': {
      opacity: 1
    }
  };
  return {
    "default": defaults,
    disabled: {
      'background-color': colors.light[500],
      color: colors.nude[600],
      cursor: 'not-allowed'
    },
    focused: {
      'border-color': colors.primary[500]
    },
    sizes: {
      sm: {
        height: '2rem',
        padding: space.xs + " " + space.md
      },
      md: {
        height: '2.25rem',
        padding: space.sm + " " + space.md
      },
      lg: {
        height: '2.5rem',
        padding: space.md
      }
    },
    placeholder: {
      color: colors.nude[600]
    },
    hint: {
      color: colors.nude[600],
      'font-size': fontSizes.body3,
      'font-weight': fontWeights.regular
    },
    label: {
      color: colors.nude[800],
      'font-size': fontSizes.body3,
      'font-weight': fontWeights.medium,
      'min-height': '1.4em'
    },
    checkablelabel: {
      "default": {
        'font-weight': fontWeights.regular
      },
      checked: {
        color: colors.dark[200],
        '-webkit-text-stroke': '0.04em'
      }
    },
    checkbox: {
      "default": {
        width: toRem(15),
        height: toRem(15),
        'flex-shrink': 0,
        'margin-top': LINE_HEIGHT_ADJUSTMENTS
      },
      checked: checked
    },
    radio: {
      "default": {
        width: toRem(18),
        height: toRem(18),
        'border-radius': '50%'
      },
      checked: _extends({}, checked, {
        'border-radius': '50%'
      })
    },
    fileupload: {
      'border-style': 'dashed',
      height: toRem(300)
    },
    mde: {
      icons: {
        'font-size': fontSizes.body3,
        color: colors.secondary[500],
        '&.active': {
          color: colors.primary[200],
          'border-color': colors.nude[300]
        },
        '&:hover': {
          color: colors.primary[200],
          'border-color': colors.nude[300]
        }
      }
    },
    radiotabs: {
      "default": _extends({}, defaults),
      checked: {
        color: colors.dark[200],
        'background-color': colors.light[200],
        'border-color': colors.primary[500],
        '&:hover': {
          'box-shadow': 'none'
        }
      },
      hover: {
        'background-color': colors.light[200],
        'box-shadow': shadows.sm
      }
    },
    select: {
      "default": {
        'max-height': toRem(200)
      },
      existing: {
        color: colors.nude[500],
        cursor: 'not-allowed'
      },
      highlighted: {
        'background-color': colors.light[500],
        cursor: 'default'
      },
      selected: {
        color: colors.dark[200],
        'font-weight': fontWeights.bold,
        'background-color': colors.primary[100]
      }
    },
    textarea: {
      'min-height': '8rem'
    },
    toggles: {
      "default": {
        width: toRem(22),
        'background-color': colors.nude[200],
        'border-color': colors.nude[200],
        'margin-top': "-" + LINE_HEIGHT_ADJUSTMENTS,
        '&::after': _extends({}, defaults, {
          'background-color': colors.light[200],
          'border-color': colors.nude[400]
        })
      },
      checked: {
        'background-color': colors.primary[500],
        'border-color': colors.primary[500],
        '&::after': {
          'border-color': colors.primary[500]
        }
      },
      disabled: {
        'border-color': colors.light[700],
        'background-color': colors.light[700],
        '&::after': {
          'border-color': colors.nude[200]
        }
      },
      checkedDisabled: {
        'border-color': colors.secondary[200],
        'background-color': colors.secondary[200],
        '&::after': {
          'border-color': colors.secondary[200]
        }
      }
    },
    fieldset: {
      'border-width': '0'
    }
  };
};

var getFontSizes = function getFontSizes(unit, theme) {
  var toEm = theme.toEm,
      toRem = theme.toRem;
  var convert = unit === 'em' ? toEm : toRem;
  return {
    h1: convert(36),
    h2: convert(28),
    h3: convert(22),
    h4: convert(18),
    body1: convert(17),
    body2: convert(15),
    body3: convert(13),
    body4: convert(11),
    button: convert(11),
    subtitle1: convert(13),
    subtitle2: convert(11),
    meta1: convert(13),
    meta2: convert(11)
  };
};
var getLineHeights = function getLineHeights() {
  return {
    html: '1.6em',
    h1: '1.6em',
    h2: '1.6em',
    h3: '1.6em',
    h4: '1.6em',
    body1: '1.6em',
    body2: '1.6em',
    body3: '1.6em',
    body4: '1.6em',
    button: '1.6em',
    subtitle1: '1.6em',
    subtitle2: '1.6em',
    meta1: '1.6em',
    meta2: '1.6em'
  };
};
var getTexts = function getTexts(theme) {
  var fontSizes = theme.fontSizes,
      fontWeights = theme.fontWeights,
      lineHeights = theme.lineHeights;
  return Object.keys(fontSizes).reduce(function (acc, key) {
    var _extends2;

    return _extends({}, acc, (_extends2 = {}, _extends2[key] = {
      'font-weight': fontWeights.regular,
      'font-size': fontSizes[key],
      'line-height': lineHeights[key] || lineHeights.body1
    }, _extends2));
  }, {});
};

var getGrowls = function getGrowls(theme) {
  var colors = theme.colors,
      fontWeights = theme.fontWeights,
      radii = theme.radii;
  return {
    "default": _extends({}, getTexts(theme).body3, {
      'background-color': theme.colors.light[200],
      'border-color': colors.nude[200],
      'border-width': '1px',
      'border-style': 'solid',
      'border-radius': radii.md
    }),
    title: _extends({}, getTexts(theme).body2, {
      'font-weight': fontWeights.bold
    }),
    close: {
      'background-color': colors.nude[200],
      'border-radius': '50%',
      '&:hover, &:focus': {
        'background-color': colors.nude[400]
      }
    }
  };
};

var getIcons = function getIcons(_ref) {
  var toRem = _ref.toRem;
  return {
    xs: toRem(10),
    sm: toRem(12),
    md: toRem(15),
    lg: toRem(20),
    xl: toRem(27.574)
  };
};

var getLinks = function getLinks(theme) {
  var colors = theme.colors,
      underline = theme.underline;
  return {
    "default": {
      color: colors.dark[500]
    },
    primary: underline,
    secondary: {}
  };
};

var getPaginations = function getPaginations(_ref) {
  var colors = _ref.colors,
      fontSizes = _ref.fontSizes,
      fontWeights = _ref.fontWeights,
      toRem = _ref.toRem;
  return {
    "default": {
      color: colors.nude[600],
      'font-weight': fontWeights.bold,
      'border-color': 'transparent',
      'border-width': '1px',
      'border-style': 'solid',
      width: toRem(30),
      height: toRem(30),
      '&:hover, &:focus': {
        color: colors.nude[800],
        'border-color': colors.nude[400]
      }
    },
    active: {
      color: colors.light[100],
      'background-color': colors.primary[500],
      'border-color': colors.primary[500],
      '&:hover, &:focus': {
        color: colors.light[100],
        'border-color': colors.primary[500]
      }
    },
    number: {
      'font-size': fontSizes.body3
    },
    dots: {
      color: colors.nude[600],
      'font-size': fontSizes.body3,
      '&:hover, &:focus': {
        border: 'none'
      }
    },
    arrow: {
      'background-color': colors.light[200],
      'border-color': colors.nude[200]
    }
  };
};

var getTabs = function getTabs(theme) {
  var borderWidths = theme.borderWidths,
      colors = theme.colors,
      fontSizes = theme.fontSizes,
      fontWeights = theme.fontWeights,
      space = theme.space;
  return {
    tabsBorder: {
      bottom: borderWidths.sm,
      width: '100%',
      height: borderWidths.sm,
      'background-color': colors.nude[200]
    },
    item: {
      "default": {
        color: colors.nude[600],
        'font-size': fontSizes.body2,
        'font-weight': fontWeights.medium
      },
      active: {
        color: colors.dark[700]
      },
      focus: {
        color: colors.nude[800]
      },
      disabled: {
        color: colors.nude[400]
      }
    },
    panel: {
      'margin-top': space.xl,
      '&:focus': {
        outline: 'none'
      }
    },
    activeBar: {
      bottom: 0,
      background: colors.primary[500],
      height: '3px',
      'border-radius': '3px'
    }
  };
};

var getVariantsTheme = function getVariantsTheme(theme) {
  return Object.entries(variantColors).reduce(function (acc, _ref) {
    var variant = _ref[0],
        color = _ref[1];

    if (variant !== '__filemeta') {
      acc[variant] = {
        'background-color': th(color)({
          theme: theme
        })
      };
    }

    return acc;
  }, {});
};
var getTags = function getTags(theme) {
  var colors = theme.colors,
      fontSizes = theme.fontSizes,
      fontWeights = theme.fontWeights,
      space = theme.space,
      toRem = theme.toRem;
  return {
    "default": {
      'font-size': fontSizes.meta2,
      'font-weight': fontWeights.medium,
      'line-height': '1em',
      color: colors.light[100]
    },
    variants: _extends({}, getVariantsTheme(theme), {
      "default": {
        'background-color': colors.light[500],
        color: colors.nude[800]
      }
    }),
    sizes: {
      sm: {
        padding: toRem(3.5) + " " + space.xxs
      },
      md: {
        padding: toRem(4.5) + " " + space.xxs
      },
      lg: {
        padding: toRem(6.5) + " " + space.xs,
        'font-size': fontSizes.meta1
      }
    },
    shape: {
      square: {
        sm: {
          width: '1.6363em',
          height: '1.6363em'
        },
        md: {
          width: '1.82em',
          height: '1.82em'
        },
        lg: {
          width: '2em',
          height: '2em'
        }
      },
      circle: {
        sm: {
          width: '1.6363em',
          height: '1.6363em'
        },
        md: {
          width: '1.82em',
          height: '1.82em'
        },
        lg: {
          width: '2em',
          height: '2em'
        }
      }
    }
  };
};

var getTooltips = function getTooltips(_ref) {
  var colors = _ref.colors,
      radii = _ref.radii,
      toRem = _ref.toRem;
  return {
    'max-width': toRem(200),
    color: colors.light[200],
    background: colors.dark[700],
    'border-radius': radii.md
  };
};

var colors = {
  primary: {
    100: '#D5E6F2',
    200: '#208DDB',
    500: '#187EC7'
  },
  secondary: {
    200: '#3A3A3A',
    500: '#2E2E2E',
    700: '#171717'
  },
  success: {
    100: '#EAf8EC',
    200: '#66CC75',
    500: '#49c25a'
  },
  danger: {
    100: '#FCDDDD',
    200: '#EA2A2D',
    500: '#D62327'
  },
  warning: {
    100: '#FBDCC5',
    200: '#EE8434',
    500: '#D6772F'
  },
  info: {
    100: '#DADAF4',
    200: '#6060D1',
    500: '#4E4EAA'
  },
  light: {
    100: '#FFFFFF',
    200: '#FAFAFA',
    500: '#FBF9F7',
    700: '#CCCCCC'
  },
  dark: {
    200: '#333333',
    500: '#2d2d2d',
    700: '#191919',
    900: '#000000'
  },
  nude: {
    100: '#E5E5E5',
    200: '#d6d6d6',
    300: '#c4c4c4',
    400: '#b7b7b7',
    500: '#a3a3a3',
    600: '#8e8e8e',
    700: '#828282',
    800: '#727272'
  },
  sub: {
    blue: '#559AF1',
    green: '#4AB519',
    orange: '#EA724C',
    pink: '#F0AABF',
    purple: '#965FE6',
    red: '#D04232',
    turquoize: '#3FD1C1',
    yellow: '#F4CF70'
  }
};

var fontFaces = {
  welcomeweb: [{
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-regular',
    weight: '400',
    extensions: ['woff2', 'woff', 'ttf']
  }, {
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-medium',
    weight: '500',
    extensions: ['woff2', 'woff', 'ttf']
  }, {
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-bold',
    weight: '600',
    extensions: ['woff2', 'woff', 'ttf']
  }, {
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-black',
    weight: '700',
    extensions: ['woff2', 'woff', 'ttf']
  }, {
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-regularitalic',
    weight: '400',
    style: 'italic',
    extensions: ['woff2', 'woff', 'ttf']
  }, {
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-mediumitalic',
    weight: '500',
    style: 'italic',
    extensions: ['woff2', 'woff', 'ttf']
  }, {
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-bolditalic',
    weight: '600',
    style: 'italic',
    extensions: ['woff2', 'woff', 'ttf']
  }, {
    url: 'https://cdn.welcometothejungle.co/common/assets/fonts/welcomeweb-blackitalic',
    weight: '700',
    style: 'italic',
    extensions: ['woff2', 'woff', 'ttf']
  }]
};

var transitionCurves = {
  primary: 'ease',
  secondary: 'linear',
  tertiary: 'cubic-bezier(0.41, 0.094, 0.54, 0.07)'
};
var transitions = {
  slow: "500ms " + transitionCurves.tertiary,
  medium: "300ms " + transitionCurves.primary,
  fast: "100ms " + transitionCurves.secondary
};

var DEFAULT_FONT_SIZE = 16;
var DEFAULT_FONT_FAMILY = 'welcomeweb';
var HEADING_FONT_FAMILY = 'welcomeweb';
var getBaseTheme = function getBaseTheme(options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      _options$defaultFontF = _options.defaultFontFamily,
      defaultFontFamily = _options$defaultFontF === void 0 ? DEFAULT_FONT_FAMILY : _options$defaultFontF,
      _options$headingFontF = _options.headingFontFamily,
      headingFontFamily = _options$headingFontF === void 0 ? HEADING_FONT_FAMILY : _options$headingFontF,
      rest = _objectWithoutPropertiesLoose(_options, ["defaultFontFamily", "headingFontFamily"]);

  var theme = {};
  theme.transformers = _extends({}, rpxTransformers);

  theme.toEm = function (px) {
    return px / DEFAULT_FONT_SIZE + "em";
  };

  theme.toRem = function (px) {
    return px / DEFAULT_FONT_SIZE + "rem";
  };

  theme.colors = colors; // fonts

  theme.fontFaces = fontFaces;
  theme.fontSizes = getFontSizes('rem', theme);
  theme.lineHeights = getLineHeights(theme);
  theme.fontWeights = {
    regular: '400',
    medium: '500',
    bold: '600',
    black: '700'
  };
  theme.letterSpacings = {
    sm: '0.5px',
    md: '1px',
    lg: '2px'
  };
  theme.fonts = {
    texts: defaultFontFamily,
    headings: headingFontFamily
  };
  theme.borderWidths = {
    sm: '1px',
    md: '2px'
  };
  theme.breakpoints = {
    xs: 0,
    sm: 480,
    md: 736,
    lg: 980,
    xl: 1280
  };
  theme.space = {
    xxs: theme.toRem(6),
    xs: theme.toRem(8),
    sm: theme.toRem(10),
    md: theme.toRem(12),
    lg: theme.toRem(15),
    xl: theme.toRem(24)
  };
  theme.icons = getIcons(theme);
  theme.radii = {
    sm: '4px',
    md: '6px',
    lg: '10px'
  };
  theme.transitions = transitions;
  theme.transitionCurves = transitionCurves;
  theme.shadows = {
    sm: '1px 2px 4px 0 rgba(0,0,0,0.05)'
  };
  theme.underline = {
    'border-bottom-style': 'solid',
    'border-bottom-width': theme.borderWidths.sm
  };
  theme = merge({}, theme, rest); // CSS blocks
  // These attributes depend on colors and fontSizes and must come last

  theme.underline['border-bottom-color'] = theme.colors.primary[500];
  theme.alerts = getAlerts(theme);
  theme.buttons = getButtons(theme);
  theme.fields = getFields(theme);
  theme.growls = getGrowls(theme);
  theme.paginations = getPaginations(theme);
  theme.tabs = getTabs(theme);
  theme.tags = getTags(theme);
  theme.texts = getTexts(theme);
  theme.tooltips = getTooltips(theme);
  theme.links = getLinks(theme);
  return theme;
};
var createTheme = function createTheme(options) {
  var base = getBaseTheme(options);
  var theme = merge({}, base, options);
  return theme;
};

var palette = {
  // primary
  eucalyptus: '#37CBA9',
  carribeangreen: '#00C29A',
  richblack: '#050506',
  smokyblack: '#0B0B0D',
  licorice: '#101013',
  eerieblack: '#16161A',
  moodyblack: '#1B1C20',
  raisinblack: '#212227',
  charcoal: '#26272E',
  gunmetal: '#2C2D34',
  metal: '#31333B',
  onyx: '#373942',
  darkliver: '#4B4D55',
  granite: '#5F6067',
  battleship: '#73747B',
  steel: '#87888D',
  silverchalice: '#AFAFB3',
  silver: '#C3C3C6',
  timberwolf: '#D7D7D9',
  isabelline: '#EEEEEE',
  snow: '#F9F9F9',
  // states : infos, warning & danger
  bluedefrance: '#3790F0',
  blueberry: '#4B9BF1',
  anzac: '#DDA343',
  sunray: '#E4AE56',
  carmen: '#BF4C3B',
  valencia: '#CE5947',
  // pastel
  mint: '#DFF5EB',
  aliceblue: '#DFEAFF',
  floralwhite: '#FFF2DC',
  rosewhite: '#FFE7E7'
};
var colors$1 = {
  primary: {
    100: palette.mint,
    200: palette.eucalyptus,
    500: palette.carribeangreen
  },
  secondary: {
    200: palette.granite,
    500: palette.onyx,
    700: palette.metal
  },
  danger: {
    100: palette.rosewhite,
    200: palette.valencia,
    500: palette.carmen
  },
  warning: {
    100: palette.floralwhite,
    200: palette.sunray,
    500: palette.anzac
  },
  info: {
    100: palette.aliceblue,
    200: palette.blueberry,
    500: palette.bluedefrance
  },
  light: {
    100: '#FFFFFF',
    200: palette.snow,
    500: palette.isabelline,
    700: palette.timberwolf
  },
  dark: {
    200: palette.metal,
    500: palette.raisinblack,
    700: palette.moodyblack,
    900: palette.richblack
  },
  nude: {
    100: palette.isabelline,
    200: palette.timberwolf,
    300: palette.silver,
    400: palette.silverchalice,
    500: palette.steel,
    600: palette.battleship,
    700: palette.granite,
    800: palette.darkliver
  }
};
var welcomeTheme = {
  colors: colors$1,
  alerts: {
    success: {
      'background-color': colors$1.primary[100],
      color: colors$1.primary[500]
    }
  },
  buttons: {
    secondary: {
      color: colors$1.secondary[500],
      'background-color': colors$1.light[100]
    },
    tertiary: {
      'background-color': colors$1.secondary[500],
      'border-color': colors$1.secondary[500]
    },
    focused: {
      secondary: {
        color: colors$1.secondary[200],
        'border-color': colors$1.nude[200],
        'box-shadow': 'none'
      },
      tertiary: {
        'background-color': colors$1.secondary[200],
        'border-color': colors$1.secondary[200]
      }
    },
    disabled: {
      color: colors$1.nude[600]
    }
  },
  palette: palette
};

var theme =
/*#__PURE__*/
getBaseTheme();
var palette$1 = {
  jade: '#00A772',
  mountainmeadow: '#17AF7F',
  //greens
  deepteal: '#002E32',
  cyprus: '#163D40',
  aquadeep: '#134B45',
  eden: '#2D5351',
  cadet: '#567672',
  seanymph: '#849C96',
  edward: '#9DB0AA',
  opal: '#AABEB9',
  junglemist: '#B9CCC6',
  nebula: '#CCDBD7',
  gin: '#E3F0EC',
  //nudes
  concord: '#7F7C7A',
  zorba: '#97938F',
  silverchalice: '#AFABA7',
  silversand: '#BFBDB9',
  quillgray: '#D7D5D1',
  gainsboro: '#E1DFDB',
  cararra: '#EEECE8',
  isabelline: '#F2F0ED',
  pampas: '#F6F4F2',
  vistawhite: '#FBF9F7',
  soapstone: '#FFFDFB',
  // states : infos, warning & danger
  bluedefrance: '#3790F0',
  blueberry: '#4B9BF1',
  anzac: '#DDA343',
  sunray: '#E4AE56',
  carmen: '#BF4C3B',
  valencia: '#CE5947',
  //colorpicker
  blue: '#559AF1',
  coral: '#EA724C',
  green: '#4AB519',
  pink: '#F0AABF',
  purple: '#965FE6',
  red: '#D04232',
  turquoize: '#3FD1C1',
  yellow: '#F4CF70',
  // pastel
  mint: '#DFF5EB',
  aliceblue: '#DFEAFF',
  floralwhite: '#FFF2DC',
  rosewhite: '#FFE7E7'
};
var colors$2 = {
  primary: {
    100: palette$1.gin,
    200: palette$1.mountainmeadow,
    500: palette$1.jade
  },
  secondary: {
    200: palette$1.seanymph,
    500: palette$1.cadet,
    700: palette$1.eden
  },
  danger: {
    100: palette$1.rosewhite,
    200: palette$1.valencia,
    500: palette$1.carmen
  },
  warning: {
    100: palette$1.floralwhite,
    200: palette$1.sunray,
    500: palette$1.anzac
  },
  info: {
    100: palette$1.aliceblue,
    200: palette$1.blueberry,
    500: palette$1.bluedefrance
  },
  light: {
    100: '#FFFFFF',
    200: palette$1.soapstone,
    500: palette$1.vistawhite,
    700: palette$1.pampas
  },
  dark: {
    200: palette$1.aquadeep,
    500: palette$1.cyprus,
    700: palette$1.deepteal,
    900: '#000'
  },
  nude: {
    100: palette$1.isabelline,
    200: palette$1.cararra,
    300: palette$1.gainsboro,
    400: palette$1.quillgray,
    500: palette$1.silversand,
    600: palette$1.silverchalice,
    700: palette$1.zorba,
    800: palette$1.concord
  }
};
var welcomekitTheme = {
  colors: colors$2,
  palette: palette$1,
  alerts: {
    success: {
      'background-color': colors$2.primary[100],
      color: colors$2.secondary[700]
    }
  },
  underline: {
    'border-bottom-width': theme.borderWidths.md
  },
  fields: {
    "default": {
      'background-color': colors$2.light[200]
    },
    focused: {
      'background-color': colors$2.light[100]
    }
  },
  tags: {
    variants: {
      "default": {
        'background-color': colors$2.nude[200]
      }
    }
  }
};

var getHexValueAtLocation = function getHexValueAtLocation(value, start, count) {
  return parseInt(value.substring(start, count), 16);
};

var isValidHex = function isValidHex(hex) {
  return /(^[0-9a-fA-F]{6}$)|(^[0-9a-fA-F]{3}$)/.test(hex);
};

var hexToRGB = function hexToRGB(hex) {
  if (!hex) {
    return;
  }

  hex = hex.replace('#', '');

  if (!isValidHex(hex)) {
    return;
  }

  if (hex.length === 3) {
    hex = "" + hex[0] + hex[0] + hex[1] + hex[1] + hex[2] + hex[2];
  }

  var hexToR = function hexToR(hex) {
    return getHexValueAtLocation(hex, 0, 2);
  };

  var hexToG = function hexToG(hex) {
    return getHexValueAtLocation(hex, 2, 4);
  };

  var hexToB = function hexToB(hex) {
    return getHexValueAtLocation(hex, 4, 6);
  };

  return hexToR(hex) + ", " + hexToG(hex) + ", " + hexToB(hex);
};

var getThemeValue = function getThemeValue(theme, path) {
  var value = _get(theme, path);

  if (process.env.NODE_ENV !== 'production') {
    if (value === undefined) {
      // eslint-disable-next-line no-console
      console.warn(path + " is not available in this theme");
    }
  }

  return value;
};

var rgba = function rgba(theme, path, opacity) {
  var value = getThemeValue(theme, "colors." + path.join('.'));

  if (value && typeof value === 'string') {
    return "rgba(" + hexToRGB(value) + ", " + opacity + ")";
  } else {
    return undefined;
  }
};

var get = function get(path, fallback) {
  return function (_ref) {
    var theme = _ref.theme;

    var _path$split = path.split('.'),
        key = _path$split[0],
        rest = _path$split.slice(1);

    if (key === 'rgba') {
      return rgba(theme, rest, fallback);
    }

    var value = getThemeValue(theme, path, fallback);

    if (process.env.NODE_ENV !== 'production' && value && typeof value !== 'string' && typeof value !== 'number') {
      // eslint-disable-next-line no-console
      console.warn(path + " is returning an object rather than a value", value);
    }

    return value;
  };
};

// Components

export { Alert$1 as Alert, AlertTitle, Badge, Box, Button$1 as Button, ClearButton$1 as ClearButton, ConnectedField, DatePicker$1 as DatePicker, DatePickerPopper, DateTimePicker$1 as DateTimePicker, Field$1 as Field, FieldGroup$1 as FieldGroup, FileDrop$1 as FileDrop, FilePreviewImage$1 as FilePreviewImage, FileUpload, GlobalStyle, Growl$1 as Growl, GrowlAction, GrowlClose, GrowlTitle, Hint$1 as Hint, Icon$1 as Icon, InputCheckbox$1 as InputCheckbox, InputRadio$1 as InputRadio, InputText$1 as InputText, InputTextarea, Label$1 as Label, Link, MarkdownEditor, Pagination$1 as Pagination, RadioGroup, RadioTab, Select, Shape$1 as Shape, Tab$1 as Tab, TabList$1 as TabList, TabPanel$1 as TabPanel, Tag$1 as Tag, Text$1 as Text, TimePicker$1 as TimePicker, Toggle$1 as Toggle, Tooltip$1 as Tooltip, UniversalLink$1 as UniversalLink, VariantIcon$1 as VariantIcon, createTheme, get, getBaseTheme, welcomeTheme, welcomekitTheme };
